<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BzAdapterIframe extends BAdapter {

	public $bookzoiframe;
	
	/**
	 * Check for valid adapter
	 *
	 * We just see if joomla framework is set
	 * If not we try to load it ourself
	 *
	 * @params	 	none
	 * @return		boolean		true if valid, false otherwise
	 * @access		public
	 * @since 		1.0.0
	 */
	public function valid()
	{
		if ( !$return = defined('BOOKZO_IFRAME') ) 
		{
		
			$iframeroot = dirname(BOOKZO_ROOT);
		
			if ( file_exists($iframeroot.'/iframe.php') ) 
			{
				require_once($iframeroot.'/iframe.php');

				if ( defined('BOOKZO_IFRAME') && class_exists('BookzoFrame') ) 
				{
					$return 			= true;
				}
			}
		}
				
		if ( $return )
		{
			$this->bookzoiframe = BookzoFrame::getInstance();

			// try loading credentials and other iframe settings
			if ( false !== ($accountname = $this->app->input->get('account', $this->bookzoiframe->session->get('bookzo.accountname', false, 'bookzo'))) ) 
			{
				$this->bookzoiframe->session->set('bookzo.accountname', $accountname, 'bookzo');

				// load credentials
				if ( $credentials = $this->bookzoiframe->account->getCredentials($accountname) )
				{
					$this->app->config->set('general.bookzourl', 	$credentials['server']);
					$this->app->config->set('general.accountname', 	$credentials['accountname']);
					$this->app->config->set('general.password', 	$credentials['password']);
				}
				
				// try loading configfile
				if ( $config = $this->bookzoiframe->account->getConfig($accountname) )
				{
					$this->app->config->merge($this->app->registry->create($config), true);
				}
				
				$this->app->config->set('iframe.account', $accountname);
			}
			

		}
		
		return $return;
	}
	
	/**
	 * Let the CMS add a stylesheet from within bookzo
	 *
	 * @params	 	$path		the path to the file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addStyleSheet($path, $external = false, $addversion = true)
	{		
		if ($external || ($path = $this->app->path->url($path))) {
			$this->bookzoiframe->document->addStyleSheet($path);
		}
		
		return $this;
	}
	
	/**
	 * Let the CMS add a javascript file from within bookzo
	 *
	 * @params	 	$path		the path to the file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addScript($path, $external = false, $addversion = true)
	{	
		if ($external || ($path = $this->app->path->url($path))) {
			$this->bookzoiframe->document->addScript($path);
		}
		
		return $this;	
	}
	
	/**
	 * Let the CMS add a javascript string from within bookzo
	 *
	 * @params	 	$string		the javascript
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addScriptDeclaration($js)
	{		
		$this->bookzoiframe->document->addScriptDeclaration($js);
		
		return $this;	
	}
	
	/**
	 * Let the CMS add jquery
	 * If CMS doesn't have jquery we could load a CDN jquery file
	 *
	 * @params	 	$ui		if true also load the jquery.ui file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function jQuery($ui = false)
	{
		$this->bookzoiframe->document->jquery($ui);	
		
		return $this;	
	}
	
	/**
	 * Let the CMS determine the SEO url for the page requested
	 *
	 * @params	 	$link	the page we are trying to load
	 * @params		$xhtml	replace & for &amp;
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function route($link, $xhtml = true, $addbase = false)
	{
		$account  = $this->bookzoiframe->session->get('bookzo.accountname', false, 'bookzo');
		$link	 .= '&account='. $account;
		
		return BOOKZO_SITE_URL . $this->bookzoiframe->route->url($link);
	}
	
	/**
	 * Let the CMS redirect us to another page
	 *
	 * @params	 	$link	the page we are redirecting to
	 * @params		$status	the html page code. default = 303
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function redirect($link, $status = 303)
	{		
		$this->bookzoiframe->redirect($link, $status);
	}
	
	/**
	 * Set a session value within the CMS
	 *
	 * @params	 	$name	the name of the value to set
	 * @params		$value	the value to set
	 * @return		bool	true if succesful
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionSet($name, $value = null, $namespace = 'bookzo')
	{
		return $this->bookzoiframe->session->set($name, $value, $namespace);
	}
	
	/**
	 * See if the session has a value
	 *
	 * @params	 	$name		the name of the value to check
	 * @params		$namespace	an optional namespace within the session to search within
	 * @return		boolean		true if value exists
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionHas($name, $namespace = 'bookzo')
	{
		return $this->bookzoiframe->session->has($name, $namespace);		
	}
	
	/**
	 * Get a value from the CMS session
	 *
	 * @params	 	$name		the name of the value to get
	 * @params		$default	the default value if not found
	 * @return		mixed		the value found
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionGet($name, $default = null, $namespace = 'bookzo')
	{
		return $this->bookzoiframe->session->get($name, $default, $namespace);
	}
	
	/**
	 * Clear a value within the session
	 *
	 * @params	 	$name		the name of the value to remove
	 * @params		$namespace	an optional namespace within the session to search within
	 * @return		boolean		true if removed
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionClear($name, $namespace = 'bookzo')
	{
		return $this->bookzoiframe->session->clear($name, $namespace);		
	}
	
	/**
	 * See if we have a new session
	 *
	 * @return		boolean		true if new
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionNew()
	{
		return $this->bookzoiframe->session->isNew();		
	}
	
	/**
	 * Clear complete session
	 *
	 * @return		boolean		true if new
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionDestroy()
	{
		return $this->bookzoiframe->session->destroy();	
	}
	
	/**
	 * Add a default path for Bookzo overrides
	 * In Joomla this would be the active template html dir
	 *
	 * @params	 	none		
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addPaths()
	{
		$namespaces = $this->app->path->getNameSpaces();
		$base	  	= __DIR__ . '/iframe/';

		foreach ( $namespaces as $namespace ) {
			$this->app->path->register($base.$namespace, 	$namespace);
		}
	}
	
	public function getLanguage()
	{
		$lang = $this->app->input->get('lang', 
					$this->bookzoiframe->session->get('bookzo.iframelang', '', 'bookzo')
				);
				
		if ( $lang != $this->bookzoiframe->session->get('bookzo.iframelang', '', 'bookzo') ) {
			$this->bookzoiframe->session->set('bookzo.iframelang', $lang, 'bookzo');
		}
				
		return $lang;
	}
	
	public function isAdmin()
	{
		return false;
	}
	
	public function isHomepage()
	{
		return false;
	}
	
	public function isBookzoPage()
	{
		return false;
	}
	
	public function setMetaData($type, $value)
	{
		return;
	}
	
	public function afterBooking( $booking )
	{
		return;
	}
	
	/**
	 * Hook to fire on after bookzoload
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function bookzoInit() {
		
		$account  = $this->app->config->get('iframe.account');
		$language = $this->app->language->get('tag');
		
		if ( $account && $language ) {
			if ( $override = $this->bookzoiframe->account->getFile($account, $language . '.override.ini') ) 
			{
				$contents 	= str_replace('_BQQ_', '"\""', $override);
				$strings 	= @parse_ini_string($contents);
	
				if (!is_array($strings))
				{
					$strings = array();
				}
			
				$this->app->language->addOverrides($strings);
			}
		}
	}
}