<?php
/**
 * @package   bookzo
 * @author    Invenda  http://www.invenda.nl
 * @copyright Copyright (C) Invenda
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Base View class
 *
 * @package Framework.Classes
 */
class BzModelConfig extends BModelForm {
	
	/**
	 * Method to get the record form.
	 *
	 * @param	array	$data		Data for the form.
	 * @param	boolean	$loadData	True if the form is to load its own data (default case), false if not.
	 * @return	mixed	A JForm object on success, false on failure
	 * @since	1.6
	 */
	public function getForm($data = array(), $loadData = true)
	{
		// Get the form.
		$form = $this->loadForm('bookzo.config', 'config', array('control' => 'bookzo', 'load_data' => $loadData));
		
		if (empty($form)) {
			return false;
		}	
		
		return $form;
	}
	
	/**
	 * Method to allow derived classes to preprocess the form.
	 *
	 * @param   JForm   $form   A JForm object.
	 * @param   mixed   $data   The data expected for the form.
	 * @param   string  $group  The name of the plugin group to import (defaults to "content").
	 *
	 * @return  void
	 *
	 * @see     BFormField
	 * @since   12.2
	 * @throws  Exception if there is an error in the form event.
	 */
	protected function preprocessForm(BForm $form, $data)
	{
		// get all widgets config files
		$widgets	 = $this->app->widget->getList();
				
		foreach ( $widgets as $widget ) {
			if ( $widgetform = $this->app->widget->{$widget}->getConfigForm() ) {
				$this->app->widget->{$widget}->loadConfigLanguageFile();
				$xml 	 = $widgetform->getXml();
				$form->setFields($xml, 'widgets');
			}
		}
		
		// get all plugin config files
		$plugins	 = $this->app->plugin->getList();
				
		foreach ( $plugins as $plugin ) {
			if ( $pluginform = $this->app->plugin->{$plugin}->getConfigForm() ) {
				$this->app->plugin->{$plugin}->loadConfigLanguageFile();
				$xml 	 = $pluginform->getXml();
				$form->setFields($xml, 'plugins');
			}
		}
		
		// fire booking formloaded event
		$this->app->event->dispatcher->fire(	
			$this->app->event->create('config:formprocessed')
						->addSubjects( array('form' => $form, 'data' => $data) ) 
		);
		
		
		// remove some basic stuff
		$form->removeField('bookzourl', 	'general');
		$form->removeField('accountname', 	'general');
		$form->removeField('password', 		'general');
		$form->removeField('cms', 			'general');
		
		// add some fields to the language options
		$newxml	  = $this->app->xml->create('new');
		
		$fieldset = $newxml->addChild('fieldset');
		$fieldset->addAttribute('name',  'general');

		$field	 = $fieldset->addChild('field');
		$field->addAttribute('type', 'bookzoiframeurl');
		$field->addAttribute('name', 'iframeurl');
		$field->addAttribute('label', 'CONFIG_FIELD_GENERAL_IFRAME_SEARCH_PAGE_LABEL');
		$field->addAttribute('description', 'CONFIG_FIELD_GENERAL_IFRAME_SEARCH_PAGE_DESC');
		$field->addAttribute('inlinelabel', true);
		
		$field	 = $fieldset->addChild('field');
		$field->addAttribute('type', 'select');
		$field->addAttribute('name', 'inlinesearch');
		$field->addAttribute('default', '1');
		$field->addAttribute('label', 'CONFIG_FIELD_GENERAL_IFRAME_INLINE_SEARCH_LABEL');
		$field->addAttribute('description', 'CONFIG_FIELD_GENERAL_IFRAME_INLINE_SEARCH_DESC');
		
		$option  = $field->addChild('<option>' . BText::_('OPTION_YES'));
		$option->addAttribute('value', '1');
		$option  = $field->addChild('<option>' . BText::_('OPTION_NO'));
		$option->addAttribute('value', '0');
		
		
		$field	 = $fieldset->addChild('field');
		$field->addAttribute('type', 'textarea');
		$field->addAttribute('name', 'iframescripts');
		$field->addAttribute('default', '');
		$field->addAttribute('rows', '8');
		$field->addAttribute('cols', '200');
		$field->addAttribute('label', 'CONFIG_FIELD_GENERAL_IFRAME_SCRIPTS_LABEL');
		$field->addAttribute('description', 'CONFIG_FIELD_GENERAL_IFRAME_SCRIPTS_DESC');

		$form->setFields($newxml, 'general', true);
		
		parent::preprocessForm($form, $data);
	}
	
	/**
	 * Method to determine the form paths.
	 *
	 * @return  void
	 * @since   12.2
	 */
	protected function addFormPaths()
	{
		$app = Bookzo::getInstance();
		
		// Load form and field paths
		BForm::addFormPath(BOOKZO_ROOT);
		BForm::addFieldPath(BOOKZO_ROOT . '/libraries/bookzo/fields');
		
		// Also load override paths
		$modelpaths = $app->path->getPaths('models', true);
		
		foreach ( $modelpaths as $modelpath ) {
			BForm::addFormPath($modelpath . '/admin/forms');
			BForm::addFieldPath($modelpath . '/admin/fields');
			BForm::addRulePath($modelpath . '/admin/rules');		
		}
	}
	
	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return  array    The default data is an empty array.
	 *
	 * @since   12.2
	 */
	protected function loadFormData()
	{
		// we try to load the config file
		return $this->app->config->toArray();
	}
	
}