<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BzAdapterJoomla extends BAdapter {
	
	/**
	 * Check for valid adapter
	 *
	 * We just see if joomla framework is set
	 * If not we try to load it ourself
	 *
	 * @params	 	none
	 * @return		boolean		true if valid, false otherwise
	 * @access		public
	 * @since 		1.0.0
	 */
	public function valid()
	{
		if ( !$return = defined('_JEXEC') ) 
		{
			$joomlaroot = dirname(BOOKZO_ROOT);
			
			if ( !defined('JPATH_BASE') && !defined('_JDEFINES') ) 
			{
				if ( file_exists($joomlaroot.'/includes/defines.php') && file_exists($joomlaroot . '/includes/framework.php') ) 
				{
					define('_JEXEC', 		1);
					define('JPATH_BASE', 	$joomlaroot);
					
					require_once($joomlaroot.'/includes/defines.php');
					require_once($joomlaroot.'/includes/framework.php');
	
					if ( class_exists('JFactory') ) {
						$application = JFactory::getApplication('site');
						$return 	 = true;
					}
				}
			}
		}
		
		return $return;
	}
	
	/**
	 * Let the CMS add a stylesheet from within bookzo
	 *
	 * @params	 	$path		the path to the file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addStyleSheet($path, $external = false, $addversion = true)
	{		
		if ( $external || $this->app->path->url($path) ) 
		{
			$url 	 = $external ? $path : $this->app->path->url($path);

			if ( $addversion && !$external ) {
				$url .= $this->app->file->getVersion($this->app->path->path($path));
			}
			
			JFactory::getDocument()->addStyleSheet($url);
		}
		
		return $this;
	}
	
	/**
	 * Let the CMS add a javascript file from within bookzo
	 *
	 * @params	 	$path		the path to the file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addScript($path, $external = false, $addversion = true)
	{	
		if ( $external || $this->app->path->url($path) ) 
		{
			$url 	 = $external ? $path : $this->app->path->url($path);

			if ( $addversion && !$external ) {
				$url .= $this->app->file->getVersion($this->app->path->path($path));
			}
			
			JFactory::getDocument()->addScript($url);
		}
		
		return $this;	
	}
	
	/**
	 * Let the CMS add a javascript string from within bookzo
	 *
	 * @params	 	$string		the javascript
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addScriptDeclaration($js)
	{		
		JFactory::getDocument()->addScriptDeclaration($js);
	}
	
	/**
	 * Let the CMS add jquery
	 * If CMS doesn't have jquery we could load a CDN jquery file
	 *
	 * @params	 	$ui		if true also load the jquery.ui file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function jQuery($ui = false)
	{		
		JHtml::_('jquery.framework', $ui);
	}
	
	/**
	 * Let the CMS determine the SEO url for the page requested
	 *
	 * @params	 	$link	the page we are trying to load
	 * @params		$xhtml	replace & for &amp;
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function route($link, $xhtml = true, $addbase = false)
	{
		$link 	= 'index.php?option=com_bookzo&'.$link;
		$return = JRoute::_($link, $xhtml);
		
		if ( $addbase ) {
			if ( strpos($return, BOOKZO_SITE_URL) === false ) {
				$return = BOOKZO_SITE_URL . $return;
				$return = str_replace('//', '/', $return);
				$return = str_replace(array('http:/', 'https:/'), array('http://', 'https://'), $return);
			}
		}
		
		// remove bookzolayer from url
		if ( strpos($return, '/bookzolayer') !== false ) {
			$return = str_replace('/bookzolayer', '', $return);
		}
		
		return $return;
	}
	
	/**
	 * Let the CMS redirect us to another page
	 *
	 * @params	 	$link	the page we are redirecting to
	 * @params		$status	the html page code. default = 303
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function redirect($link, $status = 303)
	{		
		return JFactory::getApplication()->redirect($link, $status);
	}
	
	/**
	 * Set a session value within the CMS
	 *
	 * @params	 	$name	the name of the value to set
	 * @params		$value	the value to set
	 * @return		bool	true if succesful
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionSet($name, $value = null, $namespace = 'bookzo')
	{
		return JFactory::getSession()->set($name, $value, $namespace);
	}
	
	/**
	 * See if the session has a value
	 *
	 * @params	 	$name		the name of the value to check
	 * @params		$namespace	an optional namespace within the session to search within
	 * @return		boolean		true if value exists
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionHas($name, $namespace = 'bookzo')
	{
		return JFactory::getSession()->has($name, $namespace);		
	}
	
	/**
	 * Get a value from the CMS session
	 *
	 * @params	 	$name		the name of the value to get
	 * @params		$default	the default value if not found
	 * @return		mixed		the value found
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionGet($name, $default = null, $namespace = 'bookzo')
	{
		return JFactory::getSession()->get($name, $default, $namespace);
	}
	
	/**
	 * Clear a value within the session
	 *
	 * @params	 	$name		the name of the value to remove
	 * @params		$namespace	an optional namespace within the session to search within
	 * @return		boolean		true if removed
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionClear($name, $namespace = 'bookzo')
	{
		return JFactory::getSession()->clear($name, $namespace);		
	}
	
	/**
	 * See if we have a new session
	 *
	 * @return		boolean		true if new
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionNew()
	{
		return JFactory::getSession()->isNew();		
	}
	
	/**
	 * Add a default path for Bookzo overrides
	 * In Joomla this would be the active template html dir
	 *
	 * @params	 	none		
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addPaths()
	{
		if ( JFactory::getApplication()->isAdmin() ) {
			$db 	= JFactory::getDBO();
			$query 	= $db->getQuery(true);
			$query->select('template');
			$query->from('#__template_styles');
			$query->where('client_id = 0');
			$query->where('home = 1');
			
			try {
				$template = $db->setQuery($query)->loadResult();
			}
			catch ( Exception $e ) {
				$template = false;
			}
			
			$namespaces = array('widgets');
		}
		else {
			$template 	= JFactory::getApplication()->getTemplate();
			$namespaces = $this->app->path->getNameSpaces();
			
			// for cron jobs we need to check if review system is active
			if ( JComponentHelper::isInstalled('com_review') && JComponentHelper::isEnabled('com_review') ) {
				$this->app->path->register( JPATH_SITE . '/plugins/system/bookzoreview/reviewsystem/', 'reviewsystem' );
				$this->app->loader->register('BookzoReviewJoomla', 'reviewsystem:joomla.php');
				$this->app->review->setType('joomla');
			}
			
		}
		
		if ( $template ) {
			$base	  	= JPATH_SITE.'/templates/'.$template.'/html/bookzo/';
			
			## NOTE - Do we need to add a check here if folder exists?
			foreach ( $namespaces as $namespace ) {
				$this->app->path->register($base.$namespace, 	$namespace);
			}
		}
		
		
	}
	
	public function sessionDestroy()
	{
		return JFactory::getSession()->destroy();	
	}
	
	/**
	 * Get current CMS language tag
	 *
	 * @return		string		the tag
	 * @access		public
	 * @since 		1.0.0
	 */
	public function getLanguage()
	{
		return JFactory::getLanguage()->getTag();
	}
	
	/**
	 * See is we are in admin site of CMS
	 *
	 * @return		boolean		true if in admin site
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isAdmin()
	{
		return JFactory::getApplication()->getName() != 'site';
	}
	
	/**
	 * Are we in CMS homepage
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isHomepage()
	{
		$menu = JFactory::getApplication()->getMenu('site');

		return $menu->getDefault(JFactory::getLanguage()->getTag()) == $menu->getActive();
	}
	
	/**
	 * Check to see if we are on a bookzopage of the CMS
	 *
	 * @return		boolean		true if on bookzopage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isBookzoPage()
	{
		return $this->app->input->get('option') == 'com_bookzo';
	}
	
	/**
	 * Add metadate to the CMS
	 *
	 * @param		string	$type	metadata type
	 * @param		string	$value	the value to set for the type
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function setMetaData($type, $value)
	{
		switch ( $type )
		{
			case 'description' :
				JFactory::getDocument()->setDescription($value);
				break;
			case 'title' : 
				JFactory::getDocument()->setTitle($value);
				break;
			default: 
				JFactory::getDocument()->setMetaData($type, $value);
				break;
				
		}
	}
	
	/**
	 * Hook to fire on after booking
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function afterBooking( $booking )
	{
		return;
	}
	
	/**
	 * Hook to fire on after bookzoload
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function bookzoInit() {
		return;
	}
}