<?php
/**
 * @package       Bz
 * @author        Invenda http://www.invenda.nl
 * @copyright     Copyright (C) Invenda.nl
 * @license       http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call
 * for all child classes
 *
 * @subpackage    framework.classes
 * @since         1.0.0
 *
 */
class BzAdapterModx extends BAdapter {

	/** @var modX */
	private $modx = null;

	static public $jsfiles = 0;

	static public $cssfiles = 0;

	/**
	 * Check for valid adapter
	 *
	 * We just see if modx framework is set
	 * If not we try to load it ourself
	 *
	 * @params        none
	 *
	 * @return        boolean        true if valid, false otherwise
	 * @access        public
	 * @since         1.0.0
	 */
	public function valid() {
		global $modx;

		if (!isset($_SESSION)){
			session_start();
		}

		if (!defined('MODX_CORE_PATH')) {
			if (!@include(dirname(dirname(__DIR__)).'/config.core.php')) {
				return false;
			}
			if (!defined('MODX_CORE_PATH')) {
				define('MODX_CORE_PATH', dirname(dirname(__DIR__)).'/core/');
			}
			if (!@include_once(MODX_CORE_PATH."model/modx/modx.class.php")) {
				return false;
			}
			$modx = new modX();
		}

		if (!isset($modx)) {
			return false;
		}
		$this->modx = $modx;

		return true;
	}

	/**
	 * Let the CMS add a stylesheet from within bookzo
	 *
	 * @params        $path        the path to the file
	 * @return        void
	 * @access        public
	 * @since         1.0.0
	 */
	public function addStyleSheet($path, $external = false, $addversion = true) {
		if ($this->app->input->get('format') != 'ajax') {
			if ($external || ($path = $this->app->path->url($path))) {
				$this->modx->regClientCSS($path);
				self::$cssfiles++;
			}
		}

		return $this;
	}

	/**
	 * Let the CMS add a javascript file from within bookzo
	 *
	 * @params        $path        the path to the file
	 * @return        void
	 * @access        public
	 * @since         1.0.0
	 */
	public function addScript($path, $external = false, $addversion = true) {
		if ($this->app->input->get('format') != 'ajax') {
			if ($external || ($path = $this->app->path->url($path))) {
				$this->modx->regClientScript($path);
				self::$jsfiles++;
			}
		}

		return $this;
	}

	/**
	 * Let the CMS add a javascript string from within bookzo
	 *
	 * @params        $string        the javascript
	 * @return        void
	 * @access        public
	 * @since         1.0.0
	 */
	public function addScriptDeclaration($js) {
		if ($this->app->input->get('format') != 'ajax') {
			$this->modx->regClientStartupHTMLBlock('<script type="text/javascript">'.$js.'</script>');
		}
	}

	/**
	 * Let the CMS add jquery
	 * If CMS doesn't have jquery we could load a CDN jquery file
	 *
	 * @params        $ui        if true also load the jquery.ui file
	 * @return        void
	 * @access        public
	 * @since         1.0.0
	 */
	public function jQuery($ui = false) {
		if ($this->app->input->get('format') != 'ajax') {

			//			wp_enqueue_script('jquery');
		}
	}

	/**
	 * Let the CMS determine the SEO url for the page requested
	 *
	 * @params        $link    the page we are trying to load
	 * @params        $xhtml    replace & for &amp;
	 * @return        string
	 * @access        public
	 * @since         1.0.0
	 */
	public function route($link, $xhtml = true) {
		
		if (!empty($link)) {
			parse_str($link, $uri);
			if (!empty($uri['layout'])) {
				$layout = $uri['layout'];

				if (!empty($uri['id'])) {
					$id = explode(":", $uri['id']);
					return '/'.$layout.'/'.$id[1].'-'.$uri['groupid'].'-'.$id[0].'.html';
				}

				switch($layout){
					case "discounts":
						$layout = 'last-minutes';
						break;
					case "results":
						$layout = 'zoekresultaten';
						break;
				}

				return '/'.$layout.'.html?'.http_build_query($uri);
			}
		}
		return '/book.html?'.$link;

	}

	/**
	 * Let the CMS redirect us to another page
	 *
	 * @params        $link    the page we are redirecting to
	 * @params        $status    the html page code. default = 303
	 * @return        void
	 * @access        public
	 * @since         1.0.0
	 */
	public function redirect($link, $status = 303) {
		if (!headers_sent()) {
			$this->modx->sendRedirect($link, null, $status);
			exit;
		}
		else {
			$this->addScriptDeclaration('window.location="'.$link.'"');
		}
	}

	/**
	 * Set a session value within the CMS
	 *
	 * @params        $name    the name of the value to set
	 * @params        $value    the value to set
	 * @return        bool    true if succesful
	 * @access        public
	 * @since         1.0.0
	 */
	public function sessionSet($name, $value = null, $namespace = 'bookzo') {
		$_SESSION[$namespace][$name] = $value;
		if (isset($_SESSION[$namespace][$name])) {
			return true;
		}

		return false;
	}

	/**
	 * See if the session has a value
	 *
	 * @params        $name        the name of the value to check
	 * @params        $namespace    an optional namespace within the session to search within
	 * @return        boolean        true if value exists
	 * @access        public
	 * @since         1.0.0
	 */
	public function sessionHas($name, $namespace = 'bookzo') {
		if (!isset($_SESSION[$namespace][$name])) {
			return false;
		}

		return true;
	}

	/**
	 * Get a value from the CMS session
	 *
	 * @params        $name        the name of the value to get
	 * @params        $default    the default value if not found
	 * @return        mixed        the value found
	 * @access        public
	 * @since         1.0.0
	 */
	public function sessionGet($name, $default = null, $namespace = 'bookzo') {
		if (!isset($_SESSION[$namespace][$name])) {
			return $default;
		}

		return $_SESSION[$namespace][$name];
	}

	/**
	 * Clear a value within the session
	 *
	 * @params        $name        the name of the value to remove
	 * @params        $namespace    an optional namespace within the session to search within
	 * @return        boolean        true if removed
	 * @access        public
	 * @since         1.0.0
	 */
	public function sessionClear($name, $namespace = 'bookzo') {
		$_SESSION['bookzo'][$name] = null;

		return false;
	}

	/**
	 * See if we have a new session
	 *
	 * @return        boolean        true if new
	 * @access        public
	 * @since         1.0.0
	 */
	public function sessionNew() {
//		if(count($_SESSION['bookzo']) === 0){
//			return true;
//		}
		return false;
	}

	/**
	 * Add a default path for Bookzo overrides
	 * In Joomla this would be the active template html dir
	 *
	 * @params        none
	 *
	 * @return        void
	 * @access        public
	 * @since         1.0.0
	 */
	public function addPaths() {
		$base = dirname(MODX_CORE_PATH).'/public_html/bookzolayer/adapters/modx/';
		$namespaces = $this->app->path->getNameSpaces();
		foreach($namespaces as $namespace) {
			switch($namespace) {
				case "app":
				case "bookzo":
				case "helpers":
					$namespace = 'libraries/'.$namespace;
					break;
			}
			$this->app->path->register($base.$namespace, $namespace);
		}
	}

	public function sessionDestroy() {
		$_SESSION['bookzo'] = array();

		return true;
	}

	/**
	 * Get current CMS language tag
	 *
	 * @return		string		the tag
	 * @access		public
	 * @since 		1.0.0
	 */
	public function getLanguage() {
		$contextkey = $this->modx->context->key;
		if($contextkey == "de"){
			return "de-DE";
		}else{
			return "nl-NL";
		}
	}

	/**
	 * See is we are in admin site of CMS
	 *
	 * @return		boolean		true if in admin site
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isAdmin() {
		$url = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';

		return strpos('/bzconfig/bzconfig.php', $url) !== false;

	}

	/**
	 * Add metadate to the CMS
	 *
	 * @param		string	$type	metadata type
	 * @param		string	$value	the value to set for the type
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function setMetaData($type, $value) {
		switch($type){
			case "title":
				$this->modx->setPlaceholder('bookzo_title', $value);
				break;
			default:

				break;
		}


		$this->modx->setPlaceholder('meta_' . $type, $value);
	}
	
	/**
	 * Hook to fire on after booking
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function afterBooking( $booking )
	{
		if ( $booking->get('remarks.newsletter', 0) == 1 ) {
			$name        = $booking->get('guest.firstname');
			$email        = $booking->get('guest.email');

			$url = 'http://eds2.mailcamp.nl/form.php?form=55';
			$fields = array(
				'email' => urlencode($email),
				'CustomFields[2]' => urlencode($name),
				'format' => 'h'
			);

			//url-ify the data for the POST
			$fields_string = '';
			foreach($fields as $key=>$value) {
				$fields_string .= $key.'='.$value.'&';
			}
			rtrim($fields_string, '&');

			$ch = curl_init();
			curl_setopt($ch,CURLOPT_URL, $url);
			curl_setopt($ch,CURLOPT_POST, count($fields));
			curl_setopt($ch,CURLOPT_POSTFIELDS, $fields_string);
			$result = curl_exec($ch);
			curl_close($ch);
		}
		return;
	}
	
	/**
	 * Are we in CMS homepage
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isHomepage()
	{
		return false;
	}
	
	/**
	 * Check to see if we are on a bookzopage of the CMS
	 *
	 * @return		boolean		true if on bookzopage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isBookzoPage()
	{
		return false;
	}
	
	/**
	 * Hook to fire on after bookzoload
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function bookzoInit() {
		return;
	}
}