<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BzAdapterWordpress extends BAdapter {
	
	static public $jsfiles = 0;
	
	static public $cssfiles = 0;
	
	static public $customjs = array();
	
	static public $customheaders = array();
	
	static public $headersadded = false;
	
	static public $actionsadded = false;
	
	
	/**
	 * Check for valid adapter
	 *
	 * We just see if joomla framework is set
	 * If not we try to load it ourself
	 *
	 * @params	 	none
	 * @return		boolean		true if valid, false otherwise
	 * @access		public
	 * @since 		1.0.0
	 */
	public function valid()
	{
		if ( !$return = defined('ABSPATH') ) 
		{
			$wordpressroot = dirname(BOOKZO_ROOT);
			
			define('WP_USE_THEMES', true);
			
			if (file_exists($wordpressroot . '/wp-load.php') ) {
				require( $wordpressroot . '/wp-load.php' );
			}
			
			$return = defined('ABSPATH');
		}
		
		return $return;
	}
	
	/**
	 * Let the CMS add a stylesheet from within bookzo
	 *
	 * @params	 	$path		the path to the file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addStyleSheet($path, $external = false, $addversion = true)
	{
		if ( $this->app->input->get('format') != 'ajax' && $this->isBookzoPage() ) 
		{	
			if ( $external || ($path = $this->app->path->url($path)) ) {
				
				self::$cssfiles++;
				
				wp_enqueue_style('bookzo-style' . self::$cssfiles , $path);
			}
		}
		
		return $this;
	}
	
	/**
	 * Let the CMS add a javascript file from within bookzo
	 *
	 * @params	 	$path		the path to the file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addScript($path, $external = false, $addversion = true)
	{
		if ( $this->app->input->get('format') != 'ajax' && $this->isBookzoPage() ) 
		{
			if ( $external || ($path = $this->app->path->url($path)) ) {
				
				self::$jsfiles++;
				
				wp_register_script( 'bookzo-script' . self::$jsfiles , $path );
				wp_enqueue_script( 'bookzo-script' . self::$jsfiles, $path );
			}
		}
		
		return $this;	
	}
	
	/**
	 * Let the CMS add a javascript string from within bookzo
	 *
	 * @params	 	$string		the javascript
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addScriptDeclaration($js)
	{
		if ( $this->canAdd(true) ) 
		{
			self::$customjs[] = $js;
			
			if ( !self::$actionsadded ) {
				self::$actionsadded = true;
				add_action('admin_head', 	array( $this, 'addWpCustomHeaders' ));
				add_action('wp_head', 		array( $this, 'addWpCustomHeaders' ));
			}
		}
	}
	
	public function addWpCustomHeaders()
	{
		$parts = array();
		
		foreach ( self::$customheaders as $header )
		{
			switch ( $header->type ) {
				default:
					$parts[] = '<meta name="'.$header->type.'" value="'.$header->value.'" />';
					break;
				case 'title':
					$parts[] = '<title>'.$header->value.'</title>';
					break;
			}
		}
		
		foreach ( self::$customjs as $customjs )
		{
			$parts[] = '<script type="text/javascript">'.$customjs.'</script>';
		}
		
		echo implode("\n", $parts);
	}
	
	/**
	 * Let the CMS add jquery
	 * If CMS doesn't have jquery we could load a CDN jquery file
	 *
	 * @params	 	$ui		if true also load the jquery.ui file
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function jQuery($ui = false)
	{
		if ( $this->app->input->get('format') != 'ajax' && $this->isBookzoPage() ) 
		{	
			wp_enqueue_script('jquery');
		}
	}
	
	/**
	 * Let the CMS determine the SEO url for the page requested
	 *
	 * @params	 	$link	the page we are trying to load
	 * @params		$xhtml	replace & for &amp;
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function route($link, $xhtml = true, $addbase = false)
	{
		do_action('bookzo_route', $link, $xhtml, $return = new stdClass() );
		
		$return = isset($return->link) ? $return->link : '';
		
		if ( $addbase ) {
			if ( strpos($return, BOOKZO_SITE_URL) === false ) {
				$return = BOOKZO_SITE_URL . $return;
				$return = str_replace('//', '/', $return);
				$return = str_replace(array('http:/', 'https:/'), array('http://', 'https://'), $return);
			}
		}
		
		return $return;
	}
	
	/**
	 * Let the CMS redirect us to another page
	 *
	 * @params	 	$link	the page we are redirecting to
	 * @params		$status	the html page code. default = 303
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function redirect($link, $status = 302)
	{	
		## NOTE - Wordpress outputs headers before try to redirect by js
		if ( !headers_sent() ) {
			wp_redirect($link, $status);
			exit;
		}
		else {
			$this->addScriptDeclaration('window.location="'.$link.'"');
		}
	}
	
	/**
	 * Set a session value within the CMS
	 *
	 * @params	 	$name	the name of the value to set
	 * @params		$value	the value to set
	 * @return		bool	true if succesful
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionSet($name, $value = null, $namespace = 'bookzo')
	{
		do_action('bookzo_session_set', $name, $value, $namespace, $return = new stdClass() );

		if ( isset($return->value) ) {
			return (bool) $return->value;			
		}
		
		return false;
	}
	
	/**
	 * See if the session has a value
	 *
	 * @params	 	$name		the name of the value to check
	 * @params		$namespace	an optional namespace within the session to search within
	 * @return		boolean		true if value exists
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionHas($name, $namespace = 'bookzo')
	{
		do_action('bookzo_session_has', $name, $namespace, $return = new stdClass() );

		if ( isset($return->value) ) {
			return $return->value;			
		}
		
		return false;
	}
	
	/**
	 * Get a value from the CMS session
	 *
	 * @params	 	$name		the name of the value to get
	 * @params		$default	the default value if not found
	 * @return		mixed		the value found
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionGet($name, $default = null, $namespace = 'bookzo')
	{
		do_action('bookzo_session_get', $name, $default, $namespace, $return = new stdClass() );

		if ( isset($return->value) ) {
			return $return->value;			
		}
		
		return $default;
	}
	
	/**
	 * Clear a value within the session
	 *
	 * @params	 	$name		the name of the value to remove
	 * @params		$namespace	an optional namespace within the session to search within
	 * @return		boolean		true if removed
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionClear($name, $namespace = 'bookzo')
	{
		do_action('bookzo_session_clear', $name, $namespace, $return = new stdClass() );

		if ( isset($return->value) ) {
			return $return->value;			
		}
		
		return false;		
	}
	
	/**
	 * See if we have a new session
	 *
	 * @return		boolean		true if new
	 * @access		public
	 * @since 		1.0.0
	 */
	public function sessionNew()
	{
		do_action('bookzo_session_new', $return = new stdClass() );

		if ( isset($return->value) ) {
			return $return->value;			
		}
		
		return false;	
	}
	
	public function sessionDestroy()
	{
		do_action('bookzo_session_destroy', $return = new stdClass() );

		if ( isset($return->value) ) {
			return $return->value;			
		}
		
		return false;		
	}
	
	/**
	 * Add a default path for Bookzo overrides
	 * In Joomla this would be the active template html dir
	 *
	 * @params	 	none		
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function addPaths()
	{
		if ( is_admin() ) 
		{
			$namespaces = array('widgets');
		}
		else {
			$namespaces = $this->app->path->getNameSpaces();
		}
		
		$path = get_template_directory();
		$base = $path.'/bookzo/';
		
		foreach ( $namespaces as $namespace ) {
			$this->app->path->register($base.$namespace, $namespace);
		}
	}
	
	/**
	 * Get current CMS language tag
	 *
	 * @return		string		the tag
	 * @access		public
	 * @since 		1.0.0
	 */
	public function getLanguage()
	{
		$lang = substr(get_bloginfo( 'language' ), 0, 2);
		
		return ( $this->isAdmin() || empty($lang) ? 'nl' : strtolower($lang) );
	}
	
	/**
	 * See is we are in admin site of CMS
	 *
	 * @return		boolean		true if in admin site
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isAdmin()
	{
		return is_admin();
	}
	
	/**
	 * Are we in CMS homepage
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isHomepage()
	{
		$menu = JFactory::getApplication()->getMenu('site');
		
		return $menu->getDefault() == $menu->getActive();
	}
	
/**
	 * Add metadate to the CMS
	 *
	 * @param		string	$type	metadata type
	 * @param		string	$value	the value to set for the type
	 * @return		void
	 * @access		public
	 * @since 		1.0.0
	 */
	public function setMetaData($type, $value)
	{
		if ( $this->canAdd() ) 
		{
			$header 				= new stdClass();
			$header->type 			= $type;
			$header->value 			= $value;
			
			self::$customheaders[] 	= $header;
			
			if ( !self::$actionsadded ) {
				self::$actionsadded = true;
				add_action('admin_head', 	array( $this, 'addWpCustomHeaders' ));
				add_action('wp_head', 		array( $this, 'addWpCustomHeaders' ));
			}
		}
	}
	
	/**
	 * Hook to fire on after booking
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function afterBooking( $booking )
	{
		return;
	}
	
	/**
	 * Check to see if we are on a bookzopage of the CMS
	 *
	 * @return		boolean		true if on bookzopage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function isBookzoPage()
	{
		/*
		$page 		= $this->app->input->get('page');
		$post 		= get_post( null );
		$posttype	= $post ? $post->post_type : '';
		
		
		if ( (!$this->isAdmin() && in_array($posttype, array('bookzo-object', 'bookzo-group', 'bookzo-page'))) || $page == 'bookzo' ) {
			return true;
		}
		
		return false;
		*/		
		
		$page 		= $this->app->input->get('page');
		
		if ( !$this->isAdmin() || $page == 'bookzo' ) {
			return true;
		}
		
		return false;
	}
	
	
	
	public function canAdd($admin = false)
	{
		return ($admin || (!$admin && !self::isAdmin())) 
				&& $this->app->input->get('format') != 'ajax' 
				&& (!defined( 'DOING_AJAX' ) || !DOING_AJAX ) 
				&& $this->isBookzoPage();
	}
	
	/**
	 * Hook to fire on after bookzoload
	 *
	 * @return		boolean		true if on homepage
	 * @access		public
	 * @since 		1.0.0
	 */
	public function bookzoInit() {
		return;
	}
	
}