(function(core) {
    if (typeof define == "function" && define.amd) {
        define("bzkit", function() {
            var bzkit = window.BZkit || core(window, window.jQuery, window.document);
            bzkit.load = function(res, req, onload, config) {
                var resources = res.split(","),
                    load = [],
                    i, base = (config.config && config.config.bzkit && config.config.bzkit.base ? config.config.bzkit.base : "").replace(/\/+$/g, "");
                if (!base) {
                    throw new Error("Please define base path to BZkit in the requirejs config.")
                }
                for (i = 0; i < resources.length; i += 1) {
                    var resource = resources[i].replace(/\./g, "/");
                    load.push(base + "/components/" + resource)
                }
                req(load, function() {
                    onload(bzkit)
                })
            };
            return bzkit
        })
    }
    if (!window.jQuery) {
        throw new Error("BZkit requires jQuery")
    }
    if (window && window.jQuery) {
        core(window, window.jQuery, window.document)
    }
})(function(global, $, doc) {
    "use strict";
    var BZ = {},
        _BZ = window.BZkit;
    BZ.version = "2.17.0";
    BZ.noConflict = function() {
        if (_BZ) {
            window.BZkit = _BZ;
            $.BZkit = _BZ;
            $.fn.uk = _BZ.fn
        }
        return BZ
    };
    BZ.prefix = function(str) {
        return str
    };
    BZ.$ = $;
    BZ.$doc = BZ.$(document);
    BZ.$win = BZ.$(window);
    BZ.$html = BZ.$("html");
    BZ.fn = function(command, options) {
        var args = arguments,
            cmd = command.match(/^([a-z\-]+)(?:\.([a-z]+))?/i),
            component = cmd[1],
            method = cmd[2];
        if (!BZ[component]) {
            $.error("BZkit component [" + component + "] does not exist.");
            return this
        }
        return this.each(function() {
            var $this = $(this),
                data = $this.data(component);
            if (!data) $this.data(component, data = BZ[component](this, method ? undefined : options));
            if (method) data[method].apply(data, Array.prototype.slice.call(args, 1))
        })
    };
    BZ.support = {};
    BZ.support.transition = function() {
        var transitionEnd = function() {
            var element = doc.body || doc.documentElement,
                transEndEventNames = {
                    WebkitTransition: "webkitTransitionEnd",
                    MozTransition: "transitionend",
                    OTransition: "oTransitionEnd otransitionend",
                    transition: "transitionend"
                },
                name;
            for (name in transEndEventNames) {
                if (element.style[name] !== undefined) return transEndEventNames[name]
            }
        }();
        return transitionEnd && {
            end: transitionEnd
        }
    }();
    BZ.support.animation = function() {
        var animationEnd = function() {
            var element = doc.body || doc.documentElement,
                animEndEventNames = {
                    WebkitAnimation: "webkitAnimationEnd",
                    MozAnimation: "animationend",
                    OAnimation: "oAnimationEnd oanimationend",
                    animation: "animationend"
                },
                name;
            for (name in animEndEventNames) {
                if (element.style[name] !== undefined) return animEndEventNames[name]
            }
        }();
        return animationEnd && {
            end: animationEnd
        }
    }();
    BZ.support.requestAnimationFrame = window.requestAnimationFrame || window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame || window.msRequestAnimationFrame || window.oRequestAnimationFrame || function(callback) {
        setTimeout(callback, 1e3 / 60)
    };
    BZ.support.touch = "ontouchstart" in window && navigator.userAgent.toLowerCase().match(/mobile|tablet/) || global.DocumentTouch && document instanceof global.DocumentTouch || global.navigator.msPointerEnabled && global.navigator.msMaxTouchPoints > 0 || global.navigator.pointerEnabled && global.navigator.maxTouchPoints > 0 || false;
    BZ.support.mutationobserver = global.MutationObserver || global.WebKitMutationObserver || null;
    BZ.Utils = {};
    BZ.Utils.str2json = function(str, notevil) {
        try {
            if (notevil) {
                return JSON.parse(str.replace(/([\$\w]+)\s*:/g, function(_, $1) {
                    return '"' + $1 + '":'
                }).replace(/'([^']+)'/g, function(_, $1) {
                    return '"' + $1 + '"'
                }))
            } else {
                return new Function("", "var json = " + str + "; return JSON.parse(JSON.stringify(json));")()
            }
        } catch (e) {
            return false
        }
    };
    BZ.Utils.debounce = function(func, wait, immediate) {
        var timeout;
        return function() {
            var context = this,
                args = arguments;
            var later = function() {
                timeout = null;
                if (!immediate) func.apply(context, args)
            };
            var callNow = immediate && !timeout;
            clearTimeout(timeout);
            timeout = setTimeout(later, wait);
            if (callNow) func.apply(context, args)
        }
    };
    BZ.Utils.removeCssRules = function(selectorRegEx) {
        var idx, idxs, stylesheet, _i, _j, _k, _len, _len1, _len2, _ref;
        if (!selectorRegEx) return;
        setTimeout(function() {
            try {
                _ref = document.styleSheets;
                for (_i = 0, _len = _ref.length; _i < _len; _i++) {
                    stylesheet = _ref[_i];
                    idxs = [];
                    stylesheet.cssRules = stylesheet.cssRules;
                    for (idx = _j = 0, _len1 = stylesheet.cssRules.length; _j < _len1; idx = ++_j) {
                        if (stylesheet.cssRules[idx].type === CSSRule.STYLE_RULE && selectorRegEx.test(stylesheet.cssRules[idx].selectorText)) {
                            idxs.unshift(idx)
                        }
                    }
                    for (_k = 0, _len2 = idxs.length; _k < _len2; _k++) {
                        stylesheet.deleteRule(idxs[_k])
                    }
                }
            } catch (_error) {}
        }, 0)
    };
    BZ.Utils.isInView = function(element, options) {
        var $element = $(element);
        if (!$element.is(":visible")) {
            return false
        }
        var window_left = BZ.$win.scrollLeft(),
            window_top = BZ.$win.scrollTop(),
            offset = $element.offset(),
            left = offset.left,
            top = offset.top;
        options = $.extend({
            topoffset: 0,
            leftoffset: 0
        }, options);
        if (top + $element.height() >= window_top && top - options.topoffset <= window_top + BZ.$win.height() && left + $element.width() >= window_left && left - options.leftoffset <= window_left + BZ.$win.width()) {
            return true
        } else {
            return false
        }
    };
    BZ.Utils.checkDisplay = function(context, initanimation) {
        var elements = BZ.$("[data-bz-margin], [data-bz-grid-match], [data-bz-grid-margin], [data-bz-check-display]", context || document),
            animated;
        if (context && !elements.length) {
            elements = $(context)
        } 
        elements.trigger("display.bz.check");
        if (initanimation) {
            if (typeof initanimation != "string") {
                initanimation = '[class*="bz-animation-"]'
            }
            elements.find(initanimation).each(function() {
                var ele = BZ.$(this),
                    cls = ele.attr("class"),
                    anim = cls.match(/bz\-animation\-(.+)/);
                ele.removeClass(anim[0]).width();
                ele.addClass(anim[0])
            })
        }
        return elements
    };
    BZ.Utils.options = function(string) {
        if ($.isPlainObject(string)) return string;
        var start = string ? string.indexOf("{") : -1,
            options = {};
        if (start != -1) {
            try {
                options = BZ.Utils.str2json(string.substr(start))
            } catch (e) {}
        }
        return options
    };
    BZ.Utils.animate = function(element, cls) {
        var d = $.Deferred();
        element = BZ.$(element);
        cls = cls;
        element.css("display", "none").addClass(cls).one(BZ.support.animation.end, function() {
            element.removeClass(cls);
            d.resolve()
        }).width();
        element.css("display", "");
        return d.promise()
    };
    BZ.Utils.uid = function(prefix) {
        return (prefix || "id") + (new Date).getTime() + "RAND" + Math.ceil(Math.random() * 1e5)
    };
    BZ.Utils.template = function(str, data) {
        var tokens = str.replace(/\n/g, "\\n").replace(/\{\{\{\s*(.+?)\s*\}\}\}/g, "{{!$1}}").split(/(\{\{\s*(.+?)\s*\}\})/g),
            i = 0,
            toc, cmd, prop, val, fn, output = [],
            openblocks = 0;
        while (i < tokens.length) {
            toc = tokens[i];
            if (toc.match(/\{\{\s*(.+?)\s*\}\}/)) {
                i = i + 1;
                toc = tokens[i];
                cmd = toc[0];
                prop = toc.substring(toc.match(/^(\^|\#|\!|\~|\:)/) ? 1 : 0);
                switch (cmd) {
                    case "~":
                        output.push("for(var $i=0;$i<" + prop + ".length;$i++) { var $item = " + prop + "[$i];");
                        openblocks++;
                        break;
                    case ":":
                        output.push("for(var $key in " + prop + ") { var $val = " + prop + "[$key];");
                        openblocks++;
                        break;
                    case "#":
                        output.push("if(" + prop + ") {");
                        openblocks++;
                        break;
                    case "^":
                        output.push("if(!" + prop + ") {");
                        openblocks++;
                        break;
                    case "/":
                        output.push("}");
                        openblocks--;
                        break;
                    case "!":
                        output.push("__ret.push(" + prop + ");");
                        break;
                    default:
                        output.push("__ret.push(escape(" + prop + "));");
                        break
                }
            } else {
                output.push("__ret.push('" + toc.replace(/\'/g, "\\'") + "');")
            }
            i = i + 1
        }
        fn = new Function("$data", ["var __ret = [];", "try {", "with($data){", !openblocks ? output.join("") : '__ret = ["Not all blocks are closed correctly."]', "};", "}catch(e){__ret = [e.message];}", 'return __ret.join("").replace(/\\n\\n/g, "\\n");', "function escape(html) { return String(html).replace(/&/g, '&amp;').replace(/\"/g, '&quot;').replace(/</g, '&lt;').replace(/>/g, '&gt;');}"].join("\n"));
        return data ? fn(data) : fn
    };
    BZ.Utils.events = {};
    BZ.Utils.events.click = BZ.support.touch ? "tap" : "click";
    window.BZkit = BZ;
    $.BZkit = BZ;
    $.fn.uk = BZ.fn;
    BZ.langdirection = BZ.$html.attr("dir") == "rtl" ? "right" : "left";
    BZ.components = {};
    BZ.component = function(name, def) {
        var fn = function(element, options) {
            var $this = this;
            this.BZkit = BZ;
            this.element = element ? BZ.$(element) : null;
            this.options = $.extend(true, {}, this.defaults, options);
            this.plugins = {};
            if (this.element) {
                this.element.data(name, this)
            }
            this.init();


            (this.options.plugins.length ? this.options.plugins : Object.keys(fn.plugins)).forEach(function(plugin) {
                if (fn.plugins[plugin].init) {
                    fn.plugins[plugin].init($this);
                    $this.plugins[plugin] = true
                }
            });
            this.trigger("init.bz.component", [name, this]);
            return this
        };
        fn.plugins = {};
        $.extend(true, fn.prototype, {
            defaults: {
                plugins: []
            },
            boot: function() {},
            init: function() {},
            on: function(a1, a2, a3) {
                return BZ.$(this.element || this).on(a1, a2, a3)
            },
            one: function(a1, a2, a3) {
                return BZ.$(this.element || this).one(a1, a2, a3)
            },
            off: function(evt) {
                return BZ.$(this.element || this).off(evt)
            },
            trigger: function(evt, params) {
                return BZ.$(this.element || this).trigger(evt, params)
            },
            find: function(selector) {
                return BZ.$(this.element ? this.element : []).find(selector)
            },
            proxy: function(obj, methods) {
                var $this = this;
                methods.split(" ").forEach(function(method) {
                    if (!$this[method]) $this[method] = function() {
                        return obj[method].apply(obj, arguments)
                    }
                })
            },
            mixin: function(obj, methods) {
                var $this = this;
                methods.split(" ").forEach(function(method) {
                    if (!$this[method]) $this[method] = obj[method].bind($this)
                })
            },
            option: function() {
                if (arguments.length == 1) {
                    return this.options[arguments[0]] || undefined
                } else if (arguments.length == 2) {
                    this.options[arguments[0]] = arguments[1]
                }
            }
        }, def);
        this.components[name] = fn;
        this[name] = function() {
            var element, options;
            if (arguments.length) {
                switch (arguments.length) {
                    case 1:
                        if (typeof arguments[0] === "string" || arguments[0].nodeType || arguments[0] instanceof jQuery) {
                            element = $(arguments[0])
                        } else {
                            options = arguments[0]
                        }
                        break;
                    case 2:
                        element = $(arguments[0]);
                        options = arguments[1];
                        break
                }
            }
            if (element && element.data(name)) {
                return element.data(name)
            }
            return new BZ.components[name](element, options)
        };
        if (BZ.domready) {
            BZ.component.boot(name)
        }
        return fn
    };
    BZ.plugin = function(component, name, def) {
        this.components[component].plugins[name] = def
    };
    BZ.component.boot = function(name) {
        if (BZ.components[name].prototype && BZ.components[name].prototype.boot && !BZ.components[name].booted) {
            BZ.components[name].prototype.boot.apply(BZ, []);
            BZ.components[name].booted = true
        }
    };
    BZ.component.bootComponents = function() {
        for (var component in BZ.components) {
            BZ.component.boot(component)
        }
    };
    BZ.domObservers = [];
    BZ.domready = false;
    BZ.ready = function(fn) {
        BZ.domObservers.push(fn);
        if (BZ.domready) {
            fn(document)
        }
    };
    BZ.on = function(a1, a2, a3) {
        if (a1 && a1.indexOf("ready.bz.dom") > -1 && BZ.domready) {
            a2.apply(BZ.$doc)
        }
        return BZ.$doc.on(a1, a2, a3)
    };
    BZ.one = function(a1, a2, a3) {
        if (a1 && a1.indexOf("ready.bz.dom") > -1 && BZ.domready) {
            a2.apply(BZ.$doc);
            return BZ.$doc
        }
        return BZ.$doc.one(a1, a2, a3)
    };
    BZ.trigger = function(evt, params) {
        return BZ.$doc.trigger(evt, params)
    };
    BZ.domObserve = function(selector, fn) {
        if (!BZ.support.mutationobserver) return;
        fn = fn || function() {};
        BZ.$(selector).each(function() {
            var element = this,
                $element = BZ.$(element);
            if ($element.data("observer")) {
                return
            }
            try {
                var observer = new BZ.support.mutationobserver(BZ.Utils.debounce(function(mutations) {
                    fn.apply(element, []);
                    $element.trigger("changed.bz.dom")
                }, 50));
                observer.observe(element, {
                    childList: true,
                    subtree: true
                });
                $element.data("observer", observer)
            } catch (e) {}
        })
    };
    BZ.on("domready.bz.dom", function() {
        BZ.domObservers.forEach(function(fn) {
            fn(document)
        });
        if (BZ.domready) BZ.Utils.checkDisplay(document)
    });
    $(function() {
        BZ.$body = BZ.$("body");
        BZ.ready(function(context) {
            BZ.domObserve("[data-bz-observe]")
        });
        BZ.on("changed.bz.dom", function(e) {
            var ele = e.target;
            BZ.domObservers.forEach(function(fn) {
                fn(ele)
            });
            BZ.Utils.checkDisplay(ele)
        });
        BZ.trigger("beforeready.bz.dom");
        BZ.component.bootComponents();
        setInterval(function() {
            var memory = {
                    x: window.pageXOffset,
                    y: window.pageYOffset
                },
                dir;
            var fn = function() {
                if (memory.x != window.pageXOffset || memory.y != window.pageYOffset) {
                    dir = {
                        x: 0,
                        y: 0
                    };
                    if (window.pageXOffset != memory.x) dir.x = window.pageXOffset > memory.x ? 1 : -1;
                    if (window.pageYOffset != memory.y) dir.y = window.pageYOffset > memory.y ? 1 : -1;
                    memory = {
                        dir: dir,
                        x: window.pageXOffset,
                        y: window.pageYOffset
                    };
                    BZ.$doc.trigger("scrolling.bz.document", [memory])
                }
            };
            if (BZ.support.touch) {
                BZ.$html.on("touchmove touchend MSPointerMove MSPointerUp pointermove pointerup", fn)
            }
            if (memory.x || memory.y) fn();
            return fn
        }(), 15);
        BZ.trigger("domready.bz.dom");
        if (BZ.support.touch) {
            if (navigator.userAgent.match(/(iPad|iPhone|iPod)/g)) {
                BZ.$win.on("load orientationchange resize", BZ.Utils.debounce(function() {
                    var fn = function() {
                        $(".bz-height-viewport").css("height", window.innerHeight);
                        return fn
                    };
                    return fn()
                }(), 100))
            }
        }
        BZ.trigger("afterready.bz.dom");
        BZ.domready = true
    });
    BZ.$html.addClass(BZ.support.touch ? "bz-touch" : "bz-notouch");
    if (BZ.support.touch) {
        var hoverset = false,
            exclude, hovercls = "bz-hover",
            selector = ".bz-overlay, .bz-overlay-hover, .bz-overlay-toggle, .bz-animation-hover, .bz-has-hover";
        BZ.$html.on("touchstart MSPointerDown pointerdown", selector, function() {
            if (hoverset) $("." + hovercls).removeClass(hovercls);
            hoverset = $(this).addClass(hovercls)
        }).on("touchend MSPointerUp pointerup", function(e) {
            exclude = $(e.target).parents(selector);
            if (hoverset) {
                hoverset.not(exclude).removeClass(hovercls)
            }
        })
    }
    return BZ
});
(function($) {
    if ($.fn.swipeLeft) {
        return
    }
    var touch = {},
        touchTimeout, tapTimeout, swipeTimeout, longTapTimeout, longTapDelay = 750,
        gesture;

    function swipeDirection(x1, x2, y1, y2) {
        return Math.abs(x1 - x2) >= Math.abs(y1 - y2) ? x1 - x2 > 0 ? "Left" : "Right" : y1 - y2 > 0 ? "Up" : "Down"
    }

    function longTap() {
        longTapTimeout = null;
        if (touch.last) {
            touch.el.trigger("longTap");
            touch = {}
        }
    }

    function cancelLongTap() {
        if (longTapTimeout) clearTimeout(longTapTimeout);
        longTapTimeout = null
    }

    function cancelAll() {
        if (touchTimeout) clearTimeout(touchTimeout);
        if (tapTimeout) clearTimeout(tapTimeout);
        if (swipeTimeout) clearTimeout(swipeTimeout);
        if (longTapTimeout) clearTimeout(longTapTimeout);
        touchTimeout = tapTimeout = swipeTimeout = longTapTimeout = null;
        touch = {}
    }

    function isPrimaryTouch(event) {
        return event.pointerType == event.MSPOINTER_TYPE_TOUCH && event.isPrimary
    }
    $(function() {
        var now, delta, deltaX = 0,
            deltaY = 0,
            firstTouch;
        if ("MSGesture" in window) {
            gesture = new MSGesture;
            gesture.target = document.body
        }
        $(document).on("MSGestureEnd gestureend", function(e) {
            var swipeDirectionFromVelocity = e.originalEvent.velocityX > 1 ? "Right" : e.originalEvent.velocityX < -1 ? "Left" : e.originalEvent.velocityY > 1 ? "Down" : e.originalEvent.velocityY < -1 ? "Up" : null;
            if (swipeDirectionFromVelocity) {
                touch.el.trigger("swipe");
                touch.el.trigger("swipe" + swipeDirectionFromVelocity)
            }
        }).on("touchstart MSPointerDown pointerdown", function(e) {
            if (e.type == "MSPointerDown" && !isPrimaryTouch(e.originalEvent)) return;
            firstTouch = e.type == "MSPointerDown" || e.type == "pointerdown" ? e : e.originalEvent.touches[0];
            now = Date.now();
            delta = now - (touch.last || now);
            touch.el = $("tagName" in firstTouch.target ? firstTouch.target : firstTouch.target.parentNode);
            if (touchTimeout) clearTimeout(touchTimeout);
            touch.x1 = firstTouch.pageX;
            touch.y1 = firstTouch.pageY;
            if (delta > 0 && delta <= 250) touch.isDoubleTap = true;
            touch.last = now;
            longTapTimeout = setTimeout(longTap, longTapDelay);
            if (gesture && (e.type == "MSPointerDown" || e.type == "pointerdown" || e.type == "touchstart")) {
                gesture.addPointer(e.originalEvent.pointerId)
            }
        }).on("touchmove MSPointerMove pointermove", function(e) {
            if (e.type == "MSPointerMove" && !isPrimaryTouch(e.originalEvent)) return;
            firstTouch = e.type == "MSPointerMove" || e.type == "pointermove" ? e : e.originalEvent.touches[0];
            cancelLongTap();
            touch.x2 = firstTouch.pageX;
            touch.y2 = firstTouch.pageY;
            deltaX += Math.abs(touch.x1 - touch.x2);
            deltaY += Math.abs(touch.y1 - touch.y2)
        }).on("touchend MSPointerUp pointerup", function(e) {
            if (e.type == "MSPointerUp" && !isPrimaryTouch(e.originalEvent)) return;
            cancelLongTap();
            if (touch.x2 && Math.abs(touch.x1 - touch.x2) > 30 || touch.y2 && Math.abs(touch.y1 - touch.y2) > 30) {
                swipeTimeout = setTimeout(function() {
                    touch.el.trigger("swipe");
                    touch.el.trigger("swipe" + swipeDirection(touch.x1, touch.x2, touch.y1, touch.y2));
                    touch = {}
                }, 0)
            } else if ("last" in touch) {
                if (isNaN(deltaX) || deltaX < 30 && deltaY < 30) {
                    tapTimeout = setTimeout(function() {
                        var event = $.Event("tap");
                        event.cancelTouch = cancelAll;
                        touch.el.trigger(event);
                        if (touch.isDoubleTap) {
                            touch.el.trigger("doubleTap");
                            touch = {}
                        } else {
                            touchTimeout = setTimeout(function() {
                                touchTimeout = null;
                                touch.el.trigger("singleTap");
                                touch = {}
                            }, 250)
                        }
                    }, 0)
                } else {
                    touch = {}
                }
                deltaX = deltaY = 0
            }
        }).on("touchcancel MSPointerCancel", cancelAll);
        $(window).on("scroll", cancelAll)
    });
    ["swipe", "swipeLeft", "swipeRight", "swipeUp", "swipeDown", "doubleTap", "tap", "singleTap", "longTap"].forEach(function(eventName) {
        $.fn[eventName] = function(callback) {
            return $(this).on(eventName, callback)
        }
    })
})(jQuery);
(function(BZ) {
    "use strict";
    var stacks = [];
    BZ.component("stackMargin", {
        defaults: {
            cls: "bz-margin-small-top"
        },
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-margin]", context).each(function() {
                    var ele = BZ.$(this),
                        obj;
                    if (!ele.data("stackMargin")) {
                        obj = BZ.stackMargin(ele, BZ.Utils.options(ele.attr("data-bz-margin")))
                    }
                })
            })
        },
        init: function() {
            var $this = this;
            this.columns = this.element.children();
            if (!this.columns.length) return;
            BZ.$win.on("resize orientationchange", function() {
                var fn = function() {
                    $this.process()
                };
                BZ.$(function() {
                    fn();
                    BZ.$win.on("load", fn)
                });
                return BZ.Utils.debounce(fn, 20)
            }());
            BZ.$html.on("changed.bz.dom", function(e) {
                $this.columns = $this.element.children();
                $this.process()
            });
            this.on("display.bz.check", function(e) {
                $this.columns = $this.element.children();
                if (this.element.is(":visible")) this.process()
            }.bind(this));
            stacks.push(this)
        },
        process: function() {
            var $this = this;
            BZ.Utils.stackMargin(this.columns, this.options);
            return this
        },
        revert: function() {
            this.columns.removeClass(this.options.cls);
            return this
        }
    });
    BZ.ready(function() {
        var iframes = [],
            check = function() {
                iframes.forEach(function(iframe) {
                    if (!iframe.is(":visible")) return;
                    var width = iframe.parent().width(),
                        iwidth = iframe.data("width"),
                        ratio = width / iwidth,
                        height = Math.floor(ratio * iframe.data("height"));
                    iframe.css({
                        height: width < iwidth ? height : iframe.data("height")
                    })
                })
            };
        BZ.$win.on("resize", BZ.Utils.debounce(check, 15));
        return function(context) {
            BZ.$("iframe.bz-responsive-width", context).each(function() {
                var iframe = BZ.$(this);
                if (!iframe.data("responsive") && iframe.attr("width") && iframe.attr("height")) {
                    iframe.data("width", iframe.attr("width"));
                    iframe.data("height", iframe.attr("height"));
                    iframe.data("responsive", true);
                    iframes.push(iframe)
                }
            });
            check()
        }
    }());
    BZ.Utils.stackMargin = function(elements, options) {
        options = BZ.$.extend({
            cls: "bz-margin-small-top"
        }, options);
        options.cls = options.cls;
        elements = BZ.$(elements).removeClass(options.cls);
        var skip = false,
            firstvisible = elements.filter(":visible:first"),
            offset = firstvisible.length ? firstvisible.position().top + firstvisible.outerHeight() - 1 : false;
        if (offset === false) return;
        elements.each(function() {
            var column = BZ.$(this);
            if (column.is(":visible")) {
                if (skip) {
                    column.addClass(options.cls)
                } else {
                    if (column.position().top >= offset) {
                        skip = column.addClass(options.cls)
                    }
                }
            }
        })
    }
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component("smoothScroll", {
        boot: function() {
            BZ.$html.on("click.smooth-scroll.bzkit", "[data-bz-smooth-scroll]", function(e) {
                var ele = BZ.$(this);
                if (!ele.data("smoothScroll")) {
                    var obj = BZ.smoothScroll(ele, BZ.Utils.options(ele.attr("data-bz-smooth-scroll")));
                    ele.trigger("click")
                }
                return false
            })
        },
        init: function() {
            var $this = this;
            this.on("click", function(e) {
                e.preventDefault();
                scrollToElement(BZ.$(this.hash).length ? BZ.$(this.hash) : BZ.$("body"), $this.options)
            })
        }
    });

    function scrollToElement(ele, options) {
        options = BZ.$.extend({
            duration: 1e3,
            transition: "easeOutExpo",
            offset: 0,
            complete: function() {}
        }, options);
        var target = ele.offset().top - options.offset,
            docheight = BZ.$doc.height(),
            winheight = window.innerHeight;
        if (target + winheight > docheight) {
            target = docheight - winheight
        }
        BZ.$("html,body").stop().animate({
            scrollTop: target
        }, options.duration, options.transition).promise().done(options.complete)
    }
    BZ.Utils.scrollToElement = scrollToElement;
    if (!BZ.$.easing.easeOutExpo) {
        BZ.$.easing.easeOutExpo = function(x, t, b, c, d) {
            return t == d ? b + c : c * (-Math.pow(2, -10 * t / d) + 1) + b
        }
    }
})(BZkit);
(function(BZ) {
    "use strict";
    var $win = BZ.$win,
        $doc = BZ.$doc,
        scrollspies = [],
        checkScrollSpy = function() {
            for (var i = 0; i < scrollspies.length; i++) {
                BZ.support.requestAnimationFrame.apply(window, [scrollspies[i].check])
            }
        };
    BZ.component("scrollspy", {
        defaults: {
            target: false,
            cls: "bz-scrollspy-inview",
            initcls: "bz-scrollspy-init-inview",
            topoffset: 0,
            leftoffset: 0,
            repeat: false,
            delay: 0
        },
        boot: function() {
            $doc.on("scrolling.bz.document", checkScrollSpy);
            $win.on("load resize orientationchange", BZ.Utils.debounce(checkScrollSpy, 50));
            BZ.ready(function(context) {
                BZ.$("[data-bz-scrollspy]", context).each(function() {
                    var element = BZ.$(this);
                    if (!element.data("scrollspy")) {
                        var obj = BZ.scrollspy(element, BZ.Utils.options(element.attr("data-bz-scrollspy")))
                    }
                })
            })
        },
        init: function() {
            var $this = this,
                inviewstate, initinview, togglecls = this.options.cls.split(/,/),
                fn = function() {
                    var elements = $this.options.target ? $this.element.find($this.options.target) : $this.element,
                        delayIdx = elements.length === 1 ? 1 : 0,
                        toggleclsIdx = 0;
                    elements.each(function(idx) {
                        var element = BZ.$(this),
                            inviewstate = element.data("inviewstate"),
                            inview = BZ.Utils.isInView(element, $this.options),
                            toggle = element.data("ukScrollspyCls") || togglecls[toggleclsIdx].trim();
                        if (inview && !inviewstate && !element.data("scrollspy-idle")) {
                            if (!initinview) {
                                element.addClass($this.options.initcls);
                                $this.offset = element.offset();
                                initinview = true;
                                element.trigger("init.bz.scrollspy")
                            }
                            element.data("scrollspy-idle", setTimeout(function() {
                                element.addClass("bz-scrollspy-inview").toggleClass(toggle).width();
                                element.trigger("inview.bz.scrollspy");
                                element.data("scrollspy-idle", false);
                                element.data("inviewstate", true)
                            }, $this.options.delay * delayIdx));
                            delayIdx++
                        }
                        if (!inview && inviewstate && $this.options.repeat) {
                            if (element.data("scrollspy-idle")) {
                                clearTimeout(element.data("scrollspy-idle"))
                            }
                            element.removeClass("bz-scrollspy-inview").toggleClass(toggle);
                            element.data("inviewstate", false);
                            element.trigger("outview.bz.scrollspy")
                        }
                        toggleclsIdx = togglecls[toggleclsIdx + 1] ? toggleclsIdx + 1 : 0
                    })
                };
            fn();
            this.check = fn;
            scrollspies.push(this)
        }
    });
    var scrollspynavs = [],
        checkScrollSpyNavs = function() {
            for (var i = 0; i < scrollspynavs.length; i++) {
                BZ.support.requestAnimationFrame.apply(window, [scrollspynavs[i].check])
            }
        };
    BZ.component("scrollspynav", {
        defaults: {
            cls: "bz-active",
            closest: false,
            topoffset: 0,
            leftoffset: 0,
            smoothscroll: false
        },
        boot: function() {
            $doc.on("scrolling.bz.document", checkScrollSpyNavs);
            $win.on("resize orientationchange", BZ.Utils.debounce(checkScrollSpyNavs, 50));
            BZ.ready(function(context) {
                BZ.$("[data-bz-scrollspy-nav]", context).each(function() {
                    var element = BZ.$(this);
                    if (!element.data("scrollspynav")) {
                        var obj = BZ.scrollspynav(element, BZ.Utils.options(element.attr("data-bz-scrollspy-nav")))
                    }
                })
            })
        },
        init: function() {
            var ids = [],
                links = this.find("a[href^='#']").each(function() {
                    ids.push(BZ.$(this).attr("href"))
                }),
                targets = BZ.$(ids.join(",")),
                clsActive = this.options.cls,
                clsClosest = this.options.closest || this.options.closest;
            var $this = this,
                inviews, fn = function() {
                    inviews = [];
                    for (var i = 0; i < targets.length; i++) {
                        if (BZ.Utils.isInView(targets.eq(i), $this.options)) {
                            inviews.push(targets.eq(i))
                        }
                    }
                    if (inviews.length) {
                        var navitems, scrollTop = $win.scrollTop(),
                            target = function() {
                                for (var i = 0; i < inviews.length; i++) {
                                    if (inviews[i].offset().top >= scrollTop) {
                                        return inviews[i]
                                    }
                                }
                            }();
                        if (!target) return;
                        if ($this.options.closest) {
                            links.closest(clsClosest).removeClass(clsActive);
                            navitems = links.filter("a[href='#" + target.attr("id") + "']").closest(clsClosest).addClass(clsActive)
                        } else {
                            navitems = links.removeClass(clsActive).filter("a[href='#" + target.attr("id") + "']").addClass(clsActive)
                        }
                        $this.element.trigger("inview.bz.scrollspynav", [target, navitems])
                    }
                };
            if (this.options.smoothscroll && BZ.smoothScroll) {
                links.each(function() {
                    BZ.smoothScroll(this, $this.options.smoothscroll)
                })
            }
            fn();
            this.element.data("scrollspynav", this);
            this.check = fn;
            scrollspynavs.push(this)
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    var toggles = [];
    BZ.component("toggle", {
        defaults: {
            target: false,
            cls: "bz-hidden",
			clstoggler: "open",
            animation: false,
            duration: 200
        },
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-toggle]", context).each(function() {
                    var ele = BZ.$(this);
                    if (!ele.data("toggle")) {
                        var obj = BZ.toggle(ele, BZ.Utils.options(ele.attr("data-bz-toggle")))
                    }
                });
                setTimeout(function() {
                    toggles.forEach(function(toggle) {
                        toggle.getToggles()
                    })
                }, 0)
            })
        },
        init: function() {
            var $this = this;
            this.getToggles();
            this.on("click", function(e) {
                if ($this.element.is('a[href="#"]')) e.preventDefault();
				
                $this.toggle()
            });
            toggles.push(this)
        },
        toggle: function() {
            if (!this.totoggle.length) return;
			
            if (this.options.animation && BZ.support.animation) {
                var $this = this,
                    animations = this.options.animation.split(",");
                if (animations.length == 1) {
                    animations[1] = animations[0]
                }
                animations[0] = animations[0].trim();
                animations[1] = animations[1].trim();
                this.totoggle.css("animation-duration", this.options.duration + "ms");
                if (this.totoggle.hasClass(this.options.cls)) {
                    this.totoggle.toggleClass(this.options.cls);
					this.element.toggleClass(this.options.clstoggler);
                    this.totoggle.each(function() {
                        BZ.Utils.animate(this, animations[0]).then(function() {
                            BZ.$(this).css("animation-duration", "");
                            BZ.Utils.checkDisplay(this)
                        })
                    })
                } else {
                    this.totoggle.each(function() {
                        BZ.Utils.animate(this, animations[1] + " bz-animation-reverse").then(function() {
							this.element.toggleClass(this.options.clstoggler);
                            BZ.$(this).toggleClass($this.options.cls).css("animation-duration", "");
                            BZ.Utils.checkDisplay(this)
                        }.bind(this))
                    })
                }
            } else {
				this.element.toggleClass(this.options.clstoggler);
                this.totoggle.toggleClass(this.options.cls);
                BZ.Utils.checkDisplay(this.totoggle)
            }
        },
        getToggles: function() {
            this.totoggle = this.options.target ? BZ.$(this.options.target) : []
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component("alert", {
        defaults: {
            fade: true,
            duration: 200,
            trigger: ".bz-alert-close"
        },
        boot: function() {
            BZ.$html.on("click.alert.bzkit", "[data-bz-alert]", function(e) {
                var ele = BZ.$(this);
                if (!ele.data("alert")) {
                    var alert = BZ.alert(ele, BZ.Utils.options(ele.attr("data-bz-alert")));
                    if (BZ.$(e.target).is(alert.options.trigger)) {
                        e.preventDefault();
                        alert.close()
                    }
                }
            })
        },
        init: function() {
            var $this = this;
            this.on("click", this.options.trigger, function(e) {
                e.preventDefault();
                $this.close()
            })
        },
        close: function() {
            var element = this.trigger("close.bz.alert"),
                removeElement = function() {
                    this.trigger("closed.bz.alert").remove()
                }.bind(this);
            if (this.options.fade) {
                element.css("overflow", "hidden").css("max-height", element.height()).animate({
                    height: 0,
                    opacity: 0,
                    "padding-top": 0,
                    "padding-bottom": 0,
                    "margin-top": 0,
                    "margin-bottom": 0
                }, this.options.duration, removeElement)
            } else {
                removeElement()
            }
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component("buttonRadio", {
        defaults: {
            target: ".bz-button"
        },
        boot: function() {
            BZ.$html.on("click.buttonradio.bzkit", "[data-bz-button-radio]", function(e) {
                var ele = BZ.$(this);
                if (!ele.data("buttonRadio")) {
                    var obj = BZ.buttonRadio(ele, BZ.Utils.options(ele.attr("data-bz-button-radio"))),
                        target = BZ.$(e.target);
                    if (target.is(obj.options.target)) {
                        target.trigger("click")
                    }
                }
            })
        },
        init: function() {
            var $this = this;
            this.on("click", this.options.target, function(e) {
                var ele = BZ.$(this);
                if (ele.is('a[href="#"]')) e.preventDefault();
                $this.find($this.options.target).not(ele).removeClass("bz-active").blur();
                $this.trigger("change.bz.button", [ele.addClass("bz-active")])
            })
        },
        getSelected: function() {
            return this.find(".bz-active")
        }
    });
    BZ.component("buttonCheckbox", {
        defaults: {
            target: ".bz-button"
        },
        boot: function() {
            BZ.$html.on("click.buttoncheckbox.bzkit", "[data-bz-button-checkbox]", function(e) {
                var ele = BZ.$(this);
                if (!ele.data("buttonCheckbox")) {
                    var obj = BZ.buttonCheckbox(ele, BZ.Utils.options(ele.attr("data-bz-button-checkbox"))),
                        target = BZ.$(e.target);
                    if (target.is(obj.options.target)) {
                        ele.trigger("change.bz.button", [target.toggleClass("bz-active").blur()])
                    }
                }
            })
        },
        init: function() {
            var $this = this;
            this.on("click", this.options.target, function(e) {
                if (BZ.$(this).is('a[href="#"]')) e.preventDefault();
                $this.trigger("change.bz.button", [BZ.$(this).toggleClass("bz-active").blur()])
            })
        },
        getSelected: function() {
            return this.find(".bz-active")
        }
    });
    BZ.component("button", {
        defaults: {},
        boot: function() {
            BZ.$html.on("click.button.bzkit", "[data-bz-button]", function(e) {
                var ele = BZ.$(this);
                if (!ele.data("button")) {
                    var obj = BZ.button(ele, BZ.Utils.options(ele.attr("data-bz-button")));
                    ele.trigger("click")
                }
            })
        },
        init: function() {
            var $this = this;
            this.on("click", function(e) {
                if ($this.element.is('a[href="#"]')) e.preventDefault();
                $this.toggle();
                $this.trigger("change.bz.button", [$this.element.blur().hasClass("bz-active")])
            })
        },
        toggle: function() {
            this.element.toggleClass("bz-active")
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    var active = false,
        hoverIdle;
    BZ.component("dropdown", {
        defaults: {
            mode: "hover",
            remaintime: 800,
            justify: false,
            boundary: BZ.$win,
            delay: 0
        },
        remainIdle: false,
        boot: function() {
            var triggerevent = BZ.support.touch ? "click" : "mouseenter";
            BZ.$html.on(triggerevent + ".dropdown.bzkit", "[data-bz-dropdown]", function(e) {
                var ele = BZ.$(this);
                if (!ele.data("dropdown")) {
                    var dropdown = BZ.dropdown(ele, BZ.Utils.options(ele.attr("data-bz-dropdown")));
                    if (triggerevent == "click" || triggerevent == "mouseenter" && dropdown.options.mode == "hover") {
                        dropdown.element.trigger(triggerevent)
                    }
                    if (dropdown.element.find(".bz-dropdown").length) {
                        e.preventDefault()
                    }
                }
            })
        },
        init: function() {
            var $this = this;
            this.dropdown = this.find(".bz-dropdown");
            this.centered = this.dropdown.hasClass("bz-dropdown-center");
            this.justified = this.options.justify ? BZ.$(this.options.justify) : false;
            this.boundary = BZ.$(this.options.boundary);
            this.flipped = this.dropdown.hasClass("bz-dropdown-flip");
            if (!this.boundary.length) {
                this.boundary = BZ.$win
            }
            if (this.options.mode == "click" || BZ.support.touch) {
                this.on("click.bzkit.dropdown", function(e) {
					console.log('tat');
                    var $target = BZ.$(e.target);
                    if (!$target.parents(".bz-dropdown").length) {
                        if ($target.is("a[href='#']") || $target.parent().is("a[href='#']") || $this.dropdown.length && !$this.dropdown.is(":visible")) {
                            e.preventDefault()
                        }
                        $target.blur()
                    }
                    if (!$this.element.hasClass("bz-open")) {
                        $this.show()
                    } else {
                        if ($target.is("a:not(.js-bz-prevent)") || $target.is(".bz-dropdown-close") || !$this.dropdown.find(e.target).length) {
                            $this.hide()
                        }
                    }
                })
            } else {
                this.on("mouseenter", function(e) {
                    if ($this.remainIdle) {
                        clearTimeout($this.remainIdle)
                    }
                    if (hoverIdle) {
                        clearTimeout(hoverIdle)
                    }
                    hoverIdle = setTimeout($this.show.bind($this), $this.options.delay)
                }).on("mouseleave", function() {
                    if (hoverIdle) {
                        clearTimeout(hoverIdle)
                    }
                    $this.remainIdle = setTimeout(function() {
                        $this.hide()
                    }, $this.options.remaintime)
                }).on("click", function(e) {
                    var $target = BZ.$(e.target);
                    if ($this.remainIdle) {
                        clearTimeout($this.remainIdle)
                    }
                    if ($target.is("a[href='#']") || $target.parent().is("a[href='#']")) {
                        e.preventDefault()
                    }
                    $this.show()
                })
            }
        },
        show: function() {
            BZ.$html.off("click.outer.dropdown");
            if (active && active[0] != this.element[0]) {
                active.removeClass("bz-open")
            }
            if (hoverIdle) {
                clearTimeout(hoverIdle)
            }
            this.checkDimensions();
            this.element.addClass("bz-open");
            this.trigger("show.bz.dropdown", [this]);
            BZ.Utils.checkDisplay(this.dropdown, true);
            active = this.element;
            this.registerOuterClick()
        },
        hide: function() {
            this.element.removeClass("bz-open");
            this.remainIdle = false;
            if (active && active[0] == this.element[0]) active = false
        },
        registerOuterClick: function() {
            var $this = this;
            BZ.$html.off("click.outer.dropdown");
            setTimeout(function() {
                BZ.$html.on("click.outer.dropdown", function(e) {
                    if (hoverIdle) {
                        clearTimeout(hoverIdle)
                    }
                    var $target = BZ.$(e.target);
                    if (active && active[0] == $this.element[0] && ($target.is("a:not(.js-bz-prevent)") || $target.is(".bz-dropdown-close") || !$this.dropdown.find(e.target).length)) {
                        $this.hide();
                        BZ.$html.off("click.outer.dropdown")
                    }
                })
            }, 10)
        },
        checkDimensions: function() {
            if (!this.dropdown.length) return;
            if (this.justified && this.justified.length) {
                this.dropdown.css("min-width", "")
            }
            var $this = this,
                dropdown = this.dropdown.css("margin-" + BZ.langdirection, ""),
                offset = dropdown.show().offset(),
                width = dropdown.outerWidth(),
                boundarywidth = this.boundary.width(),
                boundaryoffset = this.boundary.offset() ? this.boundary.offset().left : 0;
            if (this.centered) {
                dropdown.css("margin-" + BZ.langdirection, (parseFloat(width) / 2 - dropdown.parent().width() / 2) * -1);
                offset = dropdown.offset();
                if (width + offset.left > boundarywidth || offset.left < 0) {
                    dropdown.css("margin-" + BZ.langdirection, "");
                    offset = dropdown.offset()
                }
            }
            if (this.justified && this.justified.length) {
                var jwidth = this.justified.outerWidth();
                dropdown.css("min-width", jwidth);
                if (BZ.langdirection == "right") {
                    var right1 = boundarywidth - (this.justified.offset().left + jwidth),
                        right2 = boundarywidth - (dropdown.offset().left + dropdown.outerWidth());
                    dropdown.css("margin-right", right1 - right2)
                } else {
                    dropdown.css("margin-left", this.justified.offset().left - offset.left)
                }
                offset = dropdown.offset()
            }
            if (width + (offset.left - boundaryoffset) > boundarywidth) {
                dropdown.addClass("bz-dropdown-flip");
                offset = dropdown.offset()
            }
            if (offset.left - boundaryoffset < 0) {
                dropdown.addClass("bz-dropdown-stack");
                if (dropdown.hasClass("bz-dropdown-flip")) {
                    if (!this.flipped) {
                        dropdown.removeClass("bz-dropdown-flip");
                        offset = dropdown.offset();
                        dropdown.addClass("bz-dropdown-flip")
                    }
                    setTimeout(function() {
                        if (dropdown.offset().left - boundaryoffset < 0 || !$this.flipped && dropdown.outerWidth() + (offset.left - boundaryoffset) < boundarywidth) {
                            dropdown.removeClass("bz-dropdown-flip")
                        }
                    }, 0)
                }
                this.trigger("stack.bz.dropdown", [this])
            }
            dropdown.css("display", "")
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    var grids = [];
    BZ.component("gridMatchHeight", {
        defaults: {
            target: false,
            row: true
        },
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-grid-match]", context).each(function() {
                    var grid = BZ.$(this),
                        obj;
                    if (!grid.data("gridMatchHeight")) {
                        obj = BZ.gridMatchHeight(grid, BZ.Utils.options(grid.attr("data-bz-grid-match")))
                    }
                })
            })
        },
        init: function() {
            var $this = this;
            this.columns = this.element.children();
            this.elements = this.options.target ? this.find(this.options.target) : this.columns;
            if (!this.columns.length) return;
            BZ.$win.on("resize orientationchange", function() {
                var fn = function() {
                    $this.match()
                };
                BZ.$(function() {
                    fn();
                    BZ.$win.on("load", fn)
                });
                return BZ.Utils.debounce(fn, 50)
            }());
            BZ.$html.on("changed.bz.dom", function(e) {
                $this.columns = $this.element.children();
                $this.elements = $this.options.target ? $this.find($this.options.target) : $this.columns;
                $this.match()
            });
            this.on("display.bz.check", function(e) {
                if (this.element.is(":visible")) this.match()
            }.bind(this));
            grids.push(this)
        },
        match: function() {
            var firstvisible = this.columns.filter(":visible:first");
            if (!firstvisible.length) return;
            var stacked = Math.ceil(100 * parseFloat(firstvisible.css("width")) / parseFloat(firstvisible.parent().css("width"))) >= 100;
            if (stacked) {
                this.revert()
            } else {
                BZ.Utils.matchHeights(this.elements, this.options)
            }
            return this
        },
        revert: function() {
            this.elements.css("min-height", "");
            return this
        }
    });
    BZ.component("gridMargin", {
        defaults: {
            cls: "bz-grid-margin"
        },
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-grid-margin]", context).each(function() {
                    var grid = BZ.$(this),
                        obj;
                    if (!grid.data("gridMargin")) {
                        obj = BZ.gridMargin(grid, BZ.Utils.options(grid.attr("data-bz-grid-margin")))
                    }
                })
            })
        },
        init: function() {
            var stackMargin = BZ.stackMargin(this.element, this.options)
        }
    });
    BZ.Utils.matchHeights = function(elements, options) {
        elements = BZ.$(elements).css("min-height", "");
        options = BZ.$.extend({
            row: true
        }, options);
        var matchHeights = function(group) {
            if (group.length < 2) return;
            var max = 0;
            group.each(function() {
                max = Math.max(max, BZ.$(this).outerHeight())
            }).each(function() {
                var element = BZ.$(this),
                    height = max - (element.outerHeight() - element.height());
                element.css("min-height", height + "px")
            })
        };
        if (options.row) {
            elements.first().width();
            setTimeout(function() {
                var lastoffset = false,
                    group = [];
                elements.each(function() {
                    var ele = BZ.$(this),
                        offset = ele.offset().top;
                    if (offset != lastoffset && group.length) {
                        matchHeights(BZ.$(group));
                        group = [];
                        offset = ele.offset().top
                    }
                    group.push(ele);
                    lastoffset = offset
                });
                if (group.length) {
                    matchHeights(BZ.$(group))
                }
            }, 0)
        } else {
            matchHeights(elements)
        }
    }
})(BZkit);
(function(BZ) {
    "use strict";
    var active = false,
        $html = BZ.$html,
        body;
    BZ.component("modal", {
        defaults: {
            keyboard: true,
            bgclose: true,
            minScrollHeight: 150,
            center: false
        },
        scrollable: false,
        transition: false,
        init: function() {
            if (!body) body = BZ.$("body");
            var $this = this;
            this.transition = BZ.support.transition;
            this.paddingdir = "padding-" + (BZ.langdirection == "left" ? "right" : "left");
            this.dialog = this.find(".bz-modal-dialog");
            this.on("click", ".bz-modal-close", function(e) {
                e.preventDefault();
                $this.hide()
            }).on("click", function(e) {
                var target = BZ.$(e.target);
                if (target[0] == $this.element[0] && $this.options.bgclose) {
                    $this.hide()
                }
            })
        },
        toggle: function() {
            return this[this.isActive() ? "hide" : "show"]()
        },
        show: function() {
            var $this = this;
            if (this.isActive()) return;
            if (active) active.hide(true);
            this.element.removeClass("bz-open").show();
            this.resize();
            active = this;
            $html.addClass("bz-modal-page").height();
            this.element.addClass("bz-open").trigger("show.bz.modal");
            BZ.Utils.checkDisplay(this.dialog, true);
            return this
        },
        hide: function(force) {
            if (!this.isActive()) return;
            if (!force && BZ.support.transition) {
                var $this = this;
                this.one(BZ.support.transition.end, function() {
                    $this._hide()
                }).removeClass("bz-open")
            } else {
                this._hide()
            }
            return this
        },
        resize: function() {
            var bodywidth = body.width();
            this.scrollbarwidth = window.innerWidth - bodywidth;
            body.css(this.paddingdir, this.scrollbarwidth);
            this.element.css("overflow-y", this.scrollbarwidth ? "scroll" : "auto");
            if (!this.updateScrollable() && this.options.center) {
                var dh = this.dialog.outerHeight(),
                    pad = parseInt(this.dialog.css("margin-top"), 10) + parseInt(this.dialog.css("margin-bottom"), 10);
                if (dh + pad < window.innerHeight) {
                    this.dialog.css({
                        top: window.innerHeight / 2 - dh / 2 - pad
                    })
                } else {
                    this.dialog.css({
                        top: ""
                    })
                }
            }
        },
        updateScrollable: function() {
            var scrollable = this.dialog.find(".bz-overflow-container:visible:first");
            if (scrollable.length) {
                scrollable.css("height", 0);
                var offset = Math.abs(parseInt(this.dialog.css("margin-top"), 10)),
                    dh = this.dialog.outerHeight(),
                    wh = window.innerHeight,
                    h = wh - 2 * (offset < 20 ? 20 : offset) - dh;
                scrollable.css("height", h < this.options.minScrollHeight ? "" : h);
                return true
            }
            return false
        },
        _hide: function() {
            this.element.hide().removeClass("bz-open");
            $html.removeClass("bz-modal-page");
            body.css(this.paddingdir, "");
            if (active === this) active = false;
            this.trigger("hide.bz.modal")
        },
        isActive: function() {
            return active == this
        }
    });
    BZ.component("modalTrigger", {
        boot: function() {
            BZ.$html.on("click.modal.bzkit", "[data-bz-modal]", function(e) {
                var ele = BZ.$(this);
                if (ele.is("a")) {
                    e.preventDefault()
                }
                if (!ele.data("modalTrigger")) {
                    var modal = BZ.modalTrigger(ele, BZ.Utils.options(ele.attr("data-bz-modal")));
                    modal.show()
                }
            });
            BZ.$html.on("keydown.modal.bzkit", function(e) {
                if (active && e.keyCode === 27 && active.options.keyboard) {
                    e.preventDefault();
                    active.hide()
                }
            });
            BZ.$win.on("resize orientationchange", BZ.Utils.debounce(function() {
                if (active) active.resize()
            }, 150))
        },
        init: function() {
            var $this = this;
            this.options = BZ.$.extend({
                target: $this.element.is("a") ? $this.element.attr("href") : false
            }, this.options);
            this.modal = BZ.modal(this.options.target, this.options);
            this.on("click", function(e) {
                e.preventDefault();
                $this.show()
            });
            this.proxy(this.modal, "show hide isActive")
        }
    });
    BZ.modal.dialog = function(content, options) {
        var modal = BZ.modal(BZ.$(BZ.modal.dialog.template).appendTo("body"), options);
        modal.on("hide.bz.modal", function() {
            if (modal.persist) {
                modal.persist.appendTo(modal.persist.data("modalPersistParent"));
                modal.persist = false
            }
            modal.element.remove()
        });
        setContent(content, modal);
        return modal
    };
    BZ.modal.dialog.template = '<div class="bz-modal"><div class="bz-modal-dialog" style="min-height:0;"></div></div>';
    BZ.modal.alert = function(content, options) {
        BZ.modal.dialog(['<div class="bz-margin bz-modal-content">' + String(content) + "</div>", '<div class="bz-modal-footer bz-text-right"><button class="bz-button bz-button-primary bz-modal-close">Ok</button></div>'].join(""), BZ.$.extend({
            bgclose: false,
            keyboard: false
        }, options)).show()
    };
    BZ.modal.confirm = function(content, onconfirm, options) {
        onconfirm = BZ.$.isFunction(onconfirm) ? onconfirm : function() {};
        var modal = BZ.modal.dialog(['<div class="bz-margin bz-modal-content">' + String(content) + "</div>", '<div class="bz-modal-footer bz-text-right"><button class="bz-button bz-button-primary js-modal-confirm">Ok</button> <button class="bz-button bz-modal-close">Cancel</button></div>'].join(""), BZ.$.extend({
            bgclose: false,
            keyboard: false
        }, options));
        modal.element.find(".js-modal-confirm").on("click", function() {
            onconfirm();
            modal.hide()
        });
        modal.show()
    };

    function setContent(content, modal) {
        if (!modal) return;
        if (typeof content === "object") {
            content = content instanceof jQuery ? content : BZ.$(content);
            if (content.parent().length) {
                modal.persist = content;
                modal.persist.data("modalPersistParent", content.parent())
            }
        } else if (typeof content === "string" || typeof content === "number") {
            content = BZ.$("<div></div>").html(content)
        } else {
            content = BZ.$("<div></div>").html("BZkit.modal Error: Unsupported data type: " + typeof content)
        }
        content.appendTo(modal.element.find(".bz-modal-dialog"));
        return modal
    }
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component("nav", {
        defaults: {
            toggle: ">li.bz-parent > a[href='#']",
            lists: ">li.bz-parent > ul",
            multiple: false
        },
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-nav]", context).each(function() {
                    var nav = BZ.$(this);
                    if (!nav.data("nav")) {
                        var obj = BZ.nav(nav, BZ.Utils.options(nav.attr("data-bz-nav")))
                    }
                })
            })
        },
        init: function() {
            var $this = this;
            this.on("click.bzkit.nav", this.options.toggle, function(e) {
                e.preventDefault();
                var ele = BZ.$(this);
                $this.open(ele.parent()[0] == $this.element[0] ? ele : ele.parent("li"))
            });
            this.find(this.options.lists).each(function() {
                var $ele = BZ.$(this),
                    parent = $ele.parent(),
                    active = parent.hasClass("bz-active");
                $ele.wrap('<div style="overflow:hidden;height:0;position:relative;"></div>');
                parent.data("list-container", $ele.parent());
                if (active) $this.open(parent, true)
            })
        },
        open: function(li, noanimation) {
            var $this = this,
                element = this.element,
                $li = BZ.$(li);
            if (!this.options.multiple) {
                element.children(".bz-open").not(li).each(function() {
                    var ele = BZ.$(this);
                    if (ele.data("list-container")) {
                        ele.data("list-container").stop().animate({
                            height: 0
                        }, function() {
                            BZ.$(this).parent().removeClass("bz-open")
                        })
                    }
                })
            }
            $li.toggleClass("bz-open");
            if ($li.data("list-container")) {
                if (noanimation) {
                    $li.data("list-container").stop().height($li.hasClass("bz-open") ? "auto" : 0);
                    this.trigger("display.bz.check")
                } else {
                    $li.data("list-container").stop().animate({
                        height: $li.hasClass("bz-open") ? getHeight($li.data("list-container").find("ul:first")) : 0
                    }, function() {
                        $this.trigger("display.bz.check")
                    })
                }
            }
        }
    });

    function getHeight(ele) {
        var $ele = BZ.$(ele),
            height = "auto";
        if ($ele.is(":visible")) {
            height = $ele.outerHeight()
        } else {
            var tmp = {
                position: $ele.css("position"),
                visibility: $ele.css("visibility"),
                display: $ele.css("display")
            };
            height = $ele.css({
                position: "absolute",
                visibility: "hidden",
                display: "block"
            }).outerHeight();
            $ele.css(tmp)
        }
        return height
    }
})(BZkit);
(function(BZ) {
    "use strict";
    var scrollpos = {
            x: window.scrollX,
            y: window.scrollY
        },
        $win = BZ.$win,
        $doc = BZ.$doc,
        $html = BZ.$html,
        Offcanvas = {
            show: function(element) {
                element = BZ.$(element);
                if (!element.length) return;
                var $body = BZ.$("body"),
                    bar = element.find(".bz-offcanvas-bar:first"),
                    rtl = BZ.langdirection == "right",
                    flip = bar.hasClass("bz-offcanvas-bar-flip") ? -1 : 1,
                    dir = flip * (rtl ? -1 : 1);
                scrollpos = {
                    x: window.pageXOffset,
                    y: window.pageYOffset
                };
                element.addClass("bz-active");
                $body.css({
                    width: window.innerWidth,
                    height: window.innerHeight
                }).addClass("bz-offcanvas-page");
                $body.css(rtl ? "margin-right" : "margin-left", (rtl ? -1 : 1) * (bar.outerWidth() * dir)).width();
                $html.css("margin-top", scrollpos.y * -1);
                bar.addClass("bz-offcanvas-bar-show");
                this._initElement(element);
                $doc.trigger("show.bz.offcanvas", [element, bar])
            },
            hide: function(force) {
                var $body = BZ.$("body"),
                    panel = BZ.$(".bz-offcanvas.bz-active"),
                    rtl = BZ.langdirection == "right",
                    bar = panel.find(".bz-offcanvas-bar:first"),
                    finalize = function() {
                        $body.removeClass("bz-offcanvas-page").css({
                            width: "",
                            height: "",
                            "margin-left": "",
                            "margin-right": ""
                        });
                        panel.removeClass("bz-active");
                        bar.removeClass("bz-offcanvas-bar-show");
                        $html.css("margin-top", "");
                        window.scrollTo(scrollpos.x, scrollpos.y);
                        BZ.$doc.trigger("hide.bz.offcanvas", [panel, bar])
                    };
                if (!panel.length) return;
                if (BZ.support.transition && !force) {
                    $body.one(BZ.support.transition.end, function() {
                        finalize()
                    }).css(rtl ? "margin-right" : "margin-left", "");
                    setTimeout(function() {
                        bar.removeClass("bz-offcanvas-bar-show")
                    }, 0)
                } else {
                    finalize()
                }
            },
            _initElement: function(element) {
                if (element.data("OffcanvasInit")) return;
                element.on("click.bz.offcanvas swipeRight.bz.offcanvas swipeLeft.bz.offcanvas", function(e) {
                    var target = BZ.$(e.target);
                    if (!e.type.match(/swipe/)) {
                        if (!target.hasClass("bz-offcanvas-close")) {
                            if (target.hasClass("bz-offcanvas-bar")) return;
                            if (target.parents(".bz-offcanvas-bar:first").length) return
                        }
                    }
                    e.stopImmediatePropagation();
                    Offcanvas.hide()
                });
                element.on("click", "a[href^='#']", function(e) {
                    var element = BZ.$(this),
                        href = element.attr("href");
                    if (href == "#") {
                        return
                    }
                    BZ.$doc.one("hide.bz.offcanvas", function() {
                        var target = BZ.$(href);
                        if (!target.length) {
                            target = BZ.$('[name="' + href.replace("#", "") + '"]')
                        }
                        if (BZ.Utils.scrollToElement && target.length) {
                            BZ.Utils.scrollToElement(target)
                        } else {
                            window.location.href = href
                        }
                    });
                    Offcanvas.hide()
                });
                element.data("OffcanvasInit", true)
            }
        };
    BZ.component("offcanvasTrigger", {
        boot: function() {
            $html.on("click.offcanvas.bzkit", "[data-bz-offcanvas]", function(e) {
                e.preventDefault();
                var ele = BZ.$(this);
                if (!ele.data("offcanvasTrigger")) {
                    var obj = BZ.offcanvasTrigger(ele, BZ.Utils.options(ele.attr("data-bz-offcanvas")));
                    ele.trigger("click")
                }
            });
            $html.on("keydown.bz.offcanvas", function(e) {
                if (e.keyCode === 27) {
                    Offcanvas.hide()
                }
            })
        },
        init: function() {
            var $this = this;
            this.options = BZ.$.extend({
                target: $this.element.is("a") ? $this.element.attr("href") : false
            }, this.options);
            this.on("click", function(e) {
                e.preventDefault();
                Offcanvas.show($this.options.target)
            })
        }
    });
    BZ.offcanvas = Offcanvas
})(BZkit);
(function(BZ) {
    "use strict";
    var Animations;
    BZ.component("switcher", {
        defaults: {
            connect: false,
            toggle: ">*",
            active: 0,
            animation: false,
            duration: 200
        },
        animating: false,
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-switcher]", context).each(function() {
                    var switcher = BZ.$(this);
                    if (!switcher.data("switcher")) {
                        var obj = BZ.switcher(switcher, BZ.Utils.options(switcher.attr("data-bz-switcher")))
                    }
                })
            })
        },
        init: function() {
            var $this = this;
            this.on("click.bzkit.switcher", this.options.toggle, function(e) {
                e.preventDefault();
                $this.show(this)
            });
            if (this.options.connect) {
                this.connect = BZ.$(this.options.connect);
                this.connect.find(".bz-active").removeClass(".bz-active");
                if (this.connect.length) {
                    this.connect.on("click", "[data-bz-switcher-item]", function(e) {
                        e.preventDefault();
                        var item = BZ.$(this).attr("data-bz-switcher-item");
                        if ($this.index == item) return;
                        switch (item) {
                            case "next":
                            case "previous":
                                $this.show($this.index + (item == "next" ? 1 : -1));
                                break;
                            default:
                                $this.show(parseInt(item, 10))
                        }
                    }).on("swipeRight swipeLeft", function(e) {
                        e.preventDefault();
                        $this.show($this.index + (e.type == "swipeLeft" ? 1 : -1))
                    })
                }
                var toggles = this.find(this.options.toggle),
                    active = toggles.filter(".bz-active");
                if (active.length) {
                    this.show(active, false)
                } else {
                    if (this.options.active === false) return;
                    active = toggles.eq(this.options.active);
                    this.show(active.length ? active : toggles.eq(0), false)
                }
                this.on("changed.bz.dom", function() {
                    $this.connect = BZ.$($this.options.connect)
                })
            }
        },
        show: function(tab, animate) {
            if (this.animating) {
                return
            }
            if (isNaN(tab)) {
                tab = BZ.$(tab)
            } else {
                var toggles = this.find(this.options.toggle);
                tab = tab < 0 ? toggles.length - 1 : tab;
                tab = toggles.eq(toggles[tab] ? tab : 0)
            }
            var $this = this,
                active = BZ.$(tab),
                animation = Animations[this.options.animation] || function(current, next) {
                    if (!$this.options.animation) {
                        return Animations.none.apply($this)
                    }
                    var anim = $this.options.animation.split(",");
                    if (anim.length == 1) {
                        anim[1] = anim[0]
                    }
                    anim[0] = anim[0].trim();
                    anim[1] = anim[1].trim();
                    return coreAnimation.apply($this, [anim, current, next])
                };
            if (animate === false || !BZ.support.animation) {
                animation = Animations.none
            }
            if (active.hasClass("bz-disabled")) return;
            this.find(this.options.toggle).filter(".bz-active").removeClass("bz-active");
            active.addClass("bz-active");
            if (this.options.connect && this.connect.length) {
                this.index = this.find(this.options.toggle).index(active);
                if (this.index == -1) {
                    this.index = 0
                }
                this.connect.each(function() {
                    var container = BZ.$(this),
                        children = BZ.$(container.children()),
                        current = BZ.$(children.filter(".bz-active")),
                        next = BZ.$(children.eq($this.index));
                    $this.animating = true;
                    animation.apply($this, [current, next]).then(function() {
                        current.removeClass("bz-active");
                        next.addClass("bz-active");
                        BZ.Utils.checkDisplay(next, true);
                        $this.animating = false
                    })
                })
            }
            this.trigger("show.bz.switcher", [active])
        }
    });
    Animations = {
        none: function() {
            var d = BZ.$.Deferred();
            d.resolve();
            return d.promise()
        },
        fade: function(current, next) {
            return coreAnimation.apply(this, ["bz-animation-fade", current, next])
        },
        "slide-bottom": function(current, next) {
            return coreAnimation.apply(this, ["bz-animation-slide-bottom", current, next])
        },
        "slide-top": function(current, next) {
            return coreAnimation.apply(this, ["bz-animation-slide-top", current, next])
        },
        "slide-vertical": function(current, next, dir) {
            var anim = ["bz-animation-slide-top", "bz-animation-slide-bottom"];
            if (current && current.index() > next.index()) {
                anim.reverse()
            }
            return coreAnimation.apply(this, [anim, current, next])
        },
        "slide-left": function(current, next) {
            return coreAnimation.apply(this, ["bz-animation-slide-left", current, next])
        },
        "slide-right": function(current, next) {
            return coreAnimation.apply(this, ["bz-animation-slide-right", current, next])
        },
        "slide-horizontal": function(current, next, dir) {
            var anim = ["bz-animation-slide-right", "bz-animation-slide-left"];
            if (current && current.index() > next.index()) {
                anim.reverse()
            }
            return coreAnimation.apply(this, [anim, current, next])
        },
        scale: function(current, next) {
            return coreAnimation.apply(this, ["bz-animation-scale-up", current, next])
        }
    };
    BZ.switcher.animations = Animations;

    function coreAnimation(cls, current, next) {
        var d = BZ.$.Deferred(),
            clsIn = cls,
            clsOut = cls,
            release;
        if (next[0] === current[0]) {
            d.resolve();
            return d.promise()
        }
        if (typeof cls == "object") {
            clsIn = cls[0];
            clsOut = cls[1] || cls[0]
        }
        release = function() {
            if (current) current.hide().removeClass("bz-active " + clsOut + " bz-animation-reverse");
            next.addClass(clsIn).one(BZ.support.animation.end, function() {
                next.removeClass("" + clsIn + "").css({
                    opacity: "",
                    display: ""
                });
                d.resolve();
                if (current) current.css({
                    opacity: "",
                    display: ""
                })
            }.bind(this)).show()
        };
        next.css("animation-duration", this.options.duration + "ms");
        if (current && current.length) {
            current.css("animation-duration", this.options.duration + "ms");
            current.css("display", "none").addClass(clsOut + " bz-animation-reverse").one(BZ.support.animation.end, function() {
                release()
            }.bind(this)).css("display", "")
        } else {
            next.addClass("bz-active");
            release()
        }
        return d.promise()
    }
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component("tab", {
        defaults: {
            target: ">li:not(.bz-tab-responsive, .bz-disabled)",
            connect: false,
            active: 0,
            animation: false,
            duration: 200,
			responsive: false,
			collapse: true
        },
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-tab]", context).each(function() {
                    var tab = BZ.$(this);
                    if (!tab.data("tab")) {
                        var obj = BZ.tab(tab, BZ.Utils.options(tab.attr("data-bz-tab")))
                    }
                })
            })
        },
        init: function() {
            var $this = this;
			this.options.collapse = this.options.responsive ? false : this.options.collapse;
            this.on("click.bzkit.tab", this.options.target, function(e) {
                e.preventDefault();
                if ($this.switcher && $this.switcher.animating) {
                    return
                }
                $this.find($this.options.target).not(this).removeClass("bz-active").blur();
                $this.trigger("change.bz.tab", [BZ.$(this).addClass("bz-active")])
            });
            if (this.options.connect) {
                this.connect = BZ.$(this.options.connect)
            }
			if ( this.options.responsive ) {
				this.responsivetab = BZ.$('<li class="bz-tab-responsive bz-active"><a></a></li>').append('<div class="bz-dropdown bz-dropdown-small"><ul class="bz-nav bz-nav-dropdown"></ul><div>');
				this.responsivetab.dropdown = this.responsivetab.find(".bz-dropdown");
				this.responsivetab.lst = this.responsivetab.dropdown.find("ul");
				this.responsivetab.caption = this.responsivetab.find("a:first");
				if (this.element.hasClass("bz-tab-bottom")) this.responsivetab.dropdown.addClass("bz-dropdown-up");
				this.responsivetab.lst.on("click.bzkit.tab", "a", function(e) {
					e.preventDefault();
					e.stopPropagation();
					var link = BZ.$(this);
					$this.element.children(":not(.bz-tab-responsive)").eq(link.data("index")).trigger("click")
				});
				this.on("show.bz.switcher change.bz.tab", function(e, tab) {
					$this.responsivetab.caption.html(tab.text())
				});
				this.element.append(this.responsivetab);
			}
            if (this.options.connect) {
                this.switcher = BZ.switcher(this.element, {
                    toggle: ">li:not(.bz-tab-responsive)",
                    connect: this.options.connect,
                    active: this.options.active,
                    animation: this.options.animation,
                    duration: this.options.duration
                })
            }
			if ( this.options.responsive ) {
				BZ.dropdown(this.responsivetab, {
					mode: "click"
				});
			}
            $this.trigger("change.bz.tab", [this.element.find(this.options.target).filter(".bz-active")]);
            this.check();
            BZ.$win.on("resize orientationchange", BZ.Utils.debounce(function() {
                if ($this.element.is(":visible")) $this.check()
            }, 100));
            this.on("display.bz.check", function() {
                if ($this.element.is(":visible")) $this.check()
            })
        },
        check: function() {
			
			if ( this.options.collapse ) {
				this.element.removeClass('bz-tab-collapsed');
				var children = this.element.children(":not(.bz-tab-responsive)")
				if (!children.length) return;
				
				var w 	= this.element.width(),
					cw 	= 0;
				children.each(function() {
					cw += BZ.$(this).outerWidth();
				});
				
				if ( cw >= w ) {
					this.element.addClass('bz-tab-collapsed');
				}
			}
			
			if ( this.options.responsive ) {
				
				var children = this.element.children(":not(.bz-tab-responsive)").removeClass("bz-hidden");
				if (!children.length) return;
				var top = children.eq(0).offset().top + Math.ceil(children.eq(0).height() / 2),
					doresponsive = false,
					item, link;
				this.responsivetab.lst.empty();
				children.each(function() {
					if (BZ.$(this).offset().top > top) {
						doresponsive = true
					}
				});
				
				if (doresponsive) {
					for (var i = 0; i < children.length; i++) {
						item = BZ.$(children.eq(i));
						link = item.find("a");
						if (item.css("float") != "none" && !item.attr("bz-dropdown")) {
							item.addClass("bz-hidden");
							if (!item.hasClass("bz-disabled")) {
								this.responsivetab.lst.append('<li><a href="' + link.attr("href") + '" data-index="' + i + '">' + link.html() + "</a></li>")
							}
						}
					}
				}
				this.responsivetab[this.responsivetab.lst.children().length ? "removeClass" : "addClass"]("bz-hidden")
			}
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component("cover", {
        defaults: {
            automute: true
        },
        boot: function() {
            BZ.ready(function(context) {
                BZ.$("[data-bz-cover]", context).each(function() {
                    var ele = BZ.$(this);
                    if (!ele.data("cover")) {
                        var plugin = BZ.cover(ele, BZ.Utils.options(ele.attr("data-bz-cover")))
                    }
                })
            })
        },
        init: function() {
            this.parent = this.element.parent();
            BZ.$win.on("load resize orientationchange", BZ.Utils.debounce(function() {
                this.check()
            }.bind(this), 100));
            this.on("display.bz.check", function(e) {
                if (this.element.is(":visible")) this.check()
            }.bind(this));
            this.check();
            if (this.element.is("iframe") && this.options.automute) {
                var src = this.element.attr("src");
                this.element.attr("src", "").on("load", function() {
                    this.contentWindow.postMessage('{ "event": "command", "func": "mute", "method":"setVolume", "value":0}', "*")
                }).attr("src", [src, src.indexOf("?") > -1 ? "&" : "?", "enablejsapi=1&api=1"].join(""))
            }
        },
        check: function() {
            this.element.css({
                width: "",
                height: ""
            });
            this.dimension = {
                w: this.element.width(),
                h: this.element.height()
            };
            if (this.element.attr("width") && !isNaN(this.element.attr("width"))) {
                this.dimension.w = this.element.attr("width")
            }
            if (this.element.attr("height") && !isNaN(this.element.attr("height"))) {
                this.dimension.h = this.element.attr("height")
            }
            this.ratio = this.dimension.w / this.dimension.h;
            var w = this.parent.width(),
                h = this.parent.height(),
                width, height;
            if (w / this.ratio < h) {
                width = Math.ceil(h * this.ratio);
                height = h
            } else {
                width = w;
                height = Math.ceil(w / this.ratio)
            }
            this.element.css({
                width: width,
                height: height
            })
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component('formSelect', {

        defaults: {
            'target': '>span:first',
            'activeClass': 'bz-active'
        },

        boot: function() {
            // init code
            BZ.ready(function(context) {

                BZ.$("[data-bz-form-select]", context).each(function(){

                    var ele = BZ.$(this);

                    if (!ele.data("formSelect")) {
                        BZ.formSelect(ele, BZ.Utils.options(ele.attr("data-bz-form-select")));
                    }
                });
            });
        },

        init: function() {
            var $this = this;

            this.target  = this.find(this.options.target);
            this.select  = this.find('select');

            // init + on change event
            this.select.on("change", (function(){

                var select = $this.select[0], fn = function(){

                    try {
                        $this.target.text(select.options[select.selectedIndex].text);
                    } catch(e) {}

                    $this.element[$this.select.val() ? 'addClass':'removeClass']($this.options.activeClass);

                    return fn;
                };

                return fn();
            })());

            this.element.data("formSelect", this);
        }
    })
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component('formSubmit', {

        defaults: {
            'target': null,
            'task': null
        },

        boot: function() {
            // init code
            BZ.ready(function(context) {

                BZ.$("[data-bz-form-submit]", context).each(function(){

                    var ele = BZ.$(this);

                    if (!ele.data("formSubmit")) {
                        var obj = BZ.formSubmit(ele, BZ.Utils.options(ele.attr("data-bz-form-submit")));
                    }
                });
            });
        },

        init: function() {
            var $this = this;

            this.on("click.bzkit.formSubmit", function(e) {
                e.preventDefault();
				
				var f	= BZ.$($this.options.target),
                	d 	= BZ.$(this),
					t	= $this.options.task;
				
				if ( !d.hasClass('bz-submitting') && !f.hasClass('disabled') ) {

					d.addClass('bz-active');
					d.addClass('bz-submitting');
					d.attr('disabled', 'disabled');
					
					if ( f = BZ.$($this.options.target) ) {
						if ( t.length ) {
							var r = BZ.$('input[name="task"]', f);
							if ( r ) {
								r.val(t);
							}
						}
						
						f.submit();
					}					
				}
            });
            

            this.element.data("formSubmit", this);
        }
    })
})(BZkit);
(function(BZ){

    "use strict";

    var $win         = BZ.$win,
        $doc         = BZ.$doc,
        sticked      = [],
        direction    = 1;

    BZ.component('sticky', {

        defaults: {
            top          : 0,
            bottom       : 0,
            animation    : '',
            clsinit      : 'bz-sticky-init',
            clsactive    : 'bz-active',
            clsinactive  : '',
            getWidthFrom : '',
            showup      : false,
            boundary     : false,
            media        : false,
            target       : false,
            disabled     : false
        },

        boot: function() {

            // should be more efficient than using $win.scroll(checkscrollposition):
            BZ.$doc.on('scrolling.bz.document', function(e, data) {
                direction = data.dir.y;
                checkscrollposition();
            });

            BZ.$win.on('resize orientationchange', BZ.Utils.debounce(function() {

                if (!sticked.length) return;

                for (var i = 0; i < sticked.length; i++) {
                    sticked[i].reset(true);
                    sticked[i].self.computeWrapper();
                }

                checkscrollposition();
            }, 100));

            // init code
            BZ.ready(function(context) {

                setTimeout(function(){

                    BZ.$("[data-bz-sticky]", context).each(function(){

                        var $ele = BZ.$(this);

                        if(!$ele.data("sticky")) {
                            BZ.sticky($ele, BZ.Utils.options($ele.attr('data-bz-sticky')));
                        }
                    });

                    checkscrollposition();
                }, 0);
            });
        },

        init: function() {

            var wrapper  = BZ.$('<div class="bz-sticky-placeholder"></div>'), boundary = this.options.boundary, boundtoparent;

            this.wrapper = this.element.css('margin', 0).wrap(wrapper).parent();

            this.computeWrapper();

            if (boundary) {

                if (boundary === true) {

                    boundary      = this.wrapper.parent();
                    boundtoparent = true;

                } else if (typeof boundary === "string") {
                    boundary = BZ.$(boundary);
                }
            }

            this.sticky = {
                self          : this,
                options       : this.options,
                element       : this.element,
                currentTop    : null,
                wrapper       : this.wrapper,
                init          : false,
                getWidthFrom  : this.options.getWidthFrom || this.wrapper,
                boundary      : boundary,
                boundtoparent : boundtoparent,
                top           : 0,
                calcTop       : function() {

                    var top = this.options.top;

                    // dynamic top parameter
                    if (this.options.top && typeof(this.options.top) == 'string') {

                        // e.g. 50vh
                        if (this.options.top.match(/^(-|)(\d+)vh$/)) {
                            top = window.innerHeight * parseInt(this.options.top, 10)/100;
                        // e.g. #elementId, or .class-1,class-2,.class-3 (first found is used)
                        } else {

                            var topElement = BZ.$(this.options.top).first();

                            if (topElement.length && topElement.is(':visible')) {
                                top = -1 * ((topElement.offset().top + topElement.outerHeight()) - this.wrapper.offset().top);
                            }
                        }

                    }

                    this.top = top;
                },
                reset         : function(force) {

                    this.calcTop();

                    var finalize = function() {
                        this.element.css({"position":"", "top":"", "width":"", "left":"", "margin":"0"});
                        this.element.removeClass([this.options.animation, 'bz-animation-reverse', this.options.clsactive].join(' '));
                        this.element.addClass(this.options.clsinactive);

                        this.currentTop = null;
                        this.animate    = false;
                    }.bind(this);


                    if (!force && this.options.animation && BZ.support.animation && !BZ.Utils.isInView(this.wrapper)) {

                        this.animate = true;

                        this.element.removeClass(this.options.animation).one(BZ.support.animation.end, function(){
                            finalize();
                        }).width(); // force redraw

                        this.element.addClass(this.options.animation+' '+'bz-animation-reverse');
                    } else {
                        finalize();
                    }
                },

                check: function() {

                    if (this.options.disabled) {
                        return false;
                    }

                    if (this.options.media) {

                        switch(typeof(this.options.media)) {
                            case 'number':
                                if (window.innerWidth < this.options.media) {
                                    return false;
                                }
                                break;
                            case 'string':
                                if (window.matchMedia && !window.matchMedia(this.options.media).matches) {
                                    return false;
                                }
                                break;
                        }
                    }

                    var scrollTop      = $win.scrollTop(),
                        documentHeight = $doc.height(),
                        dwh            = documentHeight - window.innerHeight,
                        extra          = (scrollTop > dwh) ? dwh - scrollTop : 0,
                        elementTop     = this.wrapper.offset().top,
                        etse           = elementTop - this.top - extra,
                        active         = (scrollTop  >= etse);

                    if (active && this.options.showup) {

                        // set inactiv if scrolling down
                        if (direction == 1) {
                            active = false;
                        }

                        // set inactive when wrapper is still in view
                        if (direction == -1 && !this.element.hasClass(this.options.clsactive) && BZ.Utils.isInView(this.wrapper)) {
                            active = false;
                        }
                    }

                    return active;
                }
            };

            this.sticky.calcTop();

            sticked.push(this.sticky);
        },

        update: function() {
            checkscrollposition(this.sticky);
        },

        enable: function() {
            this.options.disabled = false;
            this.update();
        },

        disable: function(force) {
            this.options.disabled = true;
            this.sticky.reset(force);
        },

        computeWrapper: function() {

            this.wrapper.css({
                'height' : ['absolute','fixed'].indexOf(this.element.css('position')) == -1 ? this.element.outerHeight() : '',
                'float'  : this.element.css('float') != 'none' ? this.element.css('float') : '',
                'margin' : this.element.css('margin')
            });
        }
    });

    function checkscrollposition(direction) {

        var stickies = arguments.length ? arguments : sticked;

        if (!stickies.length || $win.scrollTop() < 0) return;

        var scrollTop       = $win.scrollTop(),
            documentHeight  = $doc.height(),
            windowHeight    = $win.height(),
            dwh             = documentHeight - windowHeight,
            extra           = (scrollTop > dwh) ? dwh - scrollTop : 0,
            newTop, containerBottom, stickyHeight, sticky;

        for (var i = 0; i < stickies.length; i++) {

            sticky = stickies[i];

            if (!sticky.element.is(":visible") || sticky.animate) {
                continue;
            }

            if (!sticky.check()) {

                if (sticky.currentTop !== null) {
                    sticky.reset();
                }

            } else {

                if (sticky.top < 0) {
                    newTop = 0;
                } else {
                    stickyHeight = sticky.element.outerHeight();
                    newTop = documentHeight - stickyHeight - sticky.top - sticky.options.bottom - scrollTop - extra;
                    newTop = newTop < 0 ? newTop + sticky.top : sticky.top;
                }

                if (sticky.boundary && sticky.boundary.length) {

                    var bTop = sticky.boundary.offset().top;

                    if (sticky.boundtoparent) {
                        containerBottom = documentHeight - (bTop + sticky.boundary.outerHeight()) + parseInt(sticky.boundary.css('padding-bottom'));
                    } else {
                        containerBottom = documentHeight - bTop - parseInt(sticky.boundary.css('margin-top'));
                    }

                    newTop = (scrollTop + stickyHeight) > (documentHeight - containerBottom - (sticky.top < 0 ? 0 : sticky.top)) ? (documentHeight - containerBottom) - (scrollTop + stickyHeight) : newTop;
                }


                if (sticky.currentTop != newTop) {

                    sticky.element.css({
                        "position" : "fixed",
                        "top"      : newTop,
                        "width"    : (typeof sticky.getWidthFrom !== 'undefined') ? BZ.$(sticky.getWidthFrom).width() : sticky.element.width(),
                        "left"     : sticky.wrapper.offset().left
                    });

                    if (!sticky.init) {

                        sticky.element.addClass(sticky.options.clsinit);

                        if (location.hash && scrollTop > 0 && sticky.options.target) {

                            var $target = BZ.$(location.hash);

                            if ($target.length) {

                                setTimeout((function($target, sticky){

                                    return function() {

                                        sticky.element.width(); // force redraw

                                        var offset       = $target.offset(),
                                            maxoffset    = offset.top + $target.outerHeight(),
                                            stickyOffset = sticky.element.offset(),
                                            stickyHeight = sticky.element.outerHeight(),
                                            stickyMaxOffset = stickyOffset.top + stickyHeight;

                                        if (stickyOffset.top < maxoffset && offset.top < stickyMaxOffset) {
                                            scrollTop = offset.top - stickyHeight - sticky.options.target;
                                            window.scrollTo(0, scrollTop);
                                        }
                                    };

                                })($target, sticky), 0);
                            }
                        }
                    }

                    sticky.element.addClass(sticky.options.clsactive).removeClass(sticky.options.clsinactive);
                    sticky.element.css('margin', '');

                    if (sticky.options.animation && sticky.init && !BZ.Utils.isInView(sticky.wrapper)) {
                        sticky.element.addClass(sticky.options.animation);
                    }

                    sticky.currentTop = newTop;
                }
            }

            sticky.init = true;
        }
    }

    return BZ.sticky;
})(BZkit);
(function(BZ) {
    "use strict";
    BZ.component('lazy', {

        defaults: {
            'target': null,
            'task': null
        },

        boot: function() {
            // init code
            BZ.ready(function(context) {

                BZ.$("img[data-bz-lazyloading]", context).each(function(){
					var a = BZ.$(this),
						s = a.data('bz-lazyloading');
					
					a.attr('src', s);                
                });
            });
        }
    })
})(BZkit);
