/*! BZkit 2.18.0 | http://www.getbzkit.com | (c) 2014 YOOtheme | MIT License */
(function(addon) {

    var component;

    if (window.BZkit) {
        component = addon(BZkit);
    }

    if (typeof define == "function" && define.amd) {
        define("bzkit-slideshow", ["bzkit"], function() {
            return component || addon(BZkit);
        });
    }

})(function(BZ) {

    "use strict";

    var Animations, playerId = 0;

    BZ.component('slideshow', {

        defaults: {
            animation        : "fade",
            duration         : 500,
            height           : "auto",
            start            : 0,
            autoplay         : false,
            autoplayInterval : 7000,
            videoautoplay    : true,
            videomute        : true,
            kenburns         : false,
            slices           : 15,
            pauseOnHover     : true,
			navigation		 : false
        },

        current  : false,
        interval : null,
        hovering : false,

        boot: function() {

            // init code
            BZ.ready(function(context) {

                BZ.$('[data-bz-slideshow]', context).each(function() {

                    var slideshow = BZ.$(this);

                    if (!slideshow.data("slideshow")) {
                        var obj = BZ.slideshow(slideshow, BZ.Utils.options(slideshow.attr("data-bz-slideshow")));
                    }
                });
            });
        },

        init: function() {

            var $this = this, canvas;

            this.container     = this.element.hasClass('bz-slideshow') ? this.element : BZ.$(this.find('.bz-slideshow'));
            this.slides        = this.container.children();
            this.slidesCount   = this.slides.length;
            this.current       = this.options.start;
            this.animating     = false;
			this.triggers 	   = this.find('[data-bz-slideshow-item]');
            this.fixFullscreen = navigator.userAgent.match(/(iPad|iPhone|iPod)/g) && this.container.hasClass('bz-slideshow-fullscreen'); // viewport unit fix for height:100vh - should be fixed in iOS 8
			
			if ( this.options.navigation && BZ.$(this.options.navigation) ) {
				this.triggers = BZ.$.merge(this.triggers, BZ.$(this.options.navigation).find('[data-bz-slideshow-item]'));
			}

            this.slides.each(function(index) {

                var slide = BZ.$(this),
                    media = slide.children('img,video,iframe').eq(0);

                slide.data('media', media);
                slide.data('sizer', media);

                if (media.length) {

                    var placeholder;

                    switch(media[0].nodeName) {
                        case 'IMG':

                            var cover = BZ.$('<div class="bz-cover-background bz-position-cover"></div>').css({'background-image':'url('+ media.attr('src') + ')'});

                            media.css({'width': '100%','height': 'auto'});
                            slide.prepend(cover).data('cover', cover);
                            break;

                        case 'IFRAME':

                            var src = media[0].src, iframeId = 'sw-'+(++playerId);

                            media
                                .attr('src', '').on('load', function(){

                                    if (index !== $this.current || (index == $this.current && !$this.options.videoautoplay)) {
                                        $this.pausemedia(media);
                                    }

                                    if ($this.options.videomute) {

                                        $this.mutemedia(media);

                                        var inv = setInterval((function(ic) {
                                            return function() {
                                                $this.mutemedia(media);
                                                if (++ic >= 4) clearInterval(inv);
                                            }
                                        })(0), 250);
                                    }

                                })
                                .data('slideshow', $this)  // add self-reference for the vimeo-ready listener
                                .attr('data-player-id', iframeId)  // add frameId for the vimeo-ready listener
                                .attr('src', [src, (src.indexOf('?') > -1 ? '&':'?'), 'enablejsapi=1&api=1&player_id='+iframeId].join(''))
                                .addClass('bz-position-absolute');

                            // disable pointer events
                            if(!BZ.support.touch) media.css('pointer-events', 'none');

                            placeholder = true;

                            if (BZ.cover) {
                                BZ.cover(media);
                                media.attr('data-bz-cover', '{}');
                            }

                            break;

                        case 'VIDEO':
                            media.addClass('bz-cover-object bz-position-absolute');
                            placeholder = true;

                            if ($this.options.videomute) $this.mutemedia(media);
                    }

                    if (placeholder) {

                        canvas  = BZ.$('<canvas></canvas>').attr({'width': media[0].width, 'height': media[0].height});
                        var img = BZ.$('<img style="width:100%;height:auto;">').attr('src', canvas[0].toDataURL());

                        slide.prepend(img);
                        slide.data('sizer', img);
                    }

                } else {
                    slide.data('sizer', slide);
                }
            });

			this.triggers.on("click.bzkit.slideshow" , function(e) {

                e.preventDefault();

                var slide = BZ.$(this).attr('data-bz-slideshow-item');

                if ($this.current == slide) return;

                switch(slide) {
                    case 'next':
                    case 'previous':
                        $this[slide=='next' ? 'next':'previous']();
                        break;
                    default:
                        $this.show(parseInt(slide, 10));
                }

                $this.stop();
            });
			
			/*
            this.on("click.bzkit.slideshow", '[data-bz-slideshow-item]', function(e) {

                e.preventDefault();

                var slide = BZ.$(this).attr('data-bz-slideshow-item');

                if ($this.current == slide) return;

                switch(slide) {
                    case 'next':
                    case 'previous':
                        $this[slide=='next' ? 'next':'previous']();
                        break;
                    default:
                        $this.show(parseInt(slide, 10));
                }

                $this.stop();
            });
			*/

            // Set start slide
            this.slides.attr('aria-hidden', 'true').eq(this.current).addClass('bz-active').attr('aria-hidden', 'false');
            this.triggers.filter('[data-bz-slideshow-item="'+this.current+'"]').addClass('bz-active');

            BZ.$win.on("resize load", BZ.Utils.debounce(function() {
                $this.resize();

                if ($this.fixFullscreen) {
                    $this.container.css('height', window.innerHeight);
                    $this.slides.css('height', window.innerHeight);
                }
            }, 100));

            this.resize();

            // Set autoplay
            if (this.options.autoplay) {
                this.start();
            }

            if (this.options.videoautoplay && this.slides.eq(this.current).data('media')) {
                this.playmedia(this.slides.eq(this.current).data('media'));
            }

            if (this.options.kenburns) {
                this.applyKenBurns(this.slides.eq(this.current));
            }

            this.container.on({
                mouseenter: function() { if ($this.options.pauseOnHover) $this.hovering = true;  },
                mouseleave: function() { $this.hovering = false; }
            });

            this.on('swipeRight swipeLeft', function(e) {
                $this[e.type=='swipeLeft' ? 'next' : 'previous']();
            });

            this.on('display.bz.check', function(){
                if ($this.element.is(":visible")) {

                    $this.resize();

                    if ($this.fixFullscreen) {
                        $this.container.css('height', window.innerHeight);
                        $this.slides.css('height', window.innerHeight);
                    }
                }
            });
        },


        resize: function() {

            if (this.container.hasClass('bz-slideshow-fullscreen')) return;

            var $this = this, height = this.options.height;

            if (this.options.height === 'auto') {

                height = 0;

                this.slides.css('height', '').each(function() {
                    height = Math.max(height, BZ.$(this).height());
                });
            }

            this.container.css('height', height);
            this.slides.css('height', height);
        },

        show: function(index, direction) {

            if (this.animating) return;

            this.animating = true;

            var $this        = this,
                current      = this.slides.eq(this.current),
                next         = this.slides.eq(index),
                dir          = direction ? direction : this.current < index ? -1 : 1,
                currentmedia = current.data('media'),
                animation    = Animations[this.options.animation] ? this.options.animation : 'fade',
                nextmedia    = next.data('media'),
                finalize     = function() {

                    if (!$this.animating) return;

                    if (currentmedia && currentmedia.is('video,iframe')) {
                        $this.pausemedia(currentmedia);
                    }

                    if (nextmedia && nextmedia.is('video,iframe')) {
                        $this.playmedia(nextmedia);
                    }

                    next.addClass("bz-active").attr('aria-hidden', 'false');
                    current.removeClass("bz-active").attr('aria-hidden', 'true');

                    $this.animating = false;
                    $this.current   = index;

                    BZ.Utils.checkDisplay(next, '[class*="bz-animation-"]:not(.bz-cover-background.bz-position-cover)');

                    $this.trigger('show.bz.slideshow', [next]);
                };

            $this.applyKenBurns(next);

            // animation fallback
            if (!BZ.support.animation) {
                animation = 'none';
            }

            current = BZ.$(current);
            next    = BZ.$(next);

            Animations[animation].apply(this, [current, next, dir]).then(finalize);

            $this.triggers.removeClass('bz-active');
            $this.triggers.filter('[data-bz-slideshow-item="'+index+'"]').addClass('bz-active');
        },

        applyKenBurns: function(slide) {

            if (!this.hasKenBurns(slide)) {
                return;
            }

            var animations = [
                    'bz-animation-middle-left',
                    'bz-animation-top-right',
                    'bz-animation-bottom-left',
                    'bz-animation-top-center',
                    '', // middle-center
                    'bz-animation-bottom-right'
                ],
                index = this.kbindex || 0;


            slide.data('cover').attr('class', 'bz-cover-background bz-position-cover').width();
            slide.data('cover').addClass(['bz-animation-scale', 'bz-animation-reverse', 'bz-animation-15', animations[index]].join(' '));

            this.kbindex = animations[index + 1] ? (index+1):0;
        },

        hasKenBurns: function(slide) {
            return (this.options.kenburns && slide.data('cover'));
        },

        next: function() {
            this.show(this.slides[this.current + 1] ? (this.current + 1) : 0);
        },

        previous: function() {
            this.show(this.slides[this.current - 1] ? (this.current - 1) : (this.slides.length - 1));
        },

        start: function() {

            this.stop();

            var $this = this;

            this.interval = setInterval(function() {
                if (!$this.hovering) $this.show($this.options.start, $this.next());
            }, this.options.autoplayInterval);

        },

        stop: function() {
            if (this.interval) clearInterval(this.interval);
        },

        playmedia: function(media) {

            if (!(media && media[0])) return;

            switch(media[0].nodeName) {
                case 'VIDEO':

                    if (!this.options.videomute) {
                        media[0].muted = false;
                    }

                    media[0].play();
                    break;
                case 'IFRAME':

                    if (!this.options.videomute) {
                        media[0].contentWindow.postMessage('{ "event": "command", "func": "unmute", "method":"setVolume", "value":1}', '*');
                    }

                    media[0].contentWindow.postMessage('{ "event": "command", "func": "playVideo", "method":"play"}', '*');
                    break;
            }
        },

        pausemedia: function(media) {

            switch(media[0].nodeName) {
                case 'VIDEO':
                    media[0].pause();
                    break;
                case 'IFRAME':
                    media[0].contentWindow.postMessage('{ "event": "command", "func": "pauseVideo", "method":"pause"}', '*');
                    break;
            }
        },

        mutemedia: function(media) {

            switch(media[0].nodeName) {
                case 'VIDEO':
                    media[0].muted = true;
                    break;
                case 'IFRAME':
                    media[0].contentWindow.postMessage('{ "event": "command", "func": "mute", "method":"setVolume", "value":0}', '*');
                    break;
            }
        }
    });

    Animations = {

        'none': function() {

            var d = BZ.$.Deferred();
            d.resolve();
            return d.promise();
        },

        'scroll': function(current, next, dir) {

            var d = BZ.$.Deferred();

            current.css('animation-duration', this.options.duration+'ms');
            next.css('animation-duration', this.options.duration+'ms');

            next.css('opacity', 1).one(BZ.support.animation.end, function() {

                current.removeClass(dir === 1 ? 'bz-slideshow-scroll-backward-out' : 'bz-slideshow-scroll-forward-out');
                next.css('opacity', '').removeClass(dir === 1 ? 'bz-slideshow-scroll-backward-in' : 'bz-slideshow-scroll-forward-in');
                d.resolve();

            }.bind(this));

            current.addClass(dir == 1 ? 'bz-slideshow-scroll-backward-out' : 'bz-slideshow-scroll-forward-out');
            next.addClass(dir == 1 ? 'bz-slideshow-scroll-backward-in' : 'bz-slideshow-scroll-forward-in');
            next.width(); // force redraw

            return d.promise();
        },

        'swipe': function(current, next, dir) {

            var d = BZ.$.Deferred();

            current.css('animation-duration', this.options.duration+'ms');
            next.css('animation-duration', this.options.duration+'ms');

            next.css('opacity', 1).one(BZ.support.animation.end, function() {

                current.removeClass(dir === 1 ? 'bz-slideshow-swipe-backward-out' : 'bz-slideshow-swipe-forward-out');
                next.css('opacity', '').removeClass(dir === 1 ? 'bz-slideshow-swipe-backward-in' : 'bz-slideshow-swipe-forward-in');
                d.resolve();

            }.bind(this));

            current.addClass(dir == 1 ? 'bz-slideshow-swipe-backward-out' : 'bz-slideshow-swipe-forward-out');
            next.addClass(dir == 1 ? 'bz-slideshow-swipe-backward-in' : 'bz-slideshow-swipe-forward-in');
            next.width(); // force redraw

            return d.promise();
        },

        'scale': function(current, next, dir) {

            var d = BZ.$.Deferred();

            current.css('animation-duration', this.options.duration+'ms');
            next.css('animation-duration', this.options.duration+'ms');

            next.css('opacity', 1);

            current.one(BZ.support.animation.end, function() {

                current.removeClass('bz-slideshow-scale-out');
                next.css('opacity', '');
                d.resolve();

            }.bind(this));

            current.addClass('bz-slideshow-scale-out');
            current.width(); // force redraw

            return d.promise();
        },

        'fade': function(current, next, dir) {

            var d = BZ.$.Deferred();

            current.css('animation-duration', this.options.duration+'ms');
            next.css('animation-duration', this.options.duration+'ms');

            next.css('opacity', 1);

            current.one(BZ.support.animation.end, function() {

                current.removeClass('bz-slideshow-fade-out');
                next.css('opacity', '');
                d.resolve();

            }.bind(this));

            current.addClass('bz-slideshow-fade-out');
            current.width(); // force redraw

            return d.promise();
        }
    };

    BZ.slideshow.animations = Animations;

    // Listen for messages from the vimeo player
	/*
    window.addEventListener('message', function onMessageReceived(e) {
        var data = JSON.parse(e.data), iframe;

        if (e.origin && e.origin.indexOf('vimeo') > -1 && data.event == 'ready' && data.player_id) {
            iframe = BZ.$('[data-player-id="'+ data.player_id+'"]');

            if (iframe.length) {
                iframe.data('slideshow').mutemedia(iframe);
            }
        }
    }, false);
	*/

});
