<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz helper class.
 *
 * This class acts as parent for all helper classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BzControllerBook extends BController 
{
	public function nextstep()
	{
		$model		= $this->getModel('Book');
		$input 		= $this->app->input;
		$data  		= $input->get('book', '', 'array');
		
		// get the form for validation
		$form 		= $model->getForm($data, false);
		$page		= $model->getCurrentPage();

		if (!$form)
		{
			# NOTE - Error here
			//$app->enqueueMessage($model->getError(), 'error');

			return false;
		}
			
		// lets validate the data
		$validData = $model->validate($form, $data);
		
		// did we find some errors
		if ($validData === false)
		{
			// Get the validation messages.
			$errors = $model->getErrors();

			// Push up to three validation messages out to the user.
			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++)
			{
				if ($errors[$i] instanceof Exception)
				{
				//	$app->enqueueMessage($errors[$i]->getMessage(), 'warning');
				}
				else
				{
				//	$app->enqueueMessage($errors[$i], 'warning');
				}
			}
			
			// if config says we want errors by field then we
			// shoul let the next page know there are errors
			if ( $this->app->config->get('bookerrors', 1) == 1 ) {
				$this->app->adapter->sessionSet('bookzo.book.errors', true);
			}
			
			// Add data into the session
			$newdata	= $this->app->registry->create($data);
			$olddata	= $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.book.data') );
		
			$olddata->merge($newdata);
			
			$this->app->adapter->sessionSet('bookzo.book.pagechecked', $page - 1);
			$this->app->adapter->sessionSet('bookzo.book.data', $olddata->toString());

			// Redirect back to the same page
		//	$this->app->log->write('Booking', 'Errors on page ' . $page . ' redirecting to page ' . $this->app->route->route('layout=book&bookpage='.$page, false), '', 'reservations' );
			return $this->app->adapter->redirect(
				$this->app->route->route('layout=book&bookpage='.$page, false)
			);

			return false;
		}
		
		// valid lets merge old and new
		$newdata	= $this->app->registry->create($data);
		$olddata	= $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.book.data') );
		
		$olddata->merge($newdata);
		
		// readd it to the session
		$this->app->adapter->sessionSet('bookzo.book.pagechecked', $page);		
		$this->app->adapter->sessionSet('bookzo.book.data', $olddata->toString() );
		
		## NOTE - For now testing onlu
		$totalpages = $model->getTotalSteps();
				
		if ( $totalpages == $page )
		{
		//	$this->app->log->write('Booking', 'All pages correct go to confirmation page', '', 'reservations' );
			return $this->confirmBooking($olddata);
		}

		// redirect to next page
	//	$this->app->log->write('Booking', 'Page ' . $page . ' correct redirecting to page ' . $this->app->route->route('layout=book&bookpage='.($page + 1), false), '', 'reservations' );
		return $this->app->adapter->redirect(
			$this->app->route->route('layout=book&bookpage='.($page + 1), false)
		);
	}
	
	public function confirmBooking($data)
	{
		// get needed objects
		$model		= $this->getModel('Book');
		$booking 	= $model->getBooking();
		$object		= $model->getObject();
		$state		= $model->getState();

		// build fields for booking
		$fields		= array();
		$fields['Comments'] 	= $data->get('remarks.remarks');
		
		if  ( $data->get('remarks.givemediscount', 0) ) {
			$fields['Comments'] .= !empty($fields['Comments']) ? ". " : '';
			$fields['Comments'] .= BText::_('FIELD_BOOK_GIVEMEDISCOUNT_LABEL'); 
		}
		
		if  ( $this->app->config->get('book.show_licenseplate', 0) && $data->get('guest.car', 0) && $data->get('guest.licenseplate') ) {
			$fields['Comments'] .= !empty($fields['Comments']) ? ". " : '';
			$fields['Comments'] .= 'Kenteken '. $data->get('guest.licenseplate'); 
		}
		
		$fields['WhereFound'] 	= $data->get('remarks.knowfrom');
		$fields['Arrival'] 		= $data->get('details.arrival');
		$fields['Departure'] 	= $data->get('details.departure');
		$fields['ObjectId']		= $state->get('object');
		$fields['Adults'] 		= $data->get('details.persons');
		$fields['Childs'] 		= $data->get('details.childs', 0);
		$fields['Babies'] 		= $data->get('details.babys', 0);
		$fields['Seniors'] 		= $data->get('details.seniors', 0);
		$fields['Pets'] 		= $data->get('details.pets');
		$fields['CouponCode']	= $data->get('details.coupon');
		$fields['LanguageId']	= $this->app->language->getId();
		
		
		$costs = array();
		foreach ( $data->get('items', array()) as $k => $v ) {
			$costs[] = $k .','.$v;
		}
		$fields['Costs'] 						= implode(',', $costs);
		$fields['CustomerSalutation']			= BText::_('FIELD_BOOK_SALUTATION_OPTION_' . $data->get('guest.salutation'));
		$fields['CustomerFirstName']			= $data->get('guest.firstname');
		$fields['CustomerMiddleName']			= $data->get('guest.middlename');
		$fields['CustomerLastName']				= $data->get('guest.lastname');
		$fields['CustomerStreet'] 				= $data->get('guest.street');
		$fields['CustomerHouseNumber'] 			= $data->get('guest.housenr.housenr');
		$fields['CustomerHouseNumberAddition'] 	= $data->get('guest.housenr.suffix');
		$fields['CustomerPhone'] 				= $data->get('guest.phone');
		$fields['CustomerMobile'] 				= $data->get('guest.mobile');
		$fields['CustomerEmail'] 				= $data->get('guest.email');
		$fields['CustomerPostalCode'] 			= $data->get('guest.zipcode');
		$fields['CustomerCity'] 				= $data->get('guest.city');
		$fields['CustomerCountry']				= $data->get('guest.country');
		
		$guests = array();
		foreach ( $data->get('guests', array() ) as $g ) {
			$g  	  = (object) $g;
			$guests[] = str_replace(',', '', $g->name) .','.$this->app->date->create($g->birthday)->format('Y-m-d');
		}
		$fields['Guests'] = implode(',', $guests);
		
		// do we use payments
		if ( $model->paymentActive() ) 
		{
			$methods 	= $this->app->targetpay->getPaymentMethods();
			$defmethod  = count($methods) > 1 ? '' : reset($methods);
			$method 	= $data->get('pay.method', $defmethod);
			$amount 	= ceil(( (float) $booking->get('prepaymentamount') ) * 100);
			
			// add amount to session for later use in processing payment
			$data->set('pay.amount', $amount);
			$this->app->adapter->sessionSet('bookzo.book.data', $data->toString() );	
			
			$fields['TargetPayPaymentMethod'] = $method;
			$fields['TargetPayLayoutCode']	  = $this->app->config->get('bookzo.onlinepaymentlogin');
			$fields['TargetPayAmountToPay']	  = $amount;
			$fields['TargetPayDescription']	  = BText::sprintf('BOOKING_PAY_DESCRIPTION', $object->translate('name'));
			$fields['TargetPayReturnUrl']	  = $this->app->adapter->route('layout=book&task=book.processpayment', false, true);
			$fields['TargetPayReportUrl']	  = $this->app->adapter->route('layout=book&task=book.reportpayment', false, true);
			if ( $method == 'IDeal' ) {
				$fields['TargetPayIdealBankId'] = $data->get('pay.issuer');
			}
			if ( $method == 'MrCash' || $method == 'DirectBanking' ) {
				$fields['TargetPayUserIp']		= $this->app->targetpay->$method->get('ip');
			}
			if ( $this->app->config->get('pay.test', 1) ) {
				$fields['TargetPayTest']			= 1;
			}
		}
		
		// book
		$result = $this->app->api->book($fields);
		
		if ( $result === false ) {
			$this->app->log->write('Booking', 'Failed', '', 'reservations');
			
			$this->app->setUserState('bookzo.page', 1);
			$this->app->adapter->sessionClear('bookzo.book.pagechecked');
			$this->app->adapter->sessionClear('bookzo.book.data');
			$this->app->adapter->sessionClear('bookzo.book.query');
			$this->app->cache->clear('periodqueries');
				
			$this->app->adapter->sessionSet('bookzo.ordersuccess', 0);
			
			// set google dm session
			$this->app->adapter->sessionSet('bookzo.orderdetails', array('success' => false));
			
			return $this->app->adapter->redirect(
				$this->app->route->route('layout=confirmation', false)
			);
		}
		else 
		{
			if ( $model->paymentActive() && $method != 'OVerboeken' && isset($result->targetpayurl) ) {
				
				$this->app->log->write('Targetpay', 'Redirecting', '', 'reservations');
				$this->app->adapter->redirect($result->targetpayurl);

				die();
			}
			else {
				
				// reset data
				$this->app->log->write('Booking', 'Success', '', 'reservations');
				$this->app->setUserState('bookzo.page', 1);
				
				// set google dm session
				$this->app->adapter->sessionSet('bookzo.orderdetails', 
					array('success' => true, 'total' => $result->total, 'object' => $state->get('object'), 
						  'arrival' => $data->get('details.arrival'), 'departure' => $data->get('details.departure') )
				);
				
				// clear data				
				$this->app->adapter->sessionClear('bookzo.book.pagechecked');
				$this->app->adapter->sessionClear('bookzo.book.data');
				$this->app->adapter->sessionClear('bookzo.book.query');
				$this->app->cache->clear('periodqueries');
							
				// go to confirmation
				$this->app->adapter->sessionSet('bookzo.ordersuccess', 1);
				$this->app->adapter->sessionSet('bookzo.ordernr', $result->reservationnumber);
				$this->app->adapter->sessionSet('bookzo.ordertotal', $result->total);
				
				// ask adapter to handle booking if they want
				$this->app->adapter->afterBooking( $data );
				
				
				// add payment status for Overboeken or failed startup at bookzo api
				if ( $model->paymentActive() ) {
					$this->app->adapter->sessionSet('bookzo.paymentsuccess', 	$method == 'OVerboeken');
					$this->app->adapter->sessionSet('bookzo.paymentmethod', 	$method);
				}
				
				return $this->app->adapter->redirect(
					$this->app->route->route('layout=confirmation', false)
				);
			}
			
			
		}
	}
	
	public function reportpayment()
	{
		$trxid 		= $this->app->input->get('trxid', '', 'string');
		$rtlo		= $this->app->input->get('rtlo', '', 'string');
		$status 	= $this->app->input->get('status', '', 'string');
			
		if ( $trxid ) {
			$this->app->log->write('Targetpay', 'Report: TRXID = '. $trxid .', RTLO = '.$rtlo. ', STATUS = ' . $status, '', 'reservations');
		}
		else {
			$this->app->log->write('Targetpay', 'Report: No Trixid', '', 'reservations');
		}
		
		die();
	}
	
	public function processpayment()
	{
		$data		= $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.book.data') );
		
		$trxid 		= $this->app->input->get('trxid', '', 'string');
		$eid		= $this->app->input->get('ec');
		$method 	= $data->get('pay.method');
		$amount		= $data->get('pay.amount');
		$amount		= (int) $amount / 100;
		$success 	= false;
		
		// log 
		$this->app->log->write('Targetpay', 'Processing', '', 'reservations');
		$this->app->log->write('Targetpay', 'TRXID ' . $trxid, '', 'reservations');
		
		// is method still available
		if ( $method ) {
			$success = $this->app->targetpay->$method->validatePayment($trxid, 1, $this->app->config->get('pay.test'));
		}
		// if not loop all methods
		else {
			$methods = $this->app->targetpay->getPaymentMethods();
			
			foreach ( $mehods as $method )
			{
				$method  = strtolower($method);
				$success = $this->app->targetpay->$method->validatePayment($trxid, 1, $this->app->config->get('pay.test'));
				
				if ( $success ) {
					break;
				}
			}
		}
		
		// log
		if ( $success ) {
			$this->app->log->write('Targetpay', 'Success', '', 'reservations');
		}
		else {
			$this->app->log->write('Targetpay', 'No Success', '', 'reservations');
		}
		
		// if success register the payment
		if ( $success ) {
			$this->app->log->write('Targetpay', 'Updating bookzo status', '', 'reservations');
			$this->app->api->addPayment($trxid, $amount, 'Online targetpay betaling');
		}
		
		// for now just redirect to confirmation page
		## NOTE we should add message for payment success or not
		$this->app->log->write('Booking', 'Success', '', 'reservations');
		$this->app->setUserState('bookzo.page', 1);
		
		$this->app->adapter->sessionClear('bookzo.book.pagechecked');
		$this->app->adapter->sessionClear('bookzo.book.data');
		$this->app->adapter->sessionClear('bookzo.book.query');
		$this->app->cache->clear('periodqueries');
					
		// go to confirmation
		$this->app->adapter->sessionSet('bookzo.ordersuccess', 1);
		$this->app->adapter->sessionSet('bookzo.paymentsuccess', (int) $success);
		
		$this->app->log->write('Booking', 'Redirecting to ' . $this->app->route->route('layout=confirmation', false), '', 'reservations'); 
		
		return $this->app->adapter->redirect(
			$this->app->route->route('layout=confirmation', false)
		);
		
	}
	
	public function previousstep()
	{
		$model		= $this->getModel('Book');
		$page		= $model->getCurrentPage();
		$previous	= $page > 1 ? $page - 1 : 1;
				
		//$this->app->log->write('Booking', 'User browsing one page back to page ' . $this->app->route->route('layout=book&bookpage='.$previous, false), '', 'reservations' );
		
		// redirect to next page
		return $this->app->adapter->redirect(
			$this->app->route->route('layout=book&bookpage='.$previous, false)
		);
	}
	
	public function cancel()
	{
		// default url
		$url = $this->app->route->route('layout=results', false);
		
		// try to get the old query for redirecting
		$query = $this->app->registry->create(
					$this->app->adapter->sessionGet('bookzo.book.query')
				);
		
		// do we still have an object
		if ( $oid = ((int) $query->get('object')) ) {
			if ( $object = $this->app->api->getObjects($oid) ) {
				$url = $this->app->route->route($object->getLink(false), false);
			}
		}

		// reset booking
		$this->app->setUserState('bookzo.page', 1);
		$this->app->adapter->sessionClear('bookzo.book.pagechecked');
		$this->app->adapter->sessionClear('bookzo.book.data');
		$this->app->adapter->sessionClear('bookzo.book.query');
		
		// redirect to url found
		return $this->app->adapter->redirect( $url );
	}
	
	# NOTE - We might want to try to set alternatives here
	public function request()
	{
		// get the search variables
		$search		= $this->app->adapter->sessionGet('bookzo.search.options', array());
		$input 		= $this->app->input;
		$object		= $input->getInt('object');
		$arrival 	= $input->getCmd('arrival');
		$departure	= $input->getCmd('departure');
		$persons 	= $input->getCmd('persons', isset($search['persons']) ? $search['persons'] : 2);
		$pets	 	= $input->getCmd('pets', 	isset($search['pets']) ? $search['pets'] : 0);
		$exact		= $departure && $input->getCmd('persons');

		// If departure not set we need to get first possible value
		if ( !$departure ) 
		{
			$departures = $this->app->api->getDepartures($arrival, 0, 0, 0, $object);
			if ( $departures ) {
				$departure = $this->app->array->first($departures);
			}
		}
		
		// get model
		$model 		= $this->getModel();
		
		// data to store
		$fields		= array('object' => $object, 'arrival' => $arrival, 'departure' => $departure, 'persons' => $persons, 'pets' => $pets, 'exact' => $exact);
		
		$query		= $this->app->registry->create( $fields );
		$data 		= $this->app->registry->create( array('details' => $fields) );
		
		// store data in the session
		$this->app->setUserState('bookzo.page', 1);
		$this->app->adapter->sessionSet('bookzo.book.pagechecked', 0);
		$this->app->adapter->sessionSet('bookzo.book.data',  $data->toString() );
		$this->app->adapter->sessionSet('bookzo.book.query', $query->toString() );
		
		// redirect to search page
		## NOTE - should we add page 1 think so
		return $this->app->adapter->redirect(
			$this->app->route->route('layout=book&bookpage=1', false)
		);
	}	
}