<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz helper class.
 *
 * This class acts as parent for all helper classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BzControllerResults extends BController {
	
	# NOTE - We might want to try to set alternatives here
	// in a way it is impossible to not find anything
	// for instance if arrival is not set find first arrival in selected month
	// if departure or type not set find new one etc.
	public function search()
	{
		## NOTE - 2. we have to take a better look at this one.
		
		
		// get the search variables
		## NOTE - 3. we need to set these values in session
		$input 			= $this->app->input;
		$group 			= $input->getInt('group');
		$arrival 		= $input->getCmd('arrival');
		$departure		= $input->getCmd('departure');
		$month			= $input->getCmd('month');
		$persons		= $input->getInt('persons');
		$pets			= $input->getInt('pets');
		$duration		= $input->getCmd('duration');
		$inlinesearch 	= $input->getInt('inlinesearch', 0);
				
		// get model
		$model 		= $this->getModel();
		
		// store data in the session
		## NOTE - Why not use search[group] etc.
		$this->app->adapter->sessionSet('bookzo.pagetype', 'search');
		$this->app->adapter->sessionSet('bookzo.search.options', 
			array('group' => $group, 'persons' => $persons, 'arrival' => $arrival, 'departure' => $departure, 'month' => $month, 'duration' => $duration, 'pets' => $pets)
		);
		
		// also remove old search results
		$this->app->setUserState('results.limitstart', 0);
		$this->app->adapter->sessionClear('bookzo.search.results');
		$this->app->adapter->sessionClear('bookzo.calendar.values');
		
		// by default remove filters on new search 
		$this->app->adapter->sessionClear('bookzo.results.filters');
		
		// reapply them if they are set
		$filters = $this->app->input->get('filters', array(), 'array');
		if ( count($filters) ) {
			$this->app->adapter->sessionSet('bookzo.results.filters', $filters);
		}
		
		// set parts for new url
		$parts		= array();
		$query		= array();
		
		$parts[] = 'persons='. $persons;
		$query['persons'] = $persons;
		
		if ( $group ) {
			$parts[] = 'group='. $group;
			$query['group'] = $group;
		}
		
		if ( $pets ) {
			$parts[] = 'pets='. $pets;
			$query['pets'] = $pets;
		}
		
		// determine arrival
		if ( !$arrival ) 
		{
			## NOTE Raise Error
			## NOTE - enquemessage $this->app->adapter->enqueuemessage or find first one
		}
		
		$parts[]			= 'arrival='.$arrival;
		$query['arrival'] 	= $arrival;
		
		if ( !$departure )
		{
			if ( $duration ) 
			{
				$departure			= $model->getDeparture($arrival, $duration);
				$parts[]			= 'departure='.$departure;
				$query['departure'] = $departure;
			}
			else {
				## NOTE Raise Error
				## NOTE - enquemessage $this->app->adapter->enqueuemessage or find first one
			}
		}
		else {
			$parts[]			= 'departure='.$departure;
			$query['departure'] = $departure;
		}
		
		## NOTE only temporary
		$lastminutes	= $input->getInt('lastminutes', 0);
		if ( $lastminutes == 1 ) {
			$query['lastminutes'] = 1;
		}
		

		// also store real query data in the session
		$this->app->adapter->sessionSet('bookzo.search.query', $query);	
		
		$values = $this->app->adapter->sessionGet('bookzo.search.query');
	
		
		// get new url		
		$new = $this->app->route->route('layout=results&'. implode('&', $parts), false);
	
		// redirect to search page
		return $this->app->adapter->redirect($new);
	}
	
	public function filter()
	{
		$reset	 = $this->app->input->get('reset', 0);
		if ( $reset ) {
			$this->app->adapter->sessionClear('bookzo.results.filters');
		}
		
		$filters = $this->app->input->get('filters', array(), 'array');
		
		// add them to the stack
		$this->app->adapter->sessionSet('bookzo.results.filters', $filters);
		
		# NOTE - Kinda silly		
		// redirect to current page
		$query 	 = $this->app->adapter->sessionGet('bookzo.search.query');
				
		return $this->app->adapter->redirect(
					$this->app->route->route('layout=results&'. $this->app->array->toUrl($query), false)
				);
	}
}