<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
abstract class BAdapter extends BObject implements BAdapterInterface {

	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected static $adapter;
		
	
	public static function getInstance($app)
	{
		if ( is_null(self::$adapter) ) 
		{	
			$app->config->get('general.cms');

			if ( $name = $app->config->get('general.cms') )
			{
				$name 		= strtolower($name);
				$classname 	= 'BzAdapter'. ucfirst($name);
				
				if ( $adapter = $app->loader->register($classname, 'adapters:'.$name.'.php')->get($classname) ) 
				{
					if ( $adapter->valid() ) {
						self::$adapter = $adapter;
					}
					else {
						self::$adapter = self::autoload($app);
					}	
				}
			}
			else {
				self::$adapter = self::autoload($app);
			}
		}
		
		return self::$adapter;
	}
	
	public function getCMS()
	{
		return strtolower(str_replace('BzAdapter', '', get_class($this)));
	}
	
	protected static function autoload($app)
	{
		$adapters = self::getAdapters($app);
		
		// do we have adapter files
		if ( !count($adapters) )
		{
			throw new BAdapterException('No adapters found');
		}
		
		// loop all found
		foreach ( $adapters as $name )
		{
			$classname 	= 'BzAdapter'. ucfirst($name);
			
			if ( $adapter = $app->loader->register($classname, 'adapters:'.$name.'.php')->get($classname) ) 
			{
				// is it a valid one
				if ( $adapter->valid() ) 
				{
					// it is store it for future references 
					## NOTE - Why not have a helper class and have $app->config->store();
					$app->config->set('general.cms', $name);
					$app->filesystem->file->write(BOOKZO_ROOT . '/config/bookzo.config', (string) $app->config );
		
					return $adapter;
				}
			}
		}
		
		// nothing found throw an error
		throw new BAdapterException('No valid adapters found');
	}
	
	protected static function getAdapters($app)
	{
		// get all register adapter files
		$files 	 = $app->path->ls('adapters:', 'file', false, '/\.php/');
		$return  = array();
		
		foreach ( $files as $filename ) 
		{
			$return[] = strtolower(str_replace('.php', '', $filename));
		}
		
		return $return;
	}
}

interface BAdapterInterface {
	
	public function valid();
		
	public function addStyleSheet($path, $external = false, $addversion = true);
	
	public function addScript($path, $external = false, $addversion = true);
	
	public function route($link, $xhtml = true);
	
	public function redirect($link, $status = 303);
	
	public function sessionSet($name, $value = null, $namespace = 'bookzo');
	
	public function sessionHas($name, $namespace = 'bookzo');
	
	public function sessionGet($name, $default = null, $namespace = 'bookzo');
	
	public function sessionClear($name, $namespace = 'bookzo');
	
	public function sessionNew();
	
	public function addPaths();
	
	/* new */
	public function sessionDestroy();
	
	public function getLanguage();
	
	public function isAdmin();
	
	public function isHomepage();
	
	public function isBookzoPage();
	
	public function setMetaData($type, $value);
	
	public function afterBooking($booking);
	
	public function bookzoInit();
	
}

/**
 * The exception class dedicated for the controller classes
 *
 * @see AppController
 */
class BAdapterException extends BRuntimeException {}