<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Form
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Form Field class for the Joomla Platform.
 * Supports a generic list of options.
 *
 * @package     Bookzo.Platform
 * @subpackage  Form
 * @since       11.1
 */
abstract class BFormFieldList extends BFormField
{
	/**
	 * The form field type.
	 *
	 * @var    string
	 * @since  11.1
	 */
	protected $type = 'List';
	
	public function addOption($value, $text = null, $attr = array(), $translate = true)
	{
		if ( is_null($text) ) {
			$text = $value;
		}
		
		$text	= $translate ? BText::_($text) : $text;
		$attr	= (array) $attr;
		
		$option = $this->element->addChild('option', $text);
		$option->addAttribute('value', $value);
		
		foreach ( $attr as $k => $v ) {
			if ( !(ctype_digit(strval($k))) && strtolower($k) != 'value' ) {
				$option->addAttribute($k, $v);
			}
		}
		
		return $this;
	}
	
	/**
	 * Method to get the field options.
	 *
	 * @return  array  The field option objects.
	 *
	 * @since   11.1
	 */
	abstract protected function getOptions();
}
