<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Form
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Form Field class for the Joomla Platform.
 * Supports a generic list of options.
 *
 * @package     Bookzo.Platform
 * @subpackage  Form
 * @since       11.1
 */
abstract class BFormFieldRowsSelect extends BFormFieldSelect
{
	/**
	 * The colors.
	 *
	 * @var    mixed
	 * @since  3.2
	 */
	protected $inlinelabel = false;
	
	/**
	 * Method to get the field input markup for a generic list.
	 * Use the multiple attribute to enable multiselect.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   11.1
	 */
	protected function getInput()
	{
		$html = array();
		$attr = '';

		// Initialize some field attributes.
		$datastring = $this->getAttribute('datastring');
		$attr .= !empty($this->class) 	? ' class="' . $this->class . '"' : '';
		$attr .= !empty($this->size) 	? ' size="' . $this->size . '"' : '';
		$attr .= $this->multiple 		? ' multiple' : '';
		$attr .= $this->required 		? ' required aria-required="true"' : '';
		$attr .= $this->autofocus 		? ' autofocus' : '';
		$attr .= !empty($datastring)  	? ' '. $datastring .' ' : '';

		// To avoid user's confusion, readonly="true" should imply disabled="true".
		if ((string) $this->readonly == '1' || (string) $this->readonly == 'true' || (string) $this->disabled == '1'|| (string) $this->disabled == 'true')
		{
			$attr .= ' disabled="disabled"';
		}

		// Initialize JavaScript field attributes.
		$attr .= $this->onchange ? ' onchange="' . $this->onchange . '"' : '';

		// Get the field options.
		$options = (array) $this->getOptions();
		$values  = (array) $this->value;
		$keys 	 = $this->getKeys();
		
		foreach ( $keys as $key )
		{
			if ( isset($key->value) ) 
			{
				$value = isset($values[$key->value]) ? $values[$key->value] : null;
				$label = isset($key->text) && ( (string) $this->inlinelabel == '1' || (string) $this->inlinelabel == 'true' ) 
					   ? $key->text
					   : false;
					   
				// Create a read-only list (no name) with a hidden input to store the value.
				if ((string) $this->readonly == '1' || (string) $this->readonly == 'true')
				{
					$html[] = '<div class="bz-grid">';
					if ( $label ) {
						$html[] = '<div class="bz-width-1-3">'.$input . ' '.  $label.'</div>';
					}
					$html[] = '<div class="bz-width-'. ($label ? '1-3' : '3-3') . '">';
					$html[] = BHtml::_('select.genericlist', '', $options, $value, trim($attr), $this->id . '-' . $key->value, 'value', 'text');
					$html[] = '<input type="hidden" name="' . $this->name . '['.$key->value.']" value="' . htmlspecialchars($value, ENT_COMPAT, 'UTF-8') . '"/>';
					$html[] = '</div>';
					$html[] = '</div>';
					
				}
				else
				// Create a regular list.
				{
					$html[] = '<div class="bz-grid">';
					if ( $label ) {
						$html[] = '<div class="bz-width-1-6">'.$label.'</div>';
					}
					$html[] = '<div class="bz-width-'. ($label ? '5-6' : '6-6') . '">';
					$html[] = BHtml::_('select.genericlist', $this->name . '['.$key->value.']', $options, $value, trim($attr), $this->id . '-' . $key->value, 'value', 'text');
					$html[] = '</div>';
					$html[] = '</div>';
				}
			}				
		}

		return implode($html);
	}
	
	protected function getOptions()
	{
		$options = array();

		try {
			
			// render the widget
			$app 		= Bookzo::getInstance();
			$languages 	= $app->path->getPaths('languages');
			$options	= array();
			
			/*foreach ( $countries as $country )
			{
				$options[$country->get('name')] = BHtml::_('select.option', $country->get('id'), $country->get('name'));
			}*/
			
			ksort($options);
		}
		catch (RuntimeException $e) {
			$options = array();
		}

		// Merge any additional options in the XML definition.
		$options = array_merge(parent::getOptions(), $options);

		return $options;
	}

	/**
	 * Method to get the field options.
	 *
	 * @return  array  The field option objects.
	 *
	 * @since   11.1
	 */
	protected function getKeys()
	{
		$keys 		= array();
		$bookzo 	= Bookzo::getInstance();
		$languages 	= $bookzo->api->getLanguages();
		
		foreach ( $languages as $language ) {
			$key 		= new stdClass();
			$key->value = $language->get('id');
			$key->text  = $language->get('name');
			
			$keys[] = $key;
		}
		
		return $keys;
	}
	
	/**
	 * Method to get certain otherwise inaccessible properties from the form field object.
	 *
	 * @param   string  $name  The property name for which to the the value.
	 *
	 * @return  mixed  The property value or null.
	 *
	 * @since   3.2
	 */
	public function __get($name)
	{
		switch ($name)
		{
			case 'inlinelabel':
				return (bool) $this->$name;
		}

		return parent::__get($name);
	}

	/**
	 * Method to set certain otherwise inaccessible properties of the form field object.
	 *
	 * @param   string  $name   The property name for which to the the value.
	 * @param   mixed   $value  The value of the property.
	 *
	 * @return  void
	 *
	 * @since   3.2
	 */
	public function __set($name, $value)
	{
		switch ($name)
		{
			case 'inlinelabel':
				$this->$name = (bool) $value;
				break;

			default:
				parent::__set($name, $value);
		}
	}
	
	/**
	 * Method to attach a JForm object to the field.
	 *
	 * @param   SimpleXMLElement  $element  The SimpleXMLElement object representing the <field /> tag for the form field object.
	 * @param   mixed             $value    The form field value to validate.
	 * @param   string            $group    The field name group control value. This acts as as an array container for the field.
	 *                                      For example if the field has name="foo" and the group value is set to "bar" then the
	 *                                      full field name would end up being "bar[foo]".
	 *
	 * @return  boolean  True on success.
	 *
	 * @see     BFormField::setup()
	 * @since   3.2
	 */
	public function setup(SimpleXMLElement $element, $value, $group = null)
	{
		$return = parent::setup($element, $value, $group);

		if ($return)
		{
			$inlinelabel = (bool) $this->element['inlinelabel'];

			$this->inlinelabel  = ($inlinelabel == 'true' || $inlinelabel == 'inlinelabel' || $inlinelabel == '1');
		}

		return $return;
	}
}
