<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz helper class.
 *
 * This class acts as parent for all helper classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BHelper {

	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	public $app;

	/**
	 * The name of the helper
	 *
	 * @var 	string
	 * @since 	1.0.0
	 */
	protected $_name;
	
	/**
	 * The name of the helper
	 *
	 * @var 	string
	 * @since 	1.0.0
	 */
	protected $_prefix;
	
	/**
	 * Holder for cached data
	 * 
	 * @var array
	 * @since 1.0.0
	 */
	protected $cache = array();

	/**
	 * Class constructor
	 *
	 * @param App $app A reference to an App Object
	 */
	public function __construct($app) 
	{
		// set application
		$this->app 	 	= $app;
		
		// set helper prefix
		$this->_prefix 	= 'BzHelper';

		// set default name
		$this->_name 	= strtolower(substr_replace(get_class($this), '', 0, strlen($this->_prefix)));
	}

	/**
	 * Get the name of the helper
	 *
	 * @return string The name of the helper
	 * @since 1.0.0
	 */
	public function getName() 
	{
		return $this->_name;
	}

	/**
	 * Execute a function call
	 *
	 * @param 	callable $callable a php callable, which can be a array($object, 'method') or a 'method'
	 * @param 	array $args	a list of arguments for the method (max 4)
	 * @return 	mixed The result of the function call
	 * @since 	1.0.0
	 */
	protected function _call($callable, $args = array()) 
	{
		return call_user_func_array($callable, $args);
	}
}