<?php
/**
 * @package     Joomla.Legacy
 * @subpackage  Model
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Prototype form model.
 *
 * @package     Joomla.Legacy
 * @subpackage  Model
 * @see         JForm
 * @see         BFormField
 * @see         JFormRule
 * @since       12.2
 */
abstract class BModelList extends BModel
{
	/**
	 * Array of form objects.
	 *
	 * @var    array
	 * @since  12.2
	 */
	protected $_forms = array();


	abstract protected function getItems();


	## NOTE find a better way
	public function getList()
	{
		$results 	= $this->getItems();
		$return		= array();
		
		if ( !count($results) ) {
			return $return;
		}
		
		$start		= $this->getStart();
		$limit		= $this->getState('list.limit');
		
		if ( $limit ) {
			return array_slice($results, $start, $limit);
		}
		
		return $results;
	}
	
	public function getTotal()
	{
		// Try to load from cache
		if (isset($this->cache['total']))
		{
			return $this->cache['total'];
		}
		
		// get items
		$items = $this->getItems();
		
		// add to cache
		$this->cache['total'] = count($items);

		// return
		return $this->cache['total'];
	}
	
	/**
	 * Method to get the starting number of items for the data set.
	 *
	 * @return  integer  The starting number of items available in the data set.
	 *
	 * @since   12.2
	 */
	public function getStart()
	{
		// Try to load from cache
		if (isset($this->cache['start']))
		{
			return $this->cache['start'];
		}

		$start = $this->getState('list.start');
		$limit = $this->getState('list.limit');
		$total = $this->getTotal();
		
		

		// start can not exceed total
		if ( !$limit ) {
			$start = 0;
		}
		else if ($start > $total - $limit)
		{
			$start = max(0, (int) (ceil($total / $limit) - 1) * $limit);
		}

		// add to cache
		$this->cache['start'] = $start;

		return $this->cache['start'];
	}

	
	public function getPagination()
	{
		// Try to load the data from internal storage.
		if (isset($this->cache['pagination']))
		{
			return $this->cache['pagination'];
		}

		// Create the pagination object.			
		$pagination = new BPagination($this->getTotal(), $this->getStart(), (int) $this->getState('list.limit'));

		// Add the object to the internal cache.
		$this->cache['pagination'] = $pagination;

		return $this->cache['pagination'];		
	}
	
	public function order(&$items)
	{
		// get defaults
		$items	= (array) $items;
		
		// what order
		$order 	= $this->getState('list.order', 'id');
		$dir	= $this->getState('list.dir', 	'asc');
		
		// no need if no items
		if ( !count($items) ) {
			return;
		}
		
		// lets sort
		switch( strtolower($order) ) 
		{
			default: 
			case 'id' :
			
					break;
				
			case 'maxpersons' :
			
					uasort($items, function($a, $b) { 
					
						return ($a->get('numberofbeds') > $b->get('numberofbeds')); 
					
					});
					
					break;
					
			case 'discountorder' :
			
					uasort($items, function($a, $b) { 
					
						return ($a->get('discountorder') > $b->get('discountorder')); 
					
					});
					
					break;
					
			case 'name' :
			
					uasort($items, function($a, $b) { 
					
						return strcmp($a->get('name'), $b->get('name')); 
					
					});
					
					break;
				
			case 'price' :
				
				$tmp   = $items;
				$first = array_shift($tmp);

				if ( $first->hasPrice() )
				{
					uasort($items, function($a, $b) { 
						
						$type   = $this->app->config->get('template.pricesincl', 0) ? 'total' : 'price';
						$pricea = $a->getPrice();
						$priceb = $b->getPrice();
						$pricea = $pricea ? $pricea->get($type) : 0;
						$priceb = $priceb ? $priceb->get($type) : 0;
						
						if ( (float) $pricea == (float) $priceb ) {
							return 0;
						}

						return ( (float) $pricea < (float) $priceb ) ? -1 : 1;
					});
				}
				
				break;
				
			case 'random' :
			
				## NOTE - We should make a difference between search results and list pages
				## search results should be resetted by each search as for normal list results should always stay the same
			
				// get a set of random ordered ids
				$randomids = $this->app->adapter->sessionGet('bookzo.randomids', array());
				
				if ( !count($randomids) ) 
				{
					$objects 	= $this->app->api->getObjects();
					$randomids 	= array_keys($objects);
					
					shuffle($randomids);
					
					$this->app->adapter->sessionSet('bookzo.randomids', $randomids);
				}
				
				// compare items to randomized ids
				$tmp = array();
				
				foreach ( $randomids as $id ) {
					if ( array_key_exists($id, $items) ) {
						$tmp[$id] = $items[$id];
					}
				}
				
				$items = $tmp;
		}
		
		// fire items formloaded event
		
		$items = $this->app->event->dispatcher->fire(
			$this->app->event->create('items:afterordering', compact('order'))->addSubject('items', $items)
		)->getSubject('items');
		
		// do we want ascending or descending
		if ( strtolower($dir) == 'desc' )
		{
			$items = array_reverse($items, true);
		}
		
		return;
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   An optional ordering field.
	 * @param   string  $direction  An optional direction (asc|desc).
	 *
	 * @return  void
	 *
	 * @since   12.2
	 */
	protected function populateState($order = 'id', $dir = 'asc')
	{
		// set pagination values
		$limit = $this->app->config->get('template.pagination_limit', 15);
		$this->setState('list.limit', $limit );
		
		if ( $this->app->input->get('start', null) != null ) {
			$limitstart = $this->app->getUserStateFromRequest($this->name . '.limitstart', 'start', 0);
		}
		else {
			$limitstart = $this->app->getUserStateFromRequest($this->name . '.limitstart', 'limitstart', 0);
		}
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
		$this->setState('list.start', $limitstart);	
		
		// set ordering values
		## NOTE - This should be expanded with frontend ordering and userstate
		$this->setState('list.order', 	$order);
		$this->setState('list.dir', 	$dir);	
	}
}
