<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz Plugin class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.2.1
 */
abstract class BPlugin {

	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	public $app;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $path;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $name;
	
	/**
	 * BRegistry object
	 *
	 * @var 	params
	 * @since 	1.0.0
	 */
	protected $params;
	

	/**
	 * Class constructor
	 *
	 * @param App $app A reference to an App Object
	 */
	public function __construct() 
	{		
		// set application
		$this->app 	 	= Bookzo::getInstance();
		$this->name		= $this->getName();
		$this->path		= new BPathHelper();
		
		// set the params
		$this->params	= $this->app->config->extract('plugins.'.$this->name);
				
		// add the renderer
		$this->renderer = $this->app->renderer->widget($this->name);
		
		// load languages
		$this->loadLanguagePaths();
		$this->app->language->load('plugin.'.$this->name, 'nl');
		$this->app->language->load('plugin.'.$this->name);
		
		// set identifier
		$this->identifier = $this->name.'-'. uniqid();
	}
	
	public static function load($name)
	{
		// get up base
		$app	= Bookzo::getInstance();
		$class 	= 'BzPlugin'.ucfirst($name);

		// register the class
		BLoader::register($class, $app->path->path('plugins:'.$name.'/plugin.'.$name.'.php'));
			
		if ( !class_exists($class) ) 
		{
			throw new BPluginException('Plugin ' . $name . ' could not be found');
		}

		$plugin = new $class;
		
		return $plugin;
	}
	
	/**
	 * Get the name of the plugin
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function getName()
	{
		if ( $this->name == null )
		{
			$this->name = strtolower(str_replace('BzPlugin', '', get_class($this))); 
		}
		
		return $this->name;
	}
			
	public function get($name, $default = null)
	{
		if ( isset($this->$name) ) {
			return $this->$name;
		}
		
		return $default;
	}
	
	public function getConfigForm()
	{
		$return = false;
		
		if ( $file = $this->app->path->path('plugins:'.$this->getName().'/config.xml') ) 
		{
			try {
				if ( $form = BForm::getInstance('plugin.'.$this->getName(), $file, array(), false, false) ) {
					$return = $form;
				}
			}
			catch ( Exception $e ) 
			{
				$return = false;
			}
		}
		
		return $return;
	}
	
	public function loadConfigLanguageFile()
	{
		$this->loadLanguagePaths();
		$this->app->language->load('plugin.'.$this->getName().'.config', 'nl');
		$this->app->language->load('plugin.'.$this->getName().'.config');
	}
	
	public function loadLanguagePaths()
	{
		// load the language for this widget
		$pluginpaths = $this->app->path->paths('plugins:');
		foreach ( $pluginpaths as $pluginpath ) {
			$this->app->path->register( $pluginpath . '/' . $this->getName() .'/language', 'languages');
		}
	}
	
	public function __get($name)
	{
		return $this->get($name);
	}
}

/**
 * BzException identifies an Exception in the Bz class
 * @see Bz
 */
class BPluginException extends BRuntimeException {}