<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Object
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die();

/**
 * Joomla Platform Object Class
 *
 * This class allows for simple but smart objects with get and set methods
 * and an internal error handler.
 *
 * @since       11.1
 * @deprecated  4.0
 */
class BRenderer extends BObject
{
	/**
	 * The layout paths
	 * @var array
	 */
	protected $_layout_paths;
	
	/**
	 * The layout paths
	 * @var array
	 */
	protected $_path;
	
	/**
	 * The layout paths
	 * @var array
	 */
	protected $_folders;

	/**
	 * The current layout
	 * @var string
	 */
	protected $_layout;
	
	/**
	 * The separator for layout paths
	 * @var string
	 */
	protected $_separator = '.';

	/**
	 * The extension type of the layouts
	 * @var string
	 */
	protected $_extension = '.php';
	
	/**
	 * Callback for escaping.
	 *
	 * @var string
	 * @deprecated 13.3
	 */
	protected $_escape = 'htmlspecialchars';
	
	/**
	 * Charset to use in escaping mechanisms; defaults to urf8 (UTF-8)
	 *
	 * @var string
	 */
	protected $_charset = 'UTF-8';
	
	/**
	 * Maximum recursion depth
	 */
	const MAX_RENDER_RECURSIONS = 100;
	
	/**
	 * Charset to use in escaping mechanisms; defaults to urf8 (UTF-8)
	 *
	 * @var string
	 */
	protected $partial;
	
	/**
	 * Class constructor
	 *
	 * @param App $app The app instance
	 * @param PathHelper|null $path The path helper to use
	 * @since 2.0
	 */
	public function __construct( $app, $basepaths = array() ) 
	{
		parent::__construct();
		
		$this->app 			 = $app;
		$this->_layout_paths = array();
		$this->_path		 = new BPathHelper();
		
		foreach ( $basepaths as $path ) {
			$this->addPath( $this->app->path->path($path) );
		}
	}
	
	/**
	 * Render objects using a layout file.
	 *
	 * @staticvar int $count
	 *
	 * @param string $layout Layout name.
	 * @param array $args Arguments to be passed to into the layout scope.
	 *
	 * @return string The rendered output
	 * @since 2.0
	 */
	public function render($layout, $args = array()) {

		// prevent render to recurse indefinitely
		static $count = 0;
		$count++;

		//if ($count < self::MAX_RENDER_RECURSIONS) {

			// render layout
			if ($__layout = $this->_getLayoutPath($layout)) {

				// import vars and layout output
				extract($args);
				ob_start();
				include($__layout);
				$output = ob_get_contents();
				ob_end_clean();

				$count--;

				return $output;
			}
			else {
				throw new BRendererException( 'Layout ' . $layout . ' could not be found' );
			}

			$count--;

			// raise warning, if layout was not found
			//JError::raiseWarning(0, 'Renderer Layout "'.$layout.'" not found. ('.$this->app->utility->debugInfo(debug_backtrace()).')');

			return null;
		//}
		//else {
		//	echo 'wat';
		//}

		// raise warning, if render recurses indefinitly
		//JError::raiseWarning(0, 'Warning! Render recursed indefinitly. ('.$this->app->utility->debugInfo(debug_backtrace()).')');

		return null;
	}
	
	/**
	 * Retrieve the renderers folder.
	 *
	 * @return string The folder
	 * @since 2.0
	 */
	public function getPaths() 
	{	
		return $this->_path->getPaths('renderer');
	}
	
	/**
	 * Retrieve the renderers folder.
	 *
	 * @return string The folder
	 * @since 2.0
	 */
	public function addPath($path) 
	{
		if (is_array($path) ) {
			foreach ( $path as $p ) {
				$this->addPath($p);
			}
		}
		else {
			$this->_path->register($path, 'renderer');
		}
	}
	
	/**
	 * Retrieve an array of layout filenames.
	 *
	 * @param string $dir
	 * @return array the layout files
	 * @since 2.0
	 */
	 /*
	public function getLayouts($dir) {

		// find layouts in path(s)
		$layouts = $this->_path->files($dir, false, '/'.preg_quote($this->_extension).'$/i');

		return array_map(create_function('$layout', 'return basename($layout, "'.$this->_extension.'");'), $layouts);
	}
	*/
	
	/**
	 * Escapes a value for output in a template script.
	 *
	 * If escaping mechanism is either htmlspecialchars or htmlentities, uses
	 * {@link $_encoding} setting.
	 *
	 * @param   mixed  $var  The output to escape.
	 *
	 * @return  mixed  The escaped value.
	 *
	 * @since   12.2
	 */
	public function escape($var)
	{
		if (in_array($this->_escape, array('htmlspecialchars', 'htmlentities')))
		{
			return call_user_func($this->_escape, $var, ENT_COMPAT, $this->_charset);
		}

		return call_user_func($this->_escape, $var);
	}
	
	public function exists($layout)
	{
		if ( false === $this->_getLayoutPath($layout) ) {
			return false;
		}
		
		return true;
	}
	
	public function partial($layout, $args = array())
	{
		if ( is_null($this->partial) ) {
			$this->partial = $this->app->renderer->partial();
		}
		
		return $this->partial->render($layout, $args);
	}
	
	/**
	 * Gets the layout path for the given layout
	 *
	 * @param string $layout
	 *
	 * @return string The layout path
	 * @since 2.0
	 */
	protected function _getLayoutPath($layout) {

		if (!isset($this->_layout_paths[$layout])) 
		{			
			// init vars
			$parts 		   = explode($this->_separator, $layout);
	
			// find it or throw error
			if ( $path = $this->_path->path('renderer:'.implode('/', $parts).$this->_extension) ) 
			{
				$this->_layout = preg_replace('/[^A-Z0-9_\.-]/i', '', end($parts));
				$this->_layout_paths[$layout] = $path;
			}
			else {
				$this->_layout_paths[$layout] = false;
			}
		}

		return $this->_layout_paths[$layout];
	}
}

/**
 * BzException identifies an Exception in the Bz class
 * @see Bz
 */
class BRendererException extends BRuntimeException {}
