<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz helper class.
 *
 * This class acts as parent for all helper classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BTargetpayIdeal extends BTargetpay {

	/**
	 * Holder for the list of issuers
	 *
	 * @var 	Array
	 * @since 	1.1.0
	 */
	protected $issuers;
	
	/**
	 * The selected issuer
	 *
	 * @var 	int
	 * @since 	1.1.0
	 */
	protected $issuer;
	
	/**
	 * Method to load additional params for the startpayment method specific to ideal
	 *
	 * @param   array	$params		a list of params set
	 * @return  void
	 *
	 * @since   1.1
	 */
	public function getPaymentParams( $params, $test = 0 )
	{
		$params['bank'] = $this->get('issuer');
		$params['test'] = $test;
		
		return $params;
	}
	
	/**
	 * Method to load additional params for the startpayment method specific to ideal
	 *
	 * @param   array	$params		a list of params set
	 * @return  void
	 *
	 * @since   1.1
	 */
	public function getValidationParams( $params, $test = 0 )
	{
		$params['test'] = $test;
		
		return $params;
	}
	
	/**
	 * Method to load the paymenturl for this child method
	 *
	 * @param   void
	 * @return  url
	 *
	 * @since   1.1
	 */
	public function getPaymentUrl()
	{
		return 'https://www.targetpay.com/ideal/start/';
	}
	
	/**
	 * Method to load the paymenturl for this child method
	 *
	 * @param   void
	 * @return  url
	 *
	 * @since   1.1
	 */
	public function getValidationUrl()
	{
		return 'https://www.targetpay.com/ideal/check/';
	}
	
	/**
	 * Method to get a list of issuer id's
	 *
	 * @param   void
	 * @return  $banks	array	a list of possible banks (issuers)
	 *
	 * @since   1.1
	 */
	public function getIssuers()
	{
		if ( is_null($this->issuers) ) 
		{
			$issuers = array();
			
			if ( $result = $this->getResponse('https://www.targetpay.com/ideal/getissuers?ver=3&format=xml') )
			{
				if ( $xml = $this->app->xml->fromString($result) ) 
				{
					foreach ( $xml->issuer as $bank ) 
					{
						$issuers[$bank->getAttribute('id')] = (string) $bank;
					}
				}
			}
			
			$this->issuers = $issuers;
		}
		
		return $this->issuers;
	}
	
	
	/**
	 * Method to set the targetpay amount (should be in cents)
	 *
	 * @param   string		$issuer  The bank issuer id
	 * @return  $this
	 *
	 * @since   1.1
	 */
	public function setIssuer ( $issuer ) {
	
		$this->issuer = $issuer;    
		
		return $this;
	}	
}