<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz helper class.
 *
 * This class acts as parent for all helper classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
abstract class BTargetpay implements BTargetpayInterface {

	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	public $app;
		
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $layoutcode;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $description;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $amount;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $returnUrl;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $reportUrl;
	
	/**
	 * Class constructor
	 *
	 * @param App $app A reference to an App Object
	 */
	public function __construct($app, $layoutcode) 
	{
		// set application
		$this->app 	 		= $app;
		$this->setIp( $_SERVER['REMOTE_ADDR'] );
		$this->setLayoutcode($layoutcode);
	}
	
	/**
	 * Method to start a payment at targetpay
	 *
	 * @param   string	$trxid  	The trxid of the payment
	 * @param   int		$once  		Should payment be validated just once
	 * @param   int		$test  		Is it a testpayment
	 * @return  boolean				true if succesfull
	 *
	 * @since   1.1
	 * @throws  Exception if amount isn't correct
	 */
	public function startPayment($test = 0 ) 
	{
	
		try {
			// Build parameters
			$params 				= array();
			$params['rtlo'] 		= $this->get('layoutcode');
			$params['description'] 	= $this->get('description');
			$params['amount'] 		= $this->get('amount');
			$params['returnurl'] 	= $this->get('returnUrl');
			$params['reporturl'] 	= $this->get('reportUrl');
			
			// get method specific params
			$params = $this->getPaymentParams( $params, $test );
			
			// do request
			$response	 	= $this->getResponse( $this->getPaymentUrl(), $params );
			$values 		= explode('|', $strResponse );
			
			// Bad response
			if ( !isset ( $values[1] ) ) {
				throw new Exception( $values[0] );    
			}
			
			$trxid = explode ( ' ', $values[0] );
			
			// We return TRXid and url to rederict
			return array ( $trxid[1], $values[1] );
		  
		} 
		catch( Exception $e ) {
	
			$this->app->log->write('Targetpay Error', $e->getMessage(), '', 'reservations');
			
			$return = false;
	
		}  
		
		return $return;		
	}
	
	/**
	 * Method to validate the payment at targetpay
	 *
	 * @param   string	$trxid  	The trxid of the payment
	 * @param   int		$once  		Should payment be validated just once
	 * @param   int		$test  		Is it a testpayment
	 * @return  boolean				true if succesfull
	 *
	 * @since   1.1
	 * @throws  Exception if amount isn't correct
	 */
	public function validatePayment ( $trxid, $once = 1, $test = 0 ) {
	
		try {
			
			// Build parameters
			$params 				= array();
			$params['rtlo'] 		= $this->get('layoutcode');
			$params['trxid'] 		= $trxid;
			$params['once'] 		= $once;

			## NOTE - Do child methods don't have params
			$params = $this->getValidationParams($params, $test);

			// connect to TargetPay
			$response 	= $this->getResponse( $this->getValidationUrl(), $params );
			$values 	= explode('|', $response );
		
			// Bad response
			if (  $values[0] != '000000 OK' ) {
				throw new Exception( $values[0] );    
			}

			$this->app->log->write('Targetpay', '000000 OK', '', 'reservations');		
			$return = true;
		
		}    
		catch( Exception $e ) {
		
			
			$this->app->log->write('Targetpay Error', $e->getMessage(), '', 'reservations');
			
			$return = false;
		
		} 
	   
	   	return $return;
	}
	
	public function get($value, $def = '')
	{
		if ( isset($this->$value) && !is_null($this->$value) ) {
			return $this->$value;
		}
		
		return $def;
	}
	
	/**
	 * Method to set the targetpay amount (should be in cents)
	 *
	 * @param   int		$amount  The amount to pay
	 * @return  $this
	 *
	 * @since   1.1
	 * @throws  Exception if amount isn't correct
	 */
	public function setAmount( $amount )
	{
		// is it a valid amount
		if ( is_numeric ( $amount ) && $amount > 0 ) {
			$this->amount = $amount;    
		}
		else {
			throw new Exception( 'Invalid ideal amount, please check.' );   
		}
		
		return $this;
	}
	
	/**
	 * Method to set the targetpay description
	 *
	 * @param   string	$desc the description
	 * @return  $this
	 *
	 * @since   1.1
	 */
	public function setDescription ( $desc ) 
	{
		$this->description = $desc;  
		
		return $this;   
	}
	
	/**
	 * Method to set the targetpay description
	 *
	 * @param   string	$ip the clients ip address
	 * @return  $this
	 *
	 * @since   1.1
	 */
	public function setIp ( $ip ) 
	{
		$this->ip = $ip;  
		
		return $this;   
	}
	
	/**
	 * Method to set the targetpay description
	 *
	 * @param   string	$ip the clients ip address
	 * @return  $this
	 *
	 * @since   1.1
	 */
	public function setLayoutcode ( $code ) 
	{
		$this->layoutcode = $code;  
		
		return $this;   
	}
	
	/**
	 * Method to set the targetpay return url
	 *
	 * @param   string	$url 	the website return url 
	 * @return  $this
	 *
	 * @since   1.1
	 */
	public function setReturnUrl ( $url ) 
	{
		$this->returnUrl = $url;  
		
		return $this;   
	}
	
	/**
	 * Method to set the targetpay report url
	 *
	 * @param   string	$url 	the website report url 
	 * @return  $this
	 *
	 * @since   1.1
	 */
	public function setReportUrl ( $url ) {
		
		$this->reportUrl = $url;  
		
		return $this;   
	}
	
	/**
	 * Get a response from the targetpay API
	 *
	 * @param   string	$url 	the targetpay url 
	 * @param 	array	$params	the params for the url
	 * @return  $this
	 *
	 * @since   1.1
	 */
	protected function getResponse( $url, $params = array() ) 
	{
		// set the options for the call
		$options 	= array(
						CURLOPT_POST 			=> 1,
						CURLOPT_HEADER 			=> 0,
						CURLOPT_URL 			=> $url,
						CURLOPT_FRESH_CONNECT 	=> 1,
						CURLOPT_RETURNTRANSFER 	=> 1,
						CURLOPT_FORBID_REUSE 	=> 1,
						CURLOPT_TIMEOUT 		=> 120,
						CURLOPT_SSL_VERIFYPEER 	=> 0,
						CURLOPT_POSTFIELDS 		=> !is_array($params) || !count($params) ? '' : http_build_query($params, '', '&')
					);
		
		$this->app->log->write( 'Targetpay Query', $url . ' - ' .  http_build_query($params, '', '&'), 'reservations' );
				
		// lets connect to TargetPay
		try {
			
			$ch = curl_init();
			curl_setopt_array($ch, $options);
				$response = curl_exec($ch);
			curl_close($ch); 
			
			if ( $response === false ) {
				throw new Exception('Could not fetch response');
			}
			
			$return = $response;
		}
		catch ( Exception $e ) 
		{
			$return = false;
		}
		
		return $return;	
	}	
}

interface BTargetpayInterface {
	
	/**
	 * Method to load additional params for the startpayment method specific to child payment method
	 *
	 * @param   array	$params		a list of params set
	 * @return  void
	 *
	 * @since   1.1
	 */
	public function getPaymentParams( $params, $test = 0 );
	
	/**
	 * Method to load additional params for the startpayment method specific to child payment method
	 *
	 * @param   array	$params		a list of params set
	 * @return  void
	 *
	 * @since   1.1
	 */
	public function getValidationParams( $params, $test = 0 );
	
	/**
	 * Method to load the payment url for a child payment method
	 *
	 * @param   array	$params		a list of params set
	 * @return  void
	 *
	 * @since   1.1
	 */
	public function getPaymentUrl( );
	
	
	/**
	 * Method to load the validation url for a child payment method
	 *
	 * @return  void
	 * @since   1.1
	 */
	public function getValidationUrl( );
	
}