<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
abstract class BWidget {

	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	public $app;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $path;
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $name;
	
	
	protected $params;
	
	protected $renderer;
	
	protected $identifier;
		
	private static $instances = array();

	/**
	 * Class constructor
	 *
	 * @param App $app A reference to an App Object
	 */
	public function __construct() 
	{		
		// set application
		$this->app 	 	= Bookzo::getInstance();
		$this->name		= $this->getName();
		$this->path		= new BPathHelper();
		
		// set the params
		$this->params	= $this->app->config->extract('widgets.'.$this->name);
				
		// add the renderer
		$this->renderer = $this->app->renderer->widget($this->name);
		
		// load the language for this widget
		## NOTE - shouldn't we check for existance
		$widgetpaths = $this->app->path->paths('widgets:');
		foreach ( $widgetpaths as $widgetpath ) {
			$this->app->path->register( $widgetpath . '/' . $this->name .'/language', 'languages');
		}
		
		$this->app->language->load('widget.'.$this->name, 'nl');
		$this->app->language->load('widget.'.$this->name);
		
		// set identifier
		$this->identifier = $this->name.'-'. uniqid();
	}
	
	public static function widget($name)
	{
		// get up base
		$app	= Bookzo::getInstance();
		$class 	= 'BzWidget'.ucfirst($name);

		// register the class
		BLoader::register($class, $app->path->path('widgets:'.$name.'/widget.php'));
			
		if ( !class_exists($class) ) 
		{
			throw new BWidgetException('Widget ' . $name . ' could not be found');
		}
		
		$widget = new $class;
		
		return $widget;
	}
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	 
	## NOTE - we should really unify this over all classes
	public function getName()
	{
		if ( $this->name == null )
		{
			$this->name = strtolower(str_replace('BzWidget', '', get_class($this))); 
		}
		
		return $this->name;
	}
	
	public function addTemplatePath($path)
	{
		if ( $path ) {
			$this->renderer->addPath($path);
		}
	}
	
	public function getTemplatePaths()
	{
		return $this->renderer->getPaths();
	}
	
	public function setParam($param, $value)
	{
		$this->params->set($param, $value);
		
		return $this;
	}
	
	public function setParams($params)
	{
		$params = $this->app->registry->create($params);
		$this->params->merge($params);
		
		return $this;
	}
	
	public function get($name)
	{
		if ( isset($this->$name) ) {
			return $this->$name;
		}
		
		return null;
	}
	
	public function getConfigForm()
	{
		$return = false;
		
		if ( $file = $this->app->path->path('widgets:'.$this->name.'/config.xml') ) 
		{
			try {
				if ( $form = BForm::getInstance('widget.'.$this->name, $file, array(), false, false) ) {
					$return = $form;
				}
			}
			catch ( Exception $e ) 
			{
				$return = false;
			}
		}
		
		return $return;
	}
	
	public function loadConfigLanguageFile()
	{
		$this->app->language->load('widget.'.$this->name.'.config', 'nl');
		$this->app->language->load('widget.'.$this->name.'.config');
	}
	
	public function __get($name)
	{
		return $this->get($name);
	}
	
	abstract public function render();
}

/**
 * BzException identifies an Exception in the Bz class
 * @see Bz
 */
class BWidgetException extends BRuntimeException {}