<?php
/**
 * @package     Joomla.Libraries
 * @subpackage  HTML
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Utility class for all HTML drawing classes
 *
 * @since  1.5
 */
class BXml extends SimpleXMLElement
{
	/**
     * Add SimpleXMLElement code into a SimpleXMLElement
     *
     * @param MySimpleXMLElement $append
     */
    public function appendXML($append)
    {	
		if ($append) {
            if (strlen(trim((string)$append)) == 0) {
                $xml = $this->addChild($append->getName());
            } else {
                $xml = $this->addChild($append->getName(), (string)$append);
            }

            foreach ($append->children() as $child) {
                $xml->appendXML($child);
            }

            foreach ($append->attributes() as $n => $v) {
                $xml->addAttribute($n, $v);
            }
			
			return $xml;
        }
		
		return false;
    }
	
	public function getChild($name)
	{
		if ( $xml = $this->xml->xpath('//'.$name) ) {
			return $xml;
		}
		
		return false;			
	}
	
	public function removeChild($name)
	{
		list($element) = $this->xml->xpath('//'.$name);
		
		if ( count($elements) ) {
			unset($elements[0]);
		}
	}
	
	public function getAttribute($name, $default = null)
	{
		$attributes = $this->attributes();

		// Ensure that the attribute exists
		if (property_exists($attributes, $name))
		{
			$value = $attributes->$name;

			if ($value !== null)
			{
				return (string) $value;
			}
		}

		return $default;
	}
	
	public function setAttribute($name, $value)
	{
		$attributes = $this->attributes();

		// Ensure that the attribute exists
		if (property_exists($attributes, $name))
		{
			$this->attributes()->$name = $value;
		}
		else {
			$this->addAttribute($name, $value);
		}
		
		return $this;
	}
}
