<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
 
class BookzoApiRequestJSON extends BookzoApiRequest {

	/**
	 * Execute the query by offering it to the bookzo api
	 * 
	 * @param 	none
	 * @return 	mixed	$data	the data received if succesfull, otherwise false
	 * @access	proteced
	 * @since 	1.0.0
	 */
	public function execute( $retry = 0, $doretry = true )
	{
		// credentials must be set
		if ( $this->credentials == false ) {
			$this->app->log->write('Error', 'No credentials set');
			throw new BookzoRequestException( 'No credentials set', 500 );
		}
		
		// do we need to do something ?
		## NOTE - SOME ERROR HERE where lastquery allready is this->query also on first time????
		//if ( $this->query != $this->lastquery && $this->query != null )
		if ( $this->query != null )  
		{		
			// update query
			$this->result	 = null;
			$this->data		 = null;
			$this->lastquery = $this->query;
			
			// get correct query
			$query 		= $this->query->getMethod();
			$wheres		= $this->query->getVars();
			$logsuffix 	= in_array( strtolower($query), array('submitreservation', 'getreservationprospect') ) ? 'reservations' : '';
		
			// do checks here to see if we got data
			$url 	= implode('/', array($this->url, $query));
			$posts	= count($wheres) ? 1 : 0;
			
			// set start for logging
			$start 	= $this->app->timer->start();

			// init vars
			$curl 	= curl_init();
			
			// add to log
			$this->app->log->write('Query' . ( $retry ? ' Retry ' . $retry : '' ), (string) $this->query, '', $logsuffix);
	
			// init curl and set settings
			curl_setopt($curl, 		CURLOPT_URL, 			$url);
			curl_setopt($curl, 		CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, 		CURLOPT_POST, 			$posts);
			curl_setopt($curl, 		CURLOPT_HEADER, 		0); 
			curl_setopt($curl, 		CURLOPT_HTTPHEADER, 	array('Content-Type: application/json', 'Accept: application/json', "Expect: 100-continue"));
			curl_setopt($curl,		CURLOPT_USERPWD, 		$this->credentials);
			curl_setopt($curl, 		CURLOPT_CONNECTTIMEOUT ,2); 
			curl_setopt($curl, 		CURLOPT_TIMEOUT, 		$this->timeout);
			curl_setopt($curl, 		CURLOPT_SSL_VERIFYPEER, (bool) $this->verifypeer);
			curl_setopt($curl, 		CURLOPT_SSL_VERIFYHOST, (bool) $this->verifyhost);
			
			
			// add the variables
			if ( $posts ) 
			{
				curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($wheres));
			}
			
			// get the response
			if ( !$response = curl_exec($curl) ) 
			{
				## NOTE - Double if we start logging exceptions
				$this->app->log->write('Error', 'Request failed: ' . curl_error( $curl ), 500, $logsuffix);
				
				if ( $retry == 1 || !$doretry ) {
					throw new BookzoRequestException( 'Request failed: ' . curl_error( $curl ), 500 );
				} else {
					return $this->execute(1);
				}
			}

			// close connection
			$httpcode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
			curl_close($curl);

			// add response as result
			$this->data	  = $response;
			
			if ( $query == 'SubmitReservation' ) {
				$this->app->log->write('ReservationResult', $response, '', $logsuffix);
			}
			
			if ( !$this->decode($response) ) {

				## NOTE - Double if we start logging exceptions
				$this->app->log->write('Error', 'Bookzo WebApp not available', 401, $logsuffix);
				
				if ( $retry == 1 || !$doretry ) {
					throw new BookzoRequestException('Bookzo WebApp not available', 401 );
				} else {
					return $this->execute(1);
				}
			}
			
			// check for errors
			if ( $httpcode != 200 ) 
			{		

				$msg = isset($response->ResponseStatus)
					 ? $response->ResponseStatus->ErrorCode .': '. $response->ResponseStatus->Message
					 : 'Request failed with code ' . $httpcode;
					 
				## NOTE - Double if we start logging exceptions
				$this->app->log->write('Error', $msg, $httpcode, $logsuffix);
				
				throw new BookzoRequestException( $msg, $httpcode );
			}
			
			// to lowerkeys		
			$this->lowerkeys($response, true);
			
			// get endtime
			$seconds = $this->app->timer->stop($start);
			
			// last check
			if ( isset($response->result) ) {
				$this->app->log->write('Success', 'Result fetched in ' . $seconds . ' seconds', '', $logsuffix);
				$this->result = $response->result;
				
				return true;
			}
			else if ( isset($response->reservation) ) {
				$this->app->log->write('Success', 'Result fetched in ' . $seconds . ' seconds', '', $logsuffix);
				$this->result = $response->reservation;
				return true;
			}
			elseif ( isset($response->error) ) {
				$this->app->log->write('Error', 'Request failed ' . $response->error, '', $logsuffix);
				throw new BookzoRequestException('Request failed ' . $response->error, 500 );
			}
			
			$this->app->log->write('Undefined', 'No result or error found', '', $logsuffix);
			throw new BookzoRequestException('No result or error found', 500 );
			
			// we have no result
			return false;
		}
	}
	
	/**
	 * Method to get the result excecuted by the last query
	 * 
	 * @param 	none
	 * @return 	mixed
	 * @access	protected
	 * @since 	1.0.0
	 */
	public function getResult($retry = true) 
	{
		// first execute the query
		$this->execute(0, $retry);
		
		return $this->result;
	}
	
	/**
	 * Method to get the result excecuted by the last query as an array
	 * 
	 * @param 	none
	 * @return 	mixed
	 * @access	protected
	 * @since 	1.0.0
	 */
	public function getResults($key = null, $retry = true, $returnfalse = false)
	{
		// first execute the query
		$this->execute(0, $retry);
		
		// initiate
		$return  = array();
		$result	 = $this->result;
		
		// we should have data
		if ( !is_null($result) ) 
		{
			if (is_object($result) ) 
			{
				$return[] = $result;
			}
			else {
				$return	  = (array) $result;
			}
		}
		elseif ( (bool) $returnfalse ) {
			return false;
		}
		
		// try setting correct key
		if ( $key ) 
		{
			$tmp = array();
			
			foreach ( $return as $k => $v ) 
			{
				if ( isset($v->$key) ) {
					$tmp[$v->$key] = $v;
				}
				else {
					$tmp[$k] = $v;
				}
			}
			
			$return = $tmp;	
		}
		
		return $return;
	}
	
	protected function decode(&$string) 
	{
 		$string = json_decode($string);
		
 		return (json_last_error() == JSON_ERROR_NONE);
	}
}