<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Object
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Joomla Platform Object Class
 *
 * This class allows for simple but smart objects with get and set methods
 * and an internal error handler.
 *
 * @since       11.1
 * @deprecated  4.0
 */
class BookzoCalendar
{
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	public $app;
	
	protected $month;
	
	protected $number = 12;
	
	protected $settings = array();
	
	protected $blocks = array();
	
	protected $events = array();
	
	protected $links = array();
	
	protected $transitions = array();
	
	protected $dates = array();
	
	protected $rendermonths;
	
	protected $datelist;
	
	/**
	 * Class constructor, overridden in descendant classes.
	 *
	 * @param   mixed  $properties  Either and associative array or another
	 *                              object to set the initial properties of the object.
	 *
	 * @since   11.1
	 */
	public function __construct($properties = array())
	{
		$this->app 			= Bookzo::getInstance();
		
		// set defaults
		$this->setMonth(date('Y-m-d'));
		
		// do properties override defaults
		if ( isset($properties['month']) ) {
			$this->setMonth($properties['month']);
		}
		
		if ( isset($properties['months']) ) {
			$this->setNumberOfMonths($properties['months']);
		}
	}
	
	public function setMonth($month)
	{
		$this->month = date('Y-m-01', strtotime($month));	
		
		return $this;
	}
	
	public function setNrOfMonths($nr)
	{
		$this->number = (int) $nr;
		
		return $this;
	}
	
	public function addBlock($start, $end, $class, $firstclass = '', $lastclass = '')
	{
		$start 	= date('Y-m-d', strtotime($start));
		$end	= date('Y-m-d', strtotime($end));
		
		if ( $end < $start ) {
			$tmpend	 = $end;
			$end	 = $start;
			$start	 = $tmpend;
		}
		
		$block = new stdClass();
		$block->start 	= $start;
		$block->end 	= $end;
		$block->class	= $class;
		
		if ( !empty($firstclass) ) {
			$block->first	= $firstclass;
		}
		
		if ( !empty($lastclass) ) {
			$block->last	= $lastclass;
		}
		
		$this->blocks[] = $block;
	}
	
	public function addTransitions($from, $to, $class)
	{
		$transition = new stdClass();
		$transition->from = $from;
		$transition->to   = $to;
		$transition->class = $class;
		
		$this->transitions[] = $transition;
	}
	
	/*
	public function addEvent($start, $end, $class, $html = '', $all = false)
	{
		$start 	= date('Y-m-d', strtotime($start));
		$end	= date('Y-m-d', strtotime($end));
		
		if ( $end < $start ) {
			$tmpend	 = $end;
			$end	 = $start;
			$start	 = $tmpend;
		}
		
		$event 			= new stdClass();
		$event->start 	= $start;
		$event->end   	= $end;
		$event->html	= $html;
		$event->class	= $class;
		$event->all		= (bool) $all;
		
		$this->events[] = $event;
	}
	*/
	
	public function addLink($date, $href, $class = '')
	{
		$date = date('Y-m-d', strtotime($date));
		
		// build link
		$link 			= new stdClass();
		$link->date 	= $date;
		$link->href 	= $href;
		$link->class 	= $class;
		
		// add to stack
		$this->links[$date] = $link;
	}
	
	public function setSetting($name, $value = null)
	{
		if ( is_array($name) ) 
		{
			foreach ( $name as $k => $v )
			{
				$this->setSetting($k, $v);
			}
		}
		else {
			$this->settings[$name] = $value;
		}
		
		return $this;
	}
	
	public function getSetting($name, $default = null)
	{
		if ( isset($this->settings[$name]) ) {
			return $this->settings[$name];
		}
		
		return $default;
	}
	
	public function getMonthsToRender()
	{
		if ( !is_array($this->rendermonths) ) 
		{
			$filled = array();
			
			foreach ( $this->blocks as $block ) {
				$startmonth = $this->app->date->create($block->start)->format('Y-m-01');		
				$filled[] 	= $startmonth;
			
			# NOTE - Not yet, we use this when we have extended calendar
			//	$endmonth	= $this->app->date->create($block->end)->format('Y-m-01');
			//	$filled[]	= $endmonth;
			}
			
			$filled = array_unique($filled);
			sort($filled);
			
			$max			= count($filled) ? $this->number : 12;
			$start 			= $this->getSetting('showemptybegin', true) || !count($filled) ? $this->app->date->create()->format('Y-m-01') : array_shift($filled);
			$end			= $max ? $this->app->date->create()->add($max, 'm')->format('Y-m-01') : array_pop($filled);
			$render			= array();
			$month			= $start;
	
			while ( $month <= $end ) {
				$render[] = $month;
				$month = $this->app->date->create($month)->add(1, 'm')->format('Y-m-01');
			}
			
			$this->rendermonths = $render;
		}
		
		return $this->rendermonths;
	}
	
	public function render($echo = false)
	{
		$month			= $this->month;
		$months		 	= $this->getMonthsToRender();
		$return 		= array();
						
		foreach( $months as $month ) 
		{
			$html 			= array();

			// open table
			$html[] = '<table class="bz-calendar">';
			
			// add header
			$html[]	= $this->addHeader($month);
			
			// add days
			if ( $this->getSetting('show_days', 1) ) 
			{
				$html[]	= $this->addDays();
			}			
			
			// add body
			$html[]	= $this->addBody($month);
			
			// close table
			$html[]	= '</table>';
			
			// glue
			$return[] 	= implode("\n", $html);
		}
		
		// return or fetch
		if ( !$echo ) {
			return $return;
		}
		
		echo implode($return);
	}
	
	
	/**
	 * This function creates a row by calling addCell for each cell
	 *
	 * @access		private
	 * @param		$cells		array	array with all the cells for a specific row
	 * @return 		string
	 * @since		1.0
	 */
	protected function row( Array $cells = array(), $attr = '') 
	{
		$html 	= array();
		$class	= '';
		
		// get class
		if ( isset($attr['class']) ) {
			$class = $this->app->array->implodeRecursive($attr['class'], ' ', true);
			
			if ( strlen($class) ) {
				$class = 'class="'.$class.'"';
			}
		}
		
		// initiate
        $html[]	= '<tr '.$class.'>';
        
		// add cells
        foreach ($cells as $cell) {
			$html[] = $cell;      
        }
      
	  	// close row 
        $html[] = '</tr>';
		
		// return
		return implode("\n", $html);		
	}
	
	/**
	 * This function creates a cell and adds aditional html if requested
	 *
	 * @access		private
	 * @param		$cell 	array	a cell with the value and additional html
	 * @param		$type	string	the type of cell td or th
	 * @return 		string	
	 * @since		1.0
	 */
	protected function cell($text = '', $attr = '', $type = 'td') 
	{	
		$type 		= strtolower($type) == 'th' ? 'th' : 'td';
		$class		= '';
		$attributes	= '';
		
		if ( isset($attr['class']) ) {
			$class = $this->app->array->implodeRecursive($attr['class'], ' ', true);
			
			if ( strlen($class) ) {
				$class = 'class="'.$class.'"';
			}
		}
		
		if ( isset($attr['attr']) ) {
			$attributes = $this->app->array->implodeRecursive($attr['attr'], ' ', true);
		}
			
		return '<'.$type.' ' . $class . ' ' . $attributes . '>' .$text. '</'.$type.'>';
	}
	
	protected function getAttributeString($attr, $type, $addname = false)
	{
		if ( !isset($attr[$type])) {
			return '';
		}
		
		$data 	= $attr[$type];
		$string = '';
		
		if ( is_array($attr[$type]) ) {
			$attr[$type] = implode(' ', array_filter( $attr[$type], 'strlen' ));
		}
		
		if ( !strlen($attr[$type]) ) {
			return '';
		}
		
		return ($addname ? $type .'="'.$data[$type].'"' : $data[$type] ); 
	}
	
	/**
	 * This function adds all the rows with the days for a requested month
	 * It will check each day for availabilty and add a class to the cell (day)
	 * We start off by getting the nr of weeks and nr of days for a month
	 * We add a correction to the starting day if calendar starts with a monday
	 * All days get calculated by counter + nr of days (i) - starting day
	 * This will make a day in last month get a value of 0 or below.
	 * We correct that value by adding up the nr of days of last month
	 *
	 * @access		private
	 * @param		none
	 * @return 		string	
	 * @since		1.0
	 */
	private function addBody($month)
	{
		// initiate
		$body		= array();
		
		// defaults
		$counter	= 1;
		$monthstamp	= strtotime($month);
		$monthshort = date('Y-m', $monthstamp);		
		
		// set some values that we are gonna need
		$dayscount		= date('t',$monthstamp);
		$startday		= date('w',$monthstamp);
		$dayslastmonth 	= date('t',$monthstamp - 86400);
		$weekcount 		= !$this->getSetting('variable_weeks', 0) 
						? 6
						: ceil( ($dayscount + $startday ) / 7 ); 
		$startday		= $this->getSetting('sunday', 0) 
						? $startday 
						: ( $startday ? $startday - 1 : $startday + 6);						

		// loop the weeks
		for( $j = 0; $j < $weekcount; $j++ ) 
		{
			// initiate row	
			$row		= array();
		
			// do we add the weeknr
			if ( $this->getSetting('show_weeks', 1) ) 
			{
				$weeknr = date('W', mktime(0,0,0,date('n',$monthstamp),$counter,date('Y',$monthstamp)));
				$row[] 	= $this->cell($weeknr, array('class' => 'weeknr'));
			}
			
			// add 7 days for each week
			for ( $i = 0; $i <= 6; $i++ ) 
			{
				// get day
				$day	= ( $i + $counter ) - $startday;
				$date	= date('Y-m-d', strtotime($monthshort .'-'.$day));	
				$today  = date('Y-m-d');
				
				// day is in other month
				if ( $day < 1 || $day > $dayscount ) 
				{
					$day	= $day < 1 ? (int) $day + $dayslastmonth : (int) $day - $dayscount;
					$row[] 	= $this->cell($day, array('class' => 'other-month'));
					continue;
				}
				
				if ( $date < $today && $oldclass = $this->getSetting('old') ) {
					$row[] 	= $this->cell($day, array('class' => $oldclass));
					continue;
				}
				
				// day is correct
				$row[] = $this->getDayCell( $day, $date );	
			}
			
			// add the week to the row and add a week to the counter
			$body[]	  = $this->row($row, array('class' => 'dates'));
			$counter += 7;
		}	
		
		return implode("\n", $body);
	}
	
	private function getDateList()
	{
		if (!count($this->datelist) )
		{
			$dates = array();
			
			foreach ( $this->blocks as $block ) 
			{
				$date 	= $block->start;
				$stop	= $block->end;
				
				while ( $date <= $stop )
				{
					$dates[] = $date;
					$date 	 = $this->app->date->create($date)->add(1)->format('Y-m-d');
				}
			}
			
			$this->datelist = array_unique($dates);
		}
		
		return $this->datelist;
		
		/*
		$dates = array();
		
		// first add the blocks
		foreach ( $this->blocks as $block ) 
		{
			$date 	= $block->start;
			$stop	= $block->end;
			
			while ( $date <= $stop )
			{
				$dates[$date] = array();
				
				if ( !empty($block->class) ) {
					$dates[$date][] = $block->class;
				}
				
				if ( $date == $block->start && isset($block->first) && !empty($block->first) ) {
					$dates[$date][] = $block->first;
				}
				
				if ( $date == $block->end && isset($block->last) && !empty($block->last) ) {
					$dates[$date][] = $block->last;
				}
				
				$date = $this->app->date->create($date)->add(1)->format('Y-m-d');
			}
		}
		
		// get months we need to render
		$months	= $this->getMonthsToRender();
	
		if ( count($months) ) {
			$first = $this->app->array->first($months);
			$last  = $this->app->array->last($months);
			
			$start = $this->app->date->create($first)->format('Y-m-01');
			$end   = $this->app->date->create($last)->format('Y-m-t');
			
			while ( $start <= $end ) {
				if ( !array_key_exists($start, $dates) ) {
					$dates[$start] = array( $this->getSetting('class', 'this-month') );
				}
				$start = $this->app->date->create($start)->add(1)->format('Y-m-d');
			}
		}
		
		ksort($dates);
		
		// now add the classes from transitions
		if ( count($this->transitions) ) {
			foreach ( $dates as $date => $classes ) {
			}
			
			
		}
		
		*/
		
	
	}
	
	/**
	 * Gets the class for a cell (date) for the calendar
	 *
	 * @access		private
	 * @param		$day	string	the date for a day
	 * @param		$days	array	all days know so far
	 * @return 		$days	array	a day with its class	
	 * @since		1.0
	 */
	private function getDayCell( $day, $date )
	{
		// initiate class
		$classes  	= array();
		$attr 		= array();
		$datelist	= $this->getDateList();
		
		// add default attributs
		$attr[]		= 'data-stamp="'.strtotime($date).'"';
		$attr[]		= 'data-date="'.$date.'"';

		// check blocks to get correct class
		foreach ( $this->blocks as $block ) {

			if ( $block->start <= $date && $date <= $block->end ) {
				$classes[] = $block->class;
			}
			
			if ( $date == $block->start && isset($block->first) ) {
				$yesterday = $this->app->date->create($date)->substract(1)->format('Y-m-d');
				if ( !in_array($yesterday, $datelist) ) {
					$classes[] = $block->first;
				}
			}
			
			if ( $date == $block->end && isset($block->last) ) {
				$tomorrow = $this->app->date->create($date)->add(1)->format('Y-m-d');
				if ( !in_array($tomorrow, $datelist) ) {
					$classes[] = $block->last;
				}
			}
		}
		
		// do we have a link for this date
		if ( array_key_exists($date, $this->links) ) 
		{
			$link 	= $this->links[$date];
			$class 	= '';
			
			if ( !empty($link->class) ) {
				$classes[] 	= $link->class;
				$class		= ' class="'.$class.'" ';
			}
			
			$day = '<a href="' . $link->href . '"' . $class . '>' . $day . '</a>';
		}
		
		// check events
		/*
		$info = array();
		foreach ( $this->events as $event ) 
		{
			if ( (!$event->all && $event->start == $date) || ($event->all && $event->start <= $date && $date <= $event->end)  ) 
			{
				$classes[] = $event->class;
				if ( strlen($event->html) ) {
					$info[]	   = $event->html;	
				}
			}
		}
		
		// do we have a infoblock
		if ( count($info) ) 
		{
			$dataattr[]	= 'data-bz-dropdown="{mode: \'click\'}"';
			$classes[] 	= 'bz-dropdown';
			
			if ( $text == $day ) 
			{
				$text  = '<a><span>'.$day.'</span></a>';
				$text .= '<div class="bz-dropdown-block">'.implode($info).'</div>';
			}
			
		}
		*/
		
		// render the cell
		if ( !count($classes) ) {
			$classes[] = $this->getSetting('class', 'this-month');
		}
		
		// get attributes
		$classes 		= array_unique($classes);
		
		// return the cell			
		return $this->cell($day, array('class' => $classes, 'attr' => $attr) );
	}

	
	protected function addHeader($month)
	{
		$headerrow		= array();
		
		if ( $this->getSetting('show_weeks', 1) ) {
			$headerrow[] = $this->cell('', '', 'th');
		}
		
		$headerrow[] 	= $this->cell(
								$this->app->date->create($month)->format('F Y'), 
								array('class' => 'month', 'attr' => 'colspan="7"'), 'th'
							);		
		
		return $this->row($headerrow, array('class' => 'month'));
	}
	
	protected function addDays()
	{
		$daysrow	= array();
		
		if ( $this->getSetting('show_weeks', 1) ) {
			$daysrow[] = $this->cell();
		}
		
		$days		= $this->getSetting('sunday', 0)
					? array('sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat')
					: array('mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun');
									
		foreach ( $days as $day ) {
			$daysrow[]	= $this->cell(BText::_($day), array('class' => 'day'));
		}
		
		return $this->row($daysrow, array('class' => 'days'));
	}
}