<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Object
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Joomla Platform Object Class
 *
 * This class allows for simple but smart objects with get and set methods
 * and an internal error handler.
 *
 * @since       11.1
 * @deprecated  4.0
 */
class BookzoCalendar
{
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	public $app;
	
	public $settings;
	
	public $prices = array();
	
	public $types = array();
	
	protected $month;
	
	protected $number = 12;
	
	protected $blocks 	= array();
		
	protected $links 	= array();
	
	protected $dates 	= array();
	
	protected $rendermonths;
	
	protected $datelist;
	
	protected $activeperiod = false;
	
	/**
	 * Class constructor, overridden in descendant classes.
	 *
	 * @param   mixed  $properties  Either and associative array or another
	 *                              object to set the initial properties of the object.
	 *
	 * @since   11.1
	 */
	public function __construct($properties = array())
	{
		$this->app 			= Bookzo::getInstance();
		$this->settings		= new BRegistry;
		
		// set defaults
		$this->setMonth(date('Y-m-d'));
		
		// do properties override defaults
		if ( isset($properties['month']) ) {
			$this->setMonth($properties['month']);
		}
		
		if ( isset($properties['months']) ) {
			$this->setNumberOfMonths($properties['months']);
		}
	}
	
	public function setMonth($month)
	{
		$this->month = date('Y-m-01', strtotime($month));	
		
		return $this;
	}
	
	public function setNrOfMonths($nr)
	{
		$this->number = (int) $nr;
		
		return $this;
	}
		
	public function addPrice($price, $class = '', $firstclass = '', $lastclass = '', $linkclass = '')
	{
		// turn price into registry object
		$price  = new BRegistry($price);
		
		// make sure we have start and end
		$price->set('arrival', 		$this->app->date->create( $price->get('arrival') )->format('Y-m-d')); 
		$price->set('departure', 	$this->app->date->create( $price->get('departure') )->format('Y-m-d')); 
		$price->set('days', 		$this->app->date->diff($price->get('arrival'), $price->get('departure')));
		$price->set('class',		$class);
		$price->set('firstclass',	$firstclass);
		$price->set('lastclass',	$lastclass);
		$price->set('linkclass',	$linkclass);
		
		## NOTE - handle throught new price helper
		if ( ($priceid = $price->get('priceid')) && ($name = $price->get('periodname')) ) {
			$this->types[$price->get('periodkey')] = trim($name);
		}
		
		$this->prices[] = $price;
	}
		
	public function getMonthsToRender()
	{
		if ( !is_array($this->rendermonths) ) 
		{
			$filled = array();
			
			foreach ( $this->prices as $price ) {
				$startmonth = $this->app->date->create($price->get('arrival'))->format('Y-m-01');		
				$filled[] 	= $startmonth;
				
				if ( $this->activeperiod && $this->activeperiod->arrival == $price->get('arrival') && $this->activeperiod->departure == $price->get('departure') )
				{
					$this->settings->set('activetype', $price->get('periodkey'));
				}
				
				if ( $price->get('discount') && $this->settings->get('showprices') ) {
					$this->settings->set('hasdiscount', true);
				}
			
			# NOTE - Not yet, we use this when we have extended calendar
			//	$endmonth	= $this->app->date->create($block->end)->format('Y-m-01');
			//	$filled[]	= $endmonth;
			}
			
			$filled = array_unique($filled);
			sort($filled);
			
			$max			= count($filled) ? $this->number : 12;
			$start 			= $this->settings->get('emptybegin', true) || !count($filled) ? $this->app->date->create()->format('Y-m-01') : array_shift($filled);
			$end			= $max ? $this->app->date->create()->add($max, 'm')->format('Y-m-01') : array_pop($filled);
			$render			= array();
			$month			= $start;
	
			while ( $month <= $end ) {
				$render[] = $month;
				$month = $this->app->date->create($month)->add(1, 'm')->format('Y-m-01');
			}
			
			$this->rendermonths = $render;
		}
		
		return $this->rendermonths;
	}
	
	public function setActivePeriod($arrival, $departure)
	{
		if ( $arrival && $departure ) {
			$period 			= new stdClass();
			$period->arrival 	= $arrival;
			$period->departure 	= $departure;
			$this->activeperiod = $period;
		}
		
		return $this;
	}
	
	public function getActiveType()
	{
		$active = $this->settings->get('activetype');
		
		if ( $active && array_key_exists($active, $this->types) ) {
			return $active;
		}
		
		return $this->app->array->firstkey($this->types);
	}
	
	public function getPriceList()
	{
		$options = array();
		foreach ( $this->types as $key => $type ) 
		{
			$options[] = $this->app->html->select->option($key, $type);
		}
		
		return $this->app->html->select->genericlist('calendarpricetype', $options, $this->getActiveType(), 'data-bz-calender-type class="bz-input"');
	}
	
	public function render($echo = false)
	{
		$month			= $this->month;
		$months		 	= $this->getMonthsToRender();
		$return 		= array();
						
		foreach( $months as $month ) 
		{
			$tmp 		= new stdClass();
			$tmp->month = $month;
			
			// open table
			$html 	= array();
			$html[] = '<table class="bz-calendar '.($this->settings->get('hasdiscount') ? 'withdiscounts' : '').'" data-active-type="'.$this->getActiveType().'">';
			
			// add header
			$html[]	= $this->addHeader($month);
			
			// add days
			if ( $this->settings->get('show_days', 1) ) 
			{
				$html[]	= $this->addDays();
			}			
			
			// add body
			$html[]	= $this->addBody($month);
			
			// close table
			$html[]	= '</table>';
			
			$tmp->html = implode("\n", $html);
			
			// glue
			$return[] = $tmp;
		}
		
		return $return;
	}
	
	
	/**
	 * This function creates a row by calling addCell for each cell
	 *
	 * @access		private
	 * @param		$cells		array	array with all the cells for a specific row
	 * @return 		string
	 * @since		1.0
	 */
	protected function row( Array $cells = array(), $attr = '') 
	{
		$html 	= array();
		$class	= '';
		
		// get class
		if ( isset($attr['class']) ) {
			$class = $this->app->array->implodeRecursive($attr['class'], ' ', true);
			
			if ( strlen($class) ) {
				$class = 'class="'.$class.'"';
			}
		}
		
		// initiate
        $html[]	= '<tr '.$class.'>';
        
		// add cells
        foreach ($cells as $cell) {
			$html[] = $cell;      
        }
      
	  	// close row 
        $html[] = '</tr>';
		
		// return
		return implode("\n", $html);		
	}
	
	/**
	 * This function creates a cell and adds aditional html if requested
	 *
	 * @access		private
	 * @param		$cell 	array	a cell with the value and additional html
	 * @param		$type	string	the type of cell td or th
	 * @return 		string	
	 * @since		1.0
	 */
	protected function cell($text = '', $attr = '', $type = 'td') 
	{	
		$type 		= strtolower($type) == 'th' ? 'th' : 'td';
		$class		= '';
		$attributes	= '';
		
		if ( isset($attr['class']) ) {
			$class = $this->app->array->implodeRecursive($attr['class'], ' ', true);
			
			if ( strlen($class) ) {
				$class = 'class="'.$class.'"';
			}
		}
		
		if ( isset($attr['attr']) ) {
			$attributes = $this->app->array->implodeRecursive($attr['attr'], ' ', true);
		}
			
		return '<'.$type.' ' . $class . ' ' . $attributes . '>' .$text. '</'.$type.'>';
	}
		
	/**
	 * This function adds all the rows with the days for a requested month
	 * It will check each day for availabilty and add a class to the cell (day)
	 * We start off by getting the nr of weeks and nr of days for a month
	 * We add a correction to the starting day if calendar starts with a monday
	 * All days get calculated by counter + nr of days (i) - starting day
	 * This will make a day in last month get a value of 0 or below.
	 * We correct that value by adding up the nr of days of last month
	 *
	 * @access		private
	 * @param		none
	 * @return 		string	
	 * @since		1.0
	 */
	private function addBody($month)
	{
		// initiate
		$body		= array();
		
		// defaults
		$counter	= 1;
		$monthstamp	= strtotime($month);
		$monthshort = date('Y-m', $monthstamp);		
		
		// set some values that we are gonna need
		$dayscount		= date('t',$monthstamp);
		$startday		= date('w',$monthstamp);
		$dayslastmonth 	= date('t',$monthstamp - 86400);
		$weekcount 		= !$this->settings->get('variable_weeks', 0) 
						? 6
						: ceil( ($dayscount + $startday ) / 7 ); 
		$startday		= $this->settings->get('sunday', 0) 
						? $startday 
						: ( $startday ? $startday - 1 : $startday + 6);						

		// loop the weeks
		for( $j = 0; $j < $weekcount; $j++ ) 
		{
			// initiate row	
			$row		= array();
		
			// do we add the weeknr
			if ( $this->settings->get('show_weeks', 1) ) 
			{
				$weeknr = date('W', mktime(0,0,0,date('n',$monthstamp),$counter,date('Y',$monthstamp)));
				$row[] 	= $this->cell($weeknr, array('class' => 'weeknr'));
			}
			
			// add 7 days for each week
			for ( $i = 0; $i <= 6; $i++ ) 
			{
				// get day
				$day	= ( $i + $counter ) - $startday;
				$date	= date('Y-m-d', strtotime($monthshort .'-'.$day));	
				$today  = date('Y-m-d');
				
				// day is in other month
				if ( $day < 1 || $day > $dayscount ) 
				{
					$day	= $day < 1 ? (int) $day + $dayslastmonth : (int) $day - $dayscount;
					$row[] 	= $this->cell($day, array('class' => 'other-month'));
					continue;
				}
				
				if ( $date < $today && $oldclass = $this->settings->get('old') ) {
					$row[] 	= $this->cell($day, array('class' => $oldclass));
					continue;
				}
				
				// day is correct
				$row[] = $this->getDayCell( $day, $date );	
			}
			
			// add the week to the row and add a week to the counter
			$body[]	  = $this->row($row, array('class' => 'dates'));
			$counter += 7;
		}	
		
		return implode("\n", $body);
	}
	
	private function getDateList()
	{
		if (!count($this->datelist) )
		{
			$dates = array();
			
			foreach ( $this->prices as $price ) 
			{
				$date 	= $price->get('arrival');
				$stop	= $price->get('departure');
				
				while ( $date <= $stop )
				{
					$dates[] = $date;
					$date 	 = $this->app->date->create($date)->add(1)->format('Y-m-d');
				}
			}
			
			$this->datelist = array_unique($dates);
		}
		
		return $this->datelist;
		
		/*
		$dates = array();
		
		// first add the blocks
		foreach ( $this->blocks as $block ) 
		{
			$date 	= $block->start;
			$stop	= $block->end;
			
			while ( $date <= $stop )
			{
				$dates[$date] = array();
				
				if ( !empty($block->class) ) {
					$dates[$date][] = $block->class;
				}
				
				if ( $date == $block->start && isset($block->first) && !empty($block->first) ) {
					$dates[$date][] = $block->first;
				}
				
				if ( $date == $block->end && isset($block->last) && !empty($block->last) ) {
					$dates[$date][] = $block->last;
				}
				
				$date = $this->app->date->create($date)->add(1)->format('Y-m-d');
			}
		}
		
		// get months we need to render
		$months	= $this->getMonthsToRender();
	
		if ( count($months) ) {
			$first = $this->app->array->first($months);
			$last  = $this->app->array->last($months);
			
			$start = $this->app->date->create($first)->format('Y-m-01');
			$end   = $this->app->date->create($last)->format('Y-m-t');
			
			while ( $start <= $end ) {
				if ( !array_key_exists($start, $dates) ) {
					$dates[$start] = array( $this->settings->get('class', 'this-month') );
				}
				$start = $this->app->date->create($start)->add(1)->format('Y-m-d');
			}
		}
		
		ksort($dates);
		
		// now add the classes from transitions
		if ( count($this->transitions) ) {
			foreach ( $dates as $date => $classes ) {
			}
			
			
		}
		
		*/
		
	
	}
	
	/**
	 * Gets the class for a cell (date) for the calendar
	 *
	 * @access		private
	 * @param		$day	string	the date for a day
	 * @param		$days	array	all days know so far
	 * @return 		$days	array	a day with its class	
	 * @since		1.0
	 */
	private function getDayCell( $day, $date )
	{
		// initiate class
		$classes  		= array();
		$attr 			= array();
		$datelist		= $this->getDateList();
		$contents 		= array();
		$hasactive		= false;
		$isarrival		= false;
		$arrivaltype 	= $this->settings->get('arrivalday', 2);
	
		// add default attributs
		$attr[]		= 'data-stamp="'.strtotime($date).'"';
		$attr[]		= 'data-date="'.$date.'"';

		// check blocks to get correct class
		foreach ( $this->prices as $price ) {
			
			// add class to the cell if date is within range
			if ( $price->get('arrival') <= $date && $date <= $price->get('departure') ) {
				$classes[] = $price->get('class');
			}
			
			// add class if day is arrival day and first class is set
			if ( $date == $price->get('arrival') && $price->get('firstclass') ) {
				$yesterday = $this->app->date->create($date)->substract(1)->format('Y-m-d');
				if ( !in_array($yesterday, $datelist) ) {
					$classes[] = $price->get('firstclass');
				}
			}
			
			// do we have an arrival button for this date
			if ( $date == $price->get('arrival') ) 
			{
				// set defaults
				$isarrival 		= true;
				$text 			= $day;
				$data			= '';
				$link			= '';
								
				// do we show prices
				## NOTE - show normal price or price included?
				if ( $this->settings->get('showprices', 0) && $price->get('total') ) {
					$text .= '<span class="calendar-price '.($price->get('discount') ? 'withdiscount' : '' ).'">' 
						  . $this->app->price->render($price, 'single', $this->settings) 
						  . '</span>';
				}
				
				// do we highlight period
				if ( $this->settings->get('highlight', 0) == 1 )
				{
					$data = ' data-days="'.$price->get('days').'" ';
				}
				
				// do we add a link to the booking form
				if ( !$this->settings->get('linktype', 0) || !$this->settings->get('pricecalculation', 0) ) {
					$link = ' href="'. $this->app->adapter->route('task=book.request&object='. $price->get('objectid') . '&arrival='. $price->get('arrival') . '&departure=' . $price->get('departure')) .'&persons='.$price->get('persons', 1).'" ';
				}
				
				// do we want to update the pricecalculation
				if ( $this->settings->get('linktype', 0) && $this->settings->get('pricecalculation', 0) && ($arrivaltype == 2 || $arrivaltype == 3) ) {
					$data .= ' data-bz-directbooking="{arrival:\''.$price->get('arrival').'\', departure:\'' .$price->get('departure'). '\', coid: ' . $price->get('objectid') .'}"';
				}
									
				// they want the extended version	
				if ( $arrivaltype == 3 ) 
				{
					$typeclasses = array('arrival-date price-type price-type-'.str_replace(' ', '-',strtolower(trim($price->get('periodname')))));
					$isactive	 = $price->get('periodkey') == $this->getActiveType();
					$hasactive	 = $hasactive ? $hasactive : $isactive;
					
					if ( $isactive ) {
						$typeclasses[] = 'active-type';
					}
					
					$classes[] 	= $price->get('linkclass');
					
					$contents[] = '<a class="' . implode(' ', $typeclasses) . '" ' . $link . $data .'>' . $text . '</a>';
				}
				// they just want a link for an arrival date, so build one
				else if ( $arrivaltype == 2 && !count($contents) )
				{
					$classes[] 	= $price->get('linkclass');
					$contents[] = '<a class="arrival-date active-type" '. $link . $data.'>'.$text.'</a>';
				}
				// no links wanted but they want a sign for an arrival date
				else if ( $arrivaltype == 1 && !count($contents) ) {
					$classes[] 	= $price->get('linkclass');
					$contents[] = '<span class="arrival-date active-type" '.$data.'>'.$text.'</span>';
				}
			}
			
			// add class if day is departure date and last class is set
			if ( $date == $price->get('departure') && $price->get('lastclass') ) {
				$tomorrow = $this->app->date->create($date)->add(1)->format('Y-m-d');
				if ( !in_array($tomorrow, $datelist) ) {
					$classes[] = $price->get('lastclass');
				}
			}
		}
		
		// add default content if needed
		if ( $isarrival && $arrivaltype == 3 ) {
			$contents[]	= '<span class="price-type price-type-empty ' . ($hasactive ? '' : 'active-type'). '">'.$day.'</span>';
		}
		
		// if no contents just add the day
		if (!count($contents) ) {
			$contents[] = '<span class="empty">'.$day.'</span>';
		}
		
		// render the cell
		if ( !count($classes) ) {
			$classes[] = $this->settings->get('class', 'this-month');
		}
		
		// get attributes
		$classes 		= array_filter(array_unique($classes));
		
		// return the cell			
		return $this->cell(implode("\n", $contents), array('class' => $classes, 'attr' => $attr) );
	}

	
	protected function addHeader($month)
	{
		$headerrow		= array();
		
		if ( $this->settings->get('show_weeks', 1) ) {
			$headerrow[] = $this->cell('', '', 'th');
		}
		
		$headerrow[] 	= $this->cell(
								$this->app->date->create($month)->format('F Y'), 
								array('class' => 'month', 'attr' => 'colspan="7"'), 'th'
							);		
		
		return $this->row($headerrow, array('class' => 'month'));
	}
	
	protected function addDays()
	{
		$daysrow	= array();
		
		if ( $this->settings->get('show_weeks', 1) ) {
			$daysrow[] = $this->cell();
		}
		
		$days		= $this->settings->get('sunday', 0)
					? array('sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat')
					: array('mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun');
									
		foreach ( $days as $day ) {
			$daysrow[]	= $this->cell(BText::_($day), array('class' => 'day'));
		}
		
		return $this->row($daysrow, array('class' => 'days'));
	}
}