<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
 ## NOTE - Why isn't this a child class of bookzofilters
class BookzoFeatures extends BObject {
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */	
	protected $features;	
	
	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */	
	protected $groups;	
	
	public function getFeatures()
	{
		if ( is_null( $this->features ) ) {
			$this->features = $this->app->api->getFeatures();
		}
		
		return $this->features;
	}
	
	public function getFeature($id)
	{
		$features = $this->getFeatures();
		$return   = null;
		
		if ( array_key_exists($id, $features) ) {
			$return = $features[$id];
		}
		
		return $return;
	}
	
	public function getFeatureList($wanted, $group = false)
	{
		$return   	= array();
		$wanted 	= (array) $wanted;
		
		foreach ( $wanted as $id => $value )
		{
			if ($feature = $this->getFeature($id) )
			{
			
				if ( ($feature->get('isboolean') && strtolower($value) != 'true') || (!$feature->get('isboolean') && !strlen(trim($value)) )  ) {
					continue;
				}
				
				$tmp	 	= new stdClass();
				$tmp->isboolean = $feature->isboolean;
				$tmp->name 	= $feature->get('name');
				$tmp->value = $feature->getValue($value);
				$tmp->order	= $feature->get('sequence');
				$tmp->group	= $feature->get('groupname');
				
				$return[$id] = $tmp;
				
				/*if ( $group ) 
				{
					$return[$groupname][$id] = $tmp;
				}
				else {
					$return[$id] = $tmp;
				}*/
			}
		}

		if ( count($return) ) {		
			uasort($return, function($a, $b) { 				
				return ($a->order > $b->order); 
			});
		}
				
		if ( $group ) {
			$grouped = array();
			foreach ( $return as $k => $v ) {
				$grouped[$v->group][$k] = $v;
			}
			$return = $grouped;
		}
		
		return $return;
	}
}