<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BookzoFiltersFilter extends BookzoResponseData {
	
	protected $name;
	
	protected $groupname;
	
	protected $options = array();
	
	protected $current;
	
	protected $objects;
	
	protected $optioncount;
	
	/**
	 * Bind data to object.
	 * Override for parent class so we can set our own data
	 *
	 * @param   object  $item  The data object
	 * @return  void
	 * @access	proteced
	 * @since   1.0.0
	 */
	protected function bind($item)
	{		
	
		// set general properties
		$this->setProperties($item, array('featurename', 'featuretexts'));
		$this->set('count', 0);
		$this->set('max', 0);
					
		## NOTE only for now
		$values = isset($item->possiblevalues) ? $item->possiblevalues : array();

		$this->buildOptions( $values );
	}
	
	protected function buildOptions($options)
	{
		foreach ( $options as $v ) 
		{
			if ( strlen(trim($v)) ) {
				$value = new stdClass();
				$value->value 	= $v;
				$value->objects = array();
				$value->count	= 0;
				$value->max 	= 0;
				
				$this->optioncount++;
				$this->options[] = $value;
			}
		}
	}
	
	public function bindObjects($objects, $queriedobjects)
	{
		$objects 		= (array) $objects;
		$queriedobjects = (array) $queriedobjects;
		
		// loop each object to bind them to options
		foreach ( $objects as $object )
		{
			if ( $object instanceof BookzoObject ) 
			{
				// loop the options
				foreach ( $this->options as $option ) 
				{
					// examinate the option against the object and add it if it is present
					if ( $object->hasFeature($this->id, $option->value) && !in_array($object->get('id'), $option->objects) ) {
						$option->objects[] = $object->get('id');
						$option->max++;
						
						if ( array_key_exists($object->get('id'), $queriedobjects) )
						{
							$option->count++;
						}
					}
					
				}
			}
		}
		
		return $this;
	}
	
	public function getOptions( $showempty = false )
	{
		if ( $showempty ) {
			return $this->options;
		}
		else {
			$return = array();
			
			foreach ( $this->options as $k => $option ) 
			{
				if ( !$option->max || ($this->get('isboolean') && strtolower($option->value) != 'true') ) {
					continue;
				}
				else {
					$return[$k] = $option;
				}
			}
			
			return $return;
		}
	}
	
	public function getMaxCount()
	{
		return count($this->objects);
	}
	
	public function getActiveCount()
	{
		return count($this->activeobjects);
	}
	
	public function getOptionValue($index)
	{
		$return  = false;
		$options = $this->getOptions(true);
		
		if ( array_key_exists($index, $options) ) {
			$return = $options[$index]->value;
		}
		
		return $return;
	}
	
	public function render($showempty = false)
	{
		$options 		= $this->getOptions($showempty);
		$filteroptions 	= array();
		
		foreach ( $options as $k => $option ) 
		{	
			if ( strlen($option->value) ) 
			{
				
				$active 	= $this->app->bookzo->filters->isActive($this->get('id'), $k);
				$name 		= $option->value;
				$count		= $option->count;
					
				if ( !$this->get('isboolean') || (strtolower($name) == 'true')) {
									
					if ( $this->optioncount == 1 || $this->get('isboolean') ) {
						$name = $this->get('name');
					}
					/*
					if ( in_array(strtolower($name), array('true', 'false')) ) {
						$name = BText::_('FILTER_OPTION_'.$name);
					}
					*/
					
					$id		 	 = 'filter-'.$this->get('id').'-'.$k;
					$identifier  = 'data-identifier="'.$id.'"';
					
					$checked 	 = $active 		  	? ' checked="checked" ' 	: '';
					$disabled	 = !$option->count 	? ' disabled="disabled" ' 	: '';
					
					$attr 	 	 = 'data-bz-filter';
					$attr		.= ' data-ids="['.implode(',', $option->objects).']"';
					$attr 		.= ' ' . $identifier;
					
					
					$input 	 = '<input id="'.$id.'" type="checkbox" name="filters['.$this->get('id').'][]" value="'.$k.'" '. $attr . $checked . $disabled . ' />';
					$counter = '<span class="count">'.$count.'</span>';
					
					
					$filteroptions[] = $this->app->renderer->partial()->render('filter.option', compact('id', 'identifier', 'name', 'input', 'counter', 'count'));
				}
			}
		}
		
		$title  = '';
		$type 	= 'single';
		$id		= $this->get('id');
		
		if ( $this->optioncount > 1 && !$this->get('isboolean') ) {
			$type	= 'multiple';
			$title 	= $this->get('name');
		}
		
		return $this->app->renderer->partial()->render('filter.filter', compact('id', 'title', 'type', 'filteroptions'));
	}
}