<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BookzoGroup extends BookzoResponseData {
	
	protected $objects;	
		
	protected $periods;
	
	protected $arrivals;
	
	public function getObjects()
	{
		return array();
	}
	
	/**
	 * Get a list of free periods for this group
	 *
	 * @access	public
	 * @since   1.0.0
	 */
	public function getPeriods()
	{	
		if ( is_null($this->periods) ) 
		{
			$from   		= $this->app->date->create()->today('Y-m-d');
			$until  		= $this->app->date->create()->nextyear('Y-m-t');
			$this->periods 	= $this->app->api->getPrices( compact('from','until','group') );
		}
		
		return $this->periods;
	}
	
	/**
	 * Get a list of possible arrivals for this group
	 *
	 * @access	public
	 * @since   1.0.0
	 */
	public function getPossibleArrivals()
	{	
		if ( is_null($this->arrivals) ) 
		{
			$from   		= $this->app->date->create()->today('Y-m-d');
			$until  		= $this->app->date->create()->nextyear('Y-m-t');
			$this->arrivals = $this->app->api->getArrivals($start, $end, 0, $this->id);
		}
		
		return $this->arrivals;
	}
}