<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Object
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Joomla Platform Object Class
 *
 * This class allows for simple but smart objects with get and set methods
 * and an internal error handler.
 *
 * @since       11.1
 * @deprecated  4.0
 */
 
 
## NOTE - Why not have a protected construct and work with getinstance
abstract class BookzoPeriods 
{
	public $app;
	
	protected $start;
	
	protected $end;
		
	protected $query;
	
	protected $periods;
	
	protected $blocks;
	
	protected $pricedefinitions;
	
	protected $pricelist;
	
	protected $combinedpricelist;
	
	public function __construct( $query = array() )
	{
		// we need the app in this class
		$this->app 	 = Bookzo::getInstance();
				
		// feed query to class
		$this->query = new BRegistry();
		$this->query->loadArray($query);
		
		// get start and end
		$today			= $this->app->date->create()->format('Y-m-d');
		$start  		= $this->app->date->create( $this->query->get('start', date('Y-m-d')) )->format( 'Y-m-d' );
		$this->start	= $today > $start ? $today : $start;
		$this->end		= $this->app->date->create( $this->query->get('end', date('Y-m-t', strtotime($this->start))) )->format( 'Y-m-d' );
				
		// lets get the periods
		$dates			= $this->getDates();
		$this->periods 	= $this->format($dates);

		// get pricedefinitions to
		$this->getPriceDefinitions();
	}
	
	protected function format($dates)
	{
		$periods = array();
		
		if ( is_array($dates) ) {
		
			foreach ( $dates as $a ) 
			{
				if ( is_object($a) ) {
					$arrival = $this->app->date->create( $a->arrival )->format('Y-m-d');
					
					foreach ( $a->departures as $b ) 
					{
						$departure = $this->app->date->create( $b->departure )->format('Y-m-d');
						unset($b->departure);
						
						$periods[$arrival][$departure][] = $b;
					}
				}
			}
			
		}
		
		return $periods;
	}
	
	public function getBlocks()
	{
		if ( is_null($this->blocks) ) {
		
			$found 				= array();
			$pricedefinitions 	= $this->getPriceDefinitions();
			$actions			= $this->app->api->getActions();

			foreach ( $this->periods as $arrival => $departures ) 
			{			
				foreach ( $departures as $departure => $blocks ) {
									
					foreach ( $blocks as $block ) 
					{
						$tmp 				= $block;
						$tmp->arrival 		= $arrival;
						$tmp->departure 	= $departure;
						$tmp->name 			= isset($pricedefinitions[$block->priceid]) 
											? $pricedefinitions[$block->priceid]->get('name') 
											: '';
						$tmp->actionname 	= isset($tmp->actionid) && isset($actions[$tmp->actionid]) 
											? $actions[$tmp->actionid]->get('description', $actions[$tmp->actionid]->get('name') ) 
											: '';

						
						$found[] = $tmp;
					}	
				}
					
			}
			
			$this->blocks = $found;
		}
		
		return $this->blocks;
	}
	
	public function getPriceList()
	{
		if ( is_null($this->pricelist) )
		{
			$blocks 	= $this->getBlocks();
			$pricelist 	= array();
			
			foreach ( $blocks as $block ) {
				
				$pricelist[$block->objectid][$block->arrival][$block->departure] = $block;
					
				ksort($pricelist[$block->objectid][$block->arrival]);
				ksort($pricelist[$block->objectid]);
				ksort($pricelist);		
			}
			
			foreach ( $pricelist as $objectid => $arrivals ) 
			{
				foreach ( $arrivals as $arrival => $departures )
				{
					foreach ( $departures as $departure => $block ) {
						$pricelist[$objectid][$arrival][$block->priceid] = $block;
						unset($pricelist[$objectid][$arrival][$departure]);
					}
				}
			}
			
			$this->pricelist = $pricelist;
		}
		
		return $this->pricelist;
		
	}
	
	public function getCombinedList($id = 0)
	{
		if ( $id ) {
			$lists = $this->getPriceList();
			if ( !isset($lists[$id]) ) {
				return array();
			}
			return $lists[$id];			
		}
		
		if ( is_null($this->combinedpricelist) )
		{
			$blocks 	= $this->getBlocks();
			$pricelist 	= array();
			
			foreach ( $blocks as $block ) {
				
				$pricelist[$block->arrival][$block->departure] = $block;
					
				ksort($pricelist[$block->arrival]);
				ksort($pricelist);		
			}
			
			foreach ( $pricelist as $arrival => $departures ) 
			{
				foreach ( $departures as $departure => $block ) {
					$pricelist[$arrival][$block->priceid] = $block;
					unset($pricelist[$arrival][$departure]);
				}
			}
			
			$this->combinedpricelist = $pricelist;
		}
		
		return $this->combinedpricelist;
		
	}
	
	public function getPriceDefinitions($merge = false)
	{
		if ( !is_array($this->pricedefinitions) ) 
		{
			$definitions = array();
			$types 		 = array();
			
			// get all types first
			foreach ( $this->periods as $arrival ) {
				foreach ( $arrival as $departure ) {
					foreach ( $departure as $block ) {
						if ( !in_array($block->priceid, $types) )
						{
							$types[] = $block->priceid;
						}
					}
				}
			}
			
			if ( count($types) ) 
			{
				// now lets get the correct ones
				$definitions = $this->app->api->getPriceDefinitions($types);
				
				// order them by duration -> start
				uasort($definitions, function($a, $b) { return strcmp($a->numberofnights, $b->numberofnights); });
			}

			$this->pricedefinitions = $definitions;
		}
		
		return $this->pricedefinitions;
	}
	
	abstract protected function getDates();
}