<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BookzoQuery {
	
	/**
	 * A list of data received
	 *
	 * @var 	string
	 * @since 	1.0.0
	 */
	protected $method;
	
	/**
	 * The current name of the class
	 *
	 * @var 	string
	 * @since 	1.0.0
	 */
	protected $wheres;
	
	public function __construct()
	{
		$this->wheres = array();
	}
		
	/**
	 * Clear the where clause for the request
	 * 
	 * @param 	string $clause The name of the clause to clear
	 * @return 	self 
	 * @access	public
	 * @since 	1.0.0
	 */
	public function clear($clause = null)
	{
		switch ($clause)
		{
			case 'query':
				$this->method 	= null;
				break;

			case 'where':
				$this->wheres 	= array();
				break;

			default:
				$this->query 	= null;
				$this->wheres 	= array();

				break;
		}

		return $this;
	}
	
	/**
	 * Get the query for currentle active
	 * 
	 * @param 	none
	 * @return 	string	$query	the query set, if none the defaultquery 
	 * @access	public
	 * @since 	1.0.0
	 */
	public function set($method)
	{
		$this->method = (string) $method;
		
		return $this;
	}
	
	/**
	 * Get the query for currentle active
	 * 
	 * @param 	none
	 * @return 	string	$query	the query set, if none the defaultquery 
	 * @access	public
	 * @since 	1.0.0
	 */
	public function getMethod()
	{
		return $this->method;
	}
	
	/**
	 * Add a where clause to the list
	 * 
	 * @param string $name The name of the where value
	 * @params string $valye The value to set
	 * @return 	self 
	 * @since 	1.0.0
	 */
	public function where($name, $value)
	{
		$this->wheres[ (string) $name ] = $value;
		
		return $this;
	}
	
	/**
	 * Add a where clause to the list
	 * 
	 * @param string $name The name of the where value
	 * @params string $valye The value to set
	 * @return 	self 
	 * @since 	1.0.0
	 */
	public function wheres($vars)
	{
		$vars = (array) $vars;
		
		foreach ( $vars as $k => $v ) {
			$this->where($k, $v);
		}
		
		return $this;
	}
	
	/**
	 * Get the where clauses for the request
	 * 
	 * @param 	none
	 * @return 	array	$vars	the where vars currently set
	 * @access	public
	 * @since 	1.0.0
	 */
	public function getVars()
	{
		return $this->wheres;
	}
	
	/**
	 * Magic toString method for putting the query in readable format
	 *
	 * @param	none
	 * @return  string  The query in string format
	 * @access	public
	 * @since   1.0.0
	 */
	public function __toString()
	{
		$string   = array();
		$string[] = $this->method;
		
		if ( count( $this->wheres ) ) 
		{
			$wheres   = array();
			foreach ( $this->wheres as $k => $v ) {
				$wheres[] = $k . ' = ' . $v;
			}
			
			$string[] = 'WHERE ' . implode (' AND ', $wheres);
		}
		
		return implode(' ', $string);
	}
}