<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
class BookzoResponseData extends BObject {
	
	/**
	 * Unique identifier
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */	
	//protected $id;
	
	/**
	 * Class constructor
	 *
	 * @param   B   $app   A reference to the BookzoApp
	 * @param   string  $type  the data type
	 * @parm    object  $item  the data to merge
	 * @return	void
	 * @since   1.0.0
	 * @access	public
	 */
	public function __construct($item)
	{
		parent::__construct();
		
		//$this->id 	= (int) $id;
		$this->bind($item);
		
		// set app to be last for readability
		$app		= $this->app;
		unset($this->app);
		$this->app 	= $app;	
	}
	
	/**
	 * Bind data to object.
	 * Just forward to setProperties. 
	 * However childclasses can override this one to add own data
	 * This way childclasses can hold on to same __construct method
	 *
	 * @param   object  $item  The data object
	 * @return  void
	 * @access	proteced
	 * @since   1.0.o
	 */
	protected function bind($item)
	{
		$this->setProperties($item);
	}
	
	/**
	 * Returns a property of the object or the default value if the property is not set.
	 *
	 * @param   string  $property  The name of the property.
	 * @param   mixed   $default   The default value.
	 * @return  mixed   The value of the property.
	 * @since   1.0.0
	 * @access	public
	 */
	public function get($property, $default = null)
	{	
		// can we call a get
		$method = 'get' . ucfirst($property);
		if ( is_callable(array($this,$method)) ) 
		{
			$args 	 = func_get_args();
			$args	 = array_slice($args, 1);
			
			return call_user_func_array(array($this,$method), $args); 	
		}
		
		// try translate first
		if ( $return = $this->translate($property) ) {
			return $return;
		}
		
		// handle default option
		return parent::get($property, $default);
	}
	
	public function translate( $field, $always = true )
	{
		$return	= isset($this->$field) && (bool) $always ? $this->$field : '';
		$lang 	= $this->app->language->getId();
		
		if ( isset($this->texts) ) 
		{
			foreach ( $this->texts as $language ) 
			{
				if ( $language->languageid == $lang && isset($language->$field) && !empty($language->$field) ) {
					$return = $language->$field;
					break;
				}
			}
		}
		
		return $return;
	}
	
	/**
	 * Returns a date in specified format
	 *
	 * @param   string  $property  	The name of the property.
	 * @param   string  $format   	The date format
	 * @return  string   			The date formatted as asked for
	 * @since   1.1.2
	 * @access	public
	 */
	 public function getDate($name, $format = 'Y-m-d')
	 {
		 $return = false;
		 
		 if ( isset($this->$name) ) 
		 {
			 $return = $this->app->date->create($this->$name)->format($format);
		 }
		 
		 return $return;
	 }
}