<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data class.
 *
 * This class acts as parent for all data classes
 * It adds default functions like a magic method call 
 * for all child classes
 *
 * @subpackage 	framework.classes
 * @since 		1.0.0
 */
abstract class BookzoReview extends BObject implements BookzoReviewInterface {

	/**
	 * Reference to the global App object
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected static $reviewsystem;
		
	
	public static function getInstance($app, $type = 'default')
	{
		if ( is_null(self::$reviewsystem) ) 
		{	
			$type 		= empty($type) ? 'default' : $type;
			$name 		= strtolower($type);
			$classname 	= 'BookzoReview'. ucfirst($type);

			if ( $reviewsystem = $app->loader->register($classname, 'bookzo:review/'.$name.'.php')->get($classname) ) 
			{
				self::$reviewsystem = $reviewsystem;
			}
			else {
				self::$reviewsystem = $app->loader->register('BookzoReviewDefault', 'bookzo:review/default.php')->get('BookzoReviewDefault');
			}
		}
		
		return self::$reviewsystem;
	}
	
	public function getGrade( $id = 0 )
	{
		return $this->getReviewGrade( $id );
	}
	
	public function getCount( $id = 0 )
	{
		return $this->getReviewCount( $id );
	}
	
	public function getQuestionList( $id = 0 )
	{
		return $this->getReviewQuestionList( $id );
	}
	
	public function getReviews( $id = 0 )
	{
		return $this->getReviewReviews( $id );
	}
	
	public function getLink( )
	{
		return $this->getReviewLink();
	}
	
	public function has( $id = 0 )
	{
		return (bool) $this->getCount($id);
	}
	
	public function render($type, $id = 0)
	{
		$args 	= func_get_args();
		$params = isset($args[2]) ? $args[2] : array();
		$params = is_array($params) ? $params : array();
		$params = new BRegistry($params);
		
		switch ( $type )
		{
			default:
			case 'grade' :

					$grade = $this->getGrade($id);
					$count = $this->getCount($id);
					
					if ( $grade ) {
												
						return $this->app->renderer->partial()->render('review.grade', compact('grade', 'count', 'params'));
						
					}
			
			
				break;
				
			case 'list' :
					
					$grade 		= $this->getGrade($id);
					$count 		= $this->getCount($id);
					$questions 	= $this->getQuestionList($id);
					$reviews 	= $this->getReviews($id);
					$link		= $this->getLink();
					$maxshow	= $this->app->config->get('review.max', 5);
					
					if ( $grade ) {
						
						return $this->app->renderer->partial()->render('review.full', compact('grade', 'count', 'questions', 'reviews', 'maxshow', 'link', 'params'));
						
					}
			
			
				break;
				
			case 'small' :

					$grade = $this->getGrade($id);
					
					if ( $grade ) {
						
						return $this->app->renderer->partial()->render('review.small', compact('grade', 'params'));
						
					}
			
			
				break;
		}
	}
}

interface BookzoReviewInterface {
		
	public function getReviewGrade($id = 0);
	
	public function getReviewCount($id = 0);
	
	public function getReviewQuestionList($id = 0);
	
	public function getReviewReviews($id = 0);
	
	public function getReviewLink();
	
}

/**
 * The exception class dedicated for the controller classes
 *
 * @see AppController
 */
class BookzoReviewException extends BRuntimeException {}