<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
## NOTE - Why not also make methods for classes that work different (for instance with more values in the constructor
class BzHelperBookzo extends BHelper {
	
	/**
	 * Name of the wrapper class
	 *
	 * @var string
	 * @since 1.0.0
	 */
	protected static $instances;
	
	public function get($name)
	{
		## NOTE - we add func_get_args here
		// This way we can also add methods for classes with properties
		// they can refer back to this get method
		if ( !isset(self::$instances[$name])) 
		{
			$classname = 'Bookzo'.ucfirst($name);
			
			if ( class_exists($classname) ) 
			{
				try {
					self::$instances[$name] = new $classname();
				}
				catch ( Exception $e ) {
					throw new BRuntimeException(sprintf('Bookzo class: %s could not be loaded', $classname), 500);
				}
			}
			else {
				## NOTE - add backtrace for this error
				throw new BRuntimeException(sprintf('Bookzo class: %s could not be found', $classname), 500);
			}
		}
		
		return self::$instances[$name];		
	}

	/**
	 * Magic method to map to (most) bookzo classes
	 * 
	 * @param string $method The method name
	 * @param array $args The list of arguments
	 * 
	 * @return mixed The method result
	 * 
	 * @since 1.0.0
	 */	
	public function __get($name) 
	{
		return $this->get($name);
	}
}