<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperCache extends BHelper {
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function get($name, $minutes = 15, $dir = 'queries') 
	{
		$dir = $this->getDir($dir);
		
		if ( !$dir ) {
			return null;
		}
	
		// do we have it in internal cache
		if ( !isset($this->cache[$dir.$name]) ) 
		{
			// try loading cache file
			## NOTE - should we use md5
			$ret 		= null;
			$file		= $dir . '/' . $name . '.cache';
			$time		= is_int($minutes) ? $minutes : 15;
			$cachetime  =  $this->app->date->create()->substract($minutes, 'minute')->toUnix();
	
			// get content if file exists and not older then cachetime
			if ( $this->app->filesystem->file->exists( $file ) 
					&& ($minutes == 0 || $this->app->filesystem->file->filetime( $file ) > $cachetime) 
					&& $content = $this->app->filesystem->file->read( $file )
				) 
			{
				$ret = $content;
			}
			
			$this->cache[$dir.$name] = $ret;
		}
		
		
		return $this->cache[$dir.$name];
	}
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function cache($name, $content, $dir = 'queries') 
	{
		// write to cache file
		if ( $dir = $this->getDir($dir) )
		{
			$return = $this->app->filesystem->file->write( $dir . '/' . $name . '.cache', $content );
			
			// update also internal cache
			if ( $return ) {
				$this->cache[$dir.$name] = $content;
			}
			
			// return success
			return $return;
		}
		
		return false;
	}
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function getDir($dir = 'queries') 
	{
		$account = $this->app->config->get('general.accountname');
		$account = trim($account);
		
		if ( $this->app->string->isempty($account) ) {
			return false;			
		}

		return BOOKZO_CACHE . '/' . $account . (!$this->app->string->isempty($dir) ? '/'.$dir : '' );
	}
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function clear($dir = null, $filenames = array()) 
	{
		$filenames 	= (array) $filenames;
		$account 	= $this->app->config->get('general.accountname');
		$account 	= trim($account);
		
		if ( $this->app->string->isempty($account) ) {
			return false;			
		}

		$dir 		= $this->getDir($dir);
		
		if ( !count($filenames) )
		{
			if ( $this->app->filesystem->folder->exists($dir) ) {
				$this->app->filesystem->folder->delete($dir);
			}
		}
		else {
			foreach ( $filenames as $filename )
			{
				if ( $this->app->filesystem->file->exists($dir . '/' . $filename) ) {
					$this->app->filesystem->file->exists($dir . '/' . $filename);
				}
			}
		}
		
		return true;
		
	}
}