<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperData extends BHelper {

	/**
	 * The list of loaded data classes
	 * 
	 * @var array
	 * @since 1.0.0
	 */
	protected $classes;
	
	/**
	 * The list of loaded data classes
	 * 
	 * @var array
	 * @since 1.0.0
	 */
	protected $instances;
	
	/**
	 * The list of loaded data classes
	 * 
	 * @var array
	 * @since 1.0.0
	 */
	protected $singulars;
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function __construct($app) 
	{
		parent::__construct($app);
		
		// basis should be array
		$this->instances = array();
		$this->classes	 = array();
		
		// load base class
		$this->app->loader->register('BzData', 'classes:data/data.php');
	}
	
	
	## NOTE - Ask jon if he can always use ID / TEXT etc instead of groupid / objectid / objecttexts
	
	public function create($name, $item, $identifier)
	{
		// see if we can find correct class
		$name 		= strtolower($name);
		$singular 	= $this->singular($name);
		$class 		= $this->getClass($name, $singular);
		$altid	 	= $singular.'id';		
		
		// try to get identifier
		if ( isset($item->id) ) 
		{	 
			$identifier = $item->id;
		} 
		elseif ( isset($item->$altid) ) 
		{
			$identifier = $item->$altid;
			$item->id 	= $identifier;
		}
		else 
		{
			$item->id 	= $identifier;
		}
		
		// try getting the correct instance
		if ( !isset($this->instances[$name][$identifier]) ) 
		{
			try {
				$item = new $class($this->app, $item);
			}
			catch ( Exception $e ) {
				$item = false;
			}
			
			$this->instances[$name][$identifier] = $item;
		}
		
		// return
		return $this->instances[$name][$identifier];		
	}
	
	protected function getClass($name, $singular)
	{
		// first find correct class to map to
		if ( !isset($this->classes[$name]) ) 
		{
			// first try default
			$classname = 'BzData'.ucfirst($name);
			$this->app->loader->register($classname, 'classes:data/'.$name.'.php');
			
			// doens't exists try singular class
			if ( !class_exists($classname) ) 
			{
				$classname 	= 'BzData'.ucfirst($singular);
				$this->app->loader->register($classname, 'classes:data/'.$singular.'.php');
				
				// doesn't exists map to default
				if ( !class_exists($classname) ) {
					$classname = 'BzData';
				}
			}
			
			// add to list of found classes
			$this->classes[$name] = $classname;
		}
		
		// return
		return $this->classes[$name];
	}
	
	protected function singular($name)
	{
		if ( !isset($this->singulars[$name]) ) 
		{
			$this->singulars[$name] = $this->app->string->singularize($name);
		}
		
		return $this->singulars[$name];
	}
}