<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperDate extends BHelper {

	protected $date;

	/**
	 * Create a JDate object
	 *
	 * @param mixed $time optional time to set the date object to (default: 'now'). @see JDate
	 * @param mixed $offset The timezone offset to apply (default: null)
	 *
	 * @return JDate The JDate object set to the given time / offset
	 *
	 * @since 1.0.0
	 */
	 
			## NOTE - does not work look into date helper since now each create removes old one
	public function create($time = 'now', $offset = null) 
	{
		$this->date = new BDate($time, $offset);
		
		return $this;
	}

	public function format($format, $local = false, $translate = true) {
		
		if ( $translate && $this->app->language->hasKey($format) ) {
			$format = BText::_($format);
		}
		
		return $this->date->format($format, $local, $translate);
	}
	
	public function add($interval, $type = 'day')
	{		
		$this->date->add( $this->createInterval($interval, $type) );
		
		return $this;
	}
	
	public function substract($interval, $type = 'day')
	{		
		$this->date->sub( $this->createInterval($interval, $type) );
		
		return $this;
	}
	
	public function today($format = null)
	{	
		$return = $this->create();
		
		if ( $format ) {
			return $return->format($format);
		}
		
		return $return;
	}
	
	public function nextyear($format = null)
	{	
		$return = $this->create()->add(1, 'year');
		
		if ( $format ) {
			return $return->format($format);
		}
		
		return $return;
	}
	
	public function diff($start, $end)
	{		
		$start 	= strtotime( $this->create($start)->format('Y-m-d') );
		$end 	= strtotime( $this->create($end)->format('Y-m-d') );
		
		if ( $start > $end ) {
			$tmp 	= $start;
			$start 	= $end;
			$end 	= $start;
		}
		
		return  round(($end - $start) / 86400);
	}
	
	protected function createInterval($interval, $type = 'day')
	{
		switch ( strtolower($type) )
		{	
			case 'y' :		
			case 'year' :
				$interval = new DateInterval('P'.$interval.'Y');
				break;	
			case 'm' :
			case 'month' :
				$interval = new DateInterval('P'.$interval.'M');
				break;					
			case 'w' :
			case 'week' :
				$interval = new DateInterval('P'. ( 7 * $interval ) .'Y');
				break;
			case 'h':
			case 'hour' :
				$interval = new DateInterval('PT'. $interval .'H');
				break;				
			case 'i':
			case 'minute' :
				$interval = new DateInterval('PT'. $interval .'M');
				break;
			default:
			case 's' :
			case 'second' :
				$interval = new DateInterval('PT'.$interval.'S');
				break;			
			case 'd' :
			case 'day' :
				$interval = new DateInterval('P'.$interval.'D');
				break;
		}
		
		return $interval;
	}
	
	public function __call($method, $args) {
		return $this->_call(array($this->date, $method), $args);
	}
	
	public function __get($name) {
		return $this->date->{$name};
	}
}