<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperEvent extends BHelper {
	
	/**
	 * Name of the wrapper class
	 *
	 * @var string
	 * @since 1.0.0
	 */
	protected static $dispatcher;

	/**
	 * Class Constructor
	 * 
	 * @param App $app A reference to the global App object
	 */
	public function __construct($app) {
		
		parent::__construct($app);
	
		if (!isset(self::$_dispatcher)) {
			self::$dispatcher = new BEventDispatcher();
		}
	}
	
 	/**
	 * Create a new AppEvent object
	 * 
	 * @param mixed $subject The subject of the event
	 * @param string $name The event name
	 * @param array $parameters The parameters for the event
	 * 
	 * @return AppEvent The AppEvent object
	 * 
	 * @since 1.0.0
	 */
	public function create($name, $params = array())
	{
		return new BEvent($name, $params);
	}
	
	/**
	 * Get variables from the AppEventDispatcher object
	 * 
	 * @param string $name The name of the property to get
	 * 
	 * @return mixed The property value
	 * 
	 * @since 1.0.0
	 */
	public function __get($name) {
		
		if ($name == 'dispatcher') {
			return self::$dispatcher;
		}
		
		return null;
	}
}