<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperHtml extends BHelper {
	
	/**
	 * The list of helpers currently loaded
	 *
	 * @var 	array
	 * @since 	1.0.0
	 */
	protected $childs = array();
	
	/**
	 * Load an helper from the path
	 *
	 * @param string|array $helpers	Helper name or list of helper names to load
	 * @param string $suffix The suffix of the helper class. Default is "Helper"
	 * @since 1.0.0
	 */
	public function get($name) {
		
		if ( !isset($this->childs[$name]) ) 
		{
			$class = 'BHtml'.ucfirst($name);
	
			// autoload helper class
			if (!class_exists($class))
			{
				throw new BRuntimeException('html class not found');
			}
	
			$this->childs[$name] = new $class();

		}
		
		return $this->childs[$name];
	}
		
	/**
	 * Map all the methods to the BookzoApi class
	 * 
	 * @param string $method The method name
	 * @param array $args The list of arguments
	 * 
	 * @return mixed The method result
	 * 
	 * @since 1.0.0
	 */
    public function __call($method, $args) 
	{		
		return $this->_call(array('BHtml', $method), $args);
    }
	
	## NOTE - A lot of these __get why not put it in parent
	public function __get($name) 
	{
		return $this->get($name);
	}
}