<?php
/**
 * @package   bookzo
 * @author    Invenda  http://www.invenda.nl
 * @copyright Copyright (C) Invenda
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Helper do deal with request variables. Wrapper for JRequest
 *
 * @package Framework.Helpers
 */
class BzHelperlanguage extends BHelper {

	/**
	 * Name of the wrapper class
	 *
	 * @var string
	 * @since 1.0.0
	 */
	protected $_tag = 'nl';
	
	/**
	 * Name of the wrapper class
	 *
	 * @var string
	 * @since 1.0.0
	 */
	protected $class;

	/**
	 * Class Constructor
	 * 
	 * @param App $app A reference to the global App object
	 */
	public function __construct($app) {
		
		parent::__construct($app);
		
		$this->app->loader->register('BLanguage', 	'classes:language/language.php');
		$this->app->loader->register('BText', 		'classes:language/text.php');
		
		// find cms language		
		$langid			= $this->app->input->get('bookzolangid', 0);
		$langcode		= 'nl';

		// get bookzo language id
		if ( !$langid ) {
			
			$activelanguage = $app->adapter->getLanguage();
			$cmstags		= (array) $app->config->get('languages.tags', array());
		
			if ( strlen(trim($activelanguage)) ) {
				foreach ( $cmstags as $k => $v ) {
					if ( strtolower($activelanguage) == strtolower($v) ) {
						$langid = (int) $k;
					}
				}
			}
		}
		
		// set default language
		if ( !$langid ) {
			$langid = 1;
		}
		
		// get correct code (language file names)
		$prefixes		= (array) $app->config->get('languages.prefixes', array());
		foreach ( $prefixes as $k => $v ) {
			if ( $k == $langid ) {
				$langcode = $v;
			}
		}
		
		## NOTE - Raise error if language is not found or not set.		
		$this->_class 	= BLanguage::getInstance($app, $langcode, $langid);
	}
	
	
	
	public function getLanguage() {
		return $this->_class;
    }

	/**
	 * Map all the methods to the mapped class
	 *
	 * @param string $method The name of the method
	 * @param array $args The list of arguments to pass on to the method
	 *
	 * @return mixed The result of the call
	 *
	 * @see BInputFilter
	 *
	 * @since 1.0.0
	 */
    public function __call($method, $args) {
		return $this->_call(array($this->_class, $method), $args);
    }
}