<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Helper for the loading of classes. 
 * Wrapper for JLoader
 * 
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperLoader extends BHelper {

	/**
	 * Register a class with the loader
	 * 
	 * @param string $class the class name to load
	 * @param string $file The file that contains the class
	 * 
	 * @since 1.0.0
	 */
	public function register($class, $file) {
		if (!class_exists($class)) {
			BLoader::register($class, $this->app->path->path($file));
		}
		
		return $this;
	}
	
	/**
	 * Register a class with the loader
	 * 
	 * @param string $class the class name to load
	 * @param string $file The file that contains the class
	 * 
	 * @since 1.0.0
	 */
	public function get($classes) 
	{
		$return  = false;
		$args	 = func_get_args();
		$classes = (array) array_shift($args);
		
		foreach ($classes as $classname)
		{
			if ( class_exists($classname) ) 
			{
				if(!count($args)) 
				{
   					$return = new $classname;
				}
				else 
				{
   					$tmp 	= new ReflectionClass($classname);
   					$return = $tmp->newInstanceArgs($args);
				}
				
				// add reference to related app instance
				if (property_exists($return, 'app')) {
					$return->app = $this->app;
				}
				
				break;
			}
		}
		
		return $return;
	}
		
	/**
	 * Map all the methods to the JLoader class
	 * 
	 * @param string $method The method name
	 * @param array $args The list of arguments
	 * 
	 * @return mixed The method result
	 * 
	 * @since 1.0.0
	 */
    public function __call($method, $args) {
		return $this->_call(array('BLoader', $method), $args);
    }
}