<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperLog extends BHelper {
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function write($type, $text = '', $code = '', $suffix = '') 
	{
		$file = $this->getFile($suffix);
		
		if ( $file ) 
		{
			$content 	= $this->getContent($suffix);
			
			$parts 		= array();
			$parts[] 	= $this->app->date->create()->format('Y-m-d H:i:s');
			$parts[] 	= $type;
			if ( !empty($code) ) {
				$parts[]	= $code;
			}
			if ( !empty($text) ) {
				$parts[]	= $text;
			}
			
			$content    .= implode(' - ', $parts) . "\r\n";
			
			$this->app->filesystem->file->write($file, $content);			
		}
		
		return $this;
	}
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function getContent($suffix = '') 
	{
		$content = '';
		$file 	 = $this->getFile($suffix);
		
		if ( $file && $this->app->filesystem->file->exists( $file ) ) {
			 $content = $this->app->filesystem->file->read( $file );
		}
		
		return $content;
			 
	}
	
	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function getFile($suffix = '') 
	{
		$account = $this->app->config->get('general.accountname');
		$account = trim($account);
		
		if ( $this->app->string->isempty($account) ) {
			return false;			
		}

		return BOOKZO_LOG . '/' . $account . '/' . $this->app->date->create()->format('Y-m-d') . ( $suffix ? '.' . $suffix : '') . '.log';			 
	}
}