<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperPrice extends BHelper {

	public function create($price, $addons = array()) 
	{
		$price 		= $this->app->registry->create($price);
		
		if ( $price->get('calculated') ) {
			return $price->toObject();
		}
		
		$addons 	= $this->app->registry->create($addons);
		$return   	= $this->app->registry->create();
		
		$return->set('arrival', 			$price->get('arrival', 				$addons->get('arrival')));
		$return->set('departure', 			$price->get('departure',			$addons->get('departure')));
		$return->set('priceid', 			$price->get('priceid', 				$addons->get('priceid', 0)));
		$return->set('actionid', 			$price->get('actionid', 			$addons->get('actionid', 0)));
		$return->set('price', 		 		$price->get('price', 				0));
		$return->set('extracosts', 			$price->get('extracosts', 			0));
		$return->set('pricebeforediscount', $price->get('pricebeforediscount',  0));
		$return->set('total', 		 		$price->get('total',				0));
		$return->set('nights',	 			0);
		$return->set('minnights',	 		0);
		$return->set('calculated',	 		1);
		
		if ( $objectid = $price->get('objectid') ) {
			$return->set('objectid' , $objectid);
		}
		
		if ( $return->get('arrival') ) {
			$return->set('arrival', $this->app->date->create($return->get('arrival'))->format('Y-m-d'));
		}
		
		if ( $return->get('departure') ) {
			$return->set('departure', $this->app->date->create($return->get('departure'))->format('Y-m-d'));
		}
		
		// set nr of nights
		$return->set('nights', $this->app->date->diff($return->get('arrival'), $return->get('departure')));
				
		// discount before can not be lower
		if ( $return->get('pricebeforediscount') < $return->get('price') ) {
			$return->set('pricebeforediscount', $return->get('price'));
		}
		
		// total can not be lower
		if ( $return->get('total') < $return->get('price') ) {
			$return->set('total', $return->get('price'));
		}
		
		// calculate totalbeforediscount
		$return->set('totalbeforediscount', (float) $return->get('pricebeforediscount') + (float) $return->get('extracosts'));
		
		// calculate discount
		$return->set('discount', (float) $return->get('pricebeforediscount') - (float) $return->get('price'));
					
		// add pricename if applied
		if ( ($priceid = $return->get('priceid')) && ($pricedef = $this->app->api->getPriceDefinitions($priceid)) ) {
			$day 	= date('D', strtotime($return->get('arrival')));
			$return->set('periodname', $pricedef->get('name'));
			$return->set('minnights',  $pricedef->get('minnumberofnights'.strtolower($day), $pricedef->get('minnumberofnights', 0)));
			$return->set('periodkey',  str_replace(' ', '-',strtolower(trim($pricedef->get('name')))));  
		}
		
		// add actionname if applied
		if ( ($actionid = $return->get('actionid')) && ($action = $this->app->api->getActions(false, $actionid)) ) {
			$return->set('actionname', $this->app->config->get('template.discounts_name_type', 'name') == 'name' 
											? $action->get('name') 
											: $action->get('description', $action->get('name'))
			); 
		}
		
		
		// add extracostnames
		$extracosts = $price->get('costsspecification', array());
		foreach ( $extracosts as $extracost ) {
			if ( $cost = $this->app->api->getExtraCosts($extracost->id) ) {
				$extracost->name = $cost->get('name');
			}
		}
		
		$return->set('costsspecification', 	$extracosts);	
		
		return $return->toObject();
	}
	
	public function render($price, $type = 'default', $params = null)
	{
		// create priceobject
		$params 	= $this->app->registry->create($params);
		$price 		= $this->app->registry->create( $this->create($price) );
				
		// lets render : )
		return $this->app->renderer->partial()->render('price.'.$type, compact('price', 'params'));
	}
	
	public function calculation($price, $jsonencode = false, $params = null)
	{
		$price 	= $this->app->registry->create( $this->create($price) );
		$return	= $this->app->renderer->partial()->render('price.minicalculation', compact('price', 'params'));
		
		if ( $jsonencode ) {
			return $this->app->string->dataAttributePrepare($return);
		}
		
		return $return;
	}
	
	public function format($price, $params = null)
	{
		$params = $this->app->registry->create($params);
		$html 	= '';
		
		// show currency
		if ( ($currency = $params->get('pricecurrency', $this->app->config->get('template.pricecurrency'))) && !$params->get('hidecurrency') ) {
			$html .= '<em class="bz-currency">'. $currency . '</em> ';
		}
		
		// format price
		$price 	= (float) $price;
		$style	= $params->get('pricestyle', $this->app->config->get('template.pricestyle'));
		
		switch( $style ) {
			
			default:
			case 'always': 
					$price = number_format($price, 2, ',', '.');
					break;
			case 'round':
					$price = round($price);
					break;
			case 'nozero':
			case 'zerochange':
					if ( round($price) == $price ) {
						$price = round($price) . ( $style == 'zerochange' ? ',-' : '' );
					}
					else {
						$price = number_format($price, 2, ',', '.');
					}
					break;
		
		}
		
		return $html . $price;
	}
	
}