<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperRegistry extends BHelper {

	/**
	 * Map all the methods to the adapter class
	 *
	 * @param string $method The name of the method
	 * @param array $args The list of arguments to pass on to the method
	 *
	 * @return mixed The result of the call
	 *
	 * @see BInputFilter
	 *
	 * @since 1.0.0
	 */
    public function create($data = null) {
		
		$return = new BRegistry();
		
		if ( !is_null($data) ) {
			if ( is_string($data) ) {
				$return->loadString($data);
			}
			if ( is_array($data) ) {
				$return->loadArray($data);
			}
			if ( is_object($data) ) {
				if ( $data instanceof BRegistry ) {
					$return = $data;
				}
				else {
					$return->loadObject($data);
				}
			}				
		}
		
		return $return;
    }
	
	/**
	 * Map all the methods to the adapter class
	 *
	 * @param string $method The name of the method
	 * @param array $args The list of arguments to pass on to the method
	 *
	 * @return mixed The result of the call
	 *
	 * @see BInputFilter
	 *
	 * @since 1.0.0
	 */
    public function creategroup( array $array ) {
		
		$return = array();
		
		foreach ( $array as $k => $v ) {
			$return[$k] = $this->create( $v );
		}
		
		return $return;
    }
}