<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing reviews
 * Bookzo doesn't actually has a review system
 * CMS's shoul implement their own system and hooking into bookzo
 * By default the default review system is loaded which only returns empty values
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperReview extends BHelper {
	
	/**
	 * Name of the wrapper class
	 *
	 * @var string
	 * @since 1.0.0
	 */
	protected $_class;
	
	/**
	 * Name of the wrapper class
	 *
	 * @var string
	 * @since 1.0.0
	 */
	protected $_type = 'default';

	/**
	 * Set the type for the review system
	 * This is part of the hook for the CMS.
	 * On CMS load they should call bookzo and set the type 
	 * The review class should have been registered before. So it should look like this in total
	 *
	 *
	 * $bookzo->path->register( __DIR__ '/review/', 'reviewsystem' );
	 * $bookzo->loader->register('BookzoReviewMyExtenionName, 'reviewsystem:myexenstionname.php');
	 * $bookzo->review->setType('MyExtensionName');
	 *
	 *
	 *
	 * @return mixed The result of the call
	 *
	 * @see BInputFilter
	 *
	 * @since 1.1.1
	 */
	public function setType($type)
	{
		if ( $this->_type != $type ) {
			$this->_type 	= $type;
			$this->_class 	= null;
		}
	}
	
	/**
	 * Load correct reviewsystem
	 * Type should be set by a hook in the CMS
	 *
	 * @return mixed The result of the call
	 *
	 * @see BInputFilter
	 *
	 * @since 1.1.1
	 */
	protected function load()
	{
		if ( is_null($this->_class) ) 
		{
			$this->_class = BookzoReview::getInstance($this->app, $this->_type);
		}
		
		return $this;
	}
	
	/**
	 * Map all the methods to the mapped class
	 *
	 * @param string $method The name of the method
	 * @param array $args The list of arguments to pass on to the method
	 *
	 * @return mixed The result of the call
	 *
	 * @see BInputFilter
	 *
	 * @since 1.0.0
	 */
    public function __call($method, $args) {
		
		$this->load();
				
		if ( $this->_class && method_exists($this->_class, $method) ) {
			return $this->_call(array($this->_class, $method), $args);
		}
		
		return null;
    }
}