<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzHelperSearch extends BHelper {

	protected $objects;
	
	protected $found = array();
	
	/**
	 * Search bookzo objects by string
	 *
	 * @var 	string	$string		the word to search for
	 * @return	array	$return		the ids of found matches
	 *
	 * @since	1.2.8
	 */
	public function search($string) 
	{
		// unifiy string
		$string = strtolower(trim($string));
		
		// do we have anything to search for
		if ( !strlen($string) ) {
			return array();
		}
		
		// did we search this allready
		if ( !isset($this->found[$string]) ) 
		{ 
			// get objects
			if ( is_null($this->objects)) {
				$this->objects = $this->app->api->getObjects();
			}
			
			$found = array();
			
			// search all objects
			foreach ( $this->objects as $object ) 
			{
				$name 		 = $object->get('name');
				$description = $object->get('description');
				$groupname	 = $object->get('groupname');
				
				if ( strpos(strtolower($name), $string) !== false || strpos(strtolower($description), $string) !== false || strpos(strtolower($groupname), $string) !== false ) {
					$found[] = $object;
				}
			}
			
			// do we group
			if ( $this->app->config->get('bookzo.bookpergroup', 0) ) 
			{
				$tmp 		 = array();
				$foundgroups = array();
				
				foreach ( $found as $k => $item ) {
					if ( !in_array($item->get('groupid'), $foundgroups) ) {
						$foundgroups[] = $item->get('groupid');
						$tmp[$k] = $item;
					}
				}
				
				$found = $tmp;
			}
			
			// cache
			$this->found[$string] = $found;
		}
		
		return $this->found[$string];
	}
	
}