<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
## NOTE - Why not also make methods for classes that work different (for instance with more values in the constructor
class BzHelperTargetPay extends BHelper {
	
	/**
	 * Holder for a list of payment methods
	 *
	 * @var 	App
	 * @since 	1.0.0
	 */
	protected $methods;
	
	/**
	 * Name of the wrapper class
	 *
	 * @var string
	 * @since 1.0.0
	 */
	protected $_class;

	/**
	 * Get a data class object
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function get($name) 
	{
		
		// get classname and load it
		$class = 'BTargetpay'.ucfirst(strtolower($name));

		// add data class to stack, if not exists
		if (!isset($this->cache[$name])) 
		{
			if ( class_exists($class) ) {
				$this->cache[$name] = new $class($this->app, $this->app->config->get('bookzo.onlinepaymentlogin'));
			}
			else {
				throw new BRuntimeException('TargetPay Method '. $name . ' can not be found');
			}
		}

		return $this->cache[$name];
	}
	
	/**
	 * Magic method to get a data class using the name
	 *
	 * @param string $name The name of data class 
	 * @return BzData The table object 
	 * @since 1.0.0
	 */
	public function __get($name) 
	{
		return $this->get($name);
	}
	
	/**
	 * Method to get a singleton controller instance.
	 *
	 * @param   string  $prefix  The prefix for the controller.
	 * @param   array   $config  An array of optional constructor options.
	 *
	 * @return  JControllerLegacy
	 *
	 * @since   12.2
	 * @throws  Exception if the controller cannot be loaded.
	 */
	public function getPaymentMethods()
	{
		if ( is_null($this->methods) ) 
		{
			$methods 	= array();
			$selected	= $this->app->config->get('bookzo.onlinepaymentmethods', 0); 
			
			if ( $this->app->string->bitComparison(1, $selected) || $selected == 'IDeal' ) {
				$methods['IDeal'] = $selected == 'IDeal' ? $selected : BText::_('FIELD_BOOK_PAYMENTMETHOD_OPTION_IDEAL');
			}
			if ( $this->app->string->bitComparison(2, $selected) || $selected == 'MrCash' ) {
				$methods['MrCash'] = $selected == 'MrCash' ? $selected : BText::_('FIELD_BOOK_PAYMENTMETHOD_OPTION_MRCASH');
			}
			if ( $this->app->string->bitComparison(4, $selected) || $selected == 'DirectBanking' ) {
				$methods['DirectBanking'] = $selected == 'DirectBanking' ? $selected : BText::_('FIELD_BOOK_PAYMENTMETHOD_OPTION_DIRECTBANKING');
			}
			if ( $this->app->string->bitComparison(8, $selected) || $selected == 'OVerboeken') {
				$methods['OVerboeken'] = $selected == 'OVerboeken' ? $selected : BText::_('FIELD_BOOK_PAYMENTMETHOD_OPTION_OVERBOEKEN');
			}
			
			$this->methods = $methods;
		}
		
		return $this->methods;
	}
}