<?php
/**
 * @package   bookzo
 * @author    Invenda  http://www.invenda.nl
 * @copyright Copyright (C) Invenda
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Base View class
 *
 * @package Framework.Classes
 */
class BzModelBook extends BModelForm {
	
	/**
	 * Method to get the record form.
	 *
	 * @param	array	$data		Data for the form.
	 * @param	boolean	$loadData	True if the form is to load its own data (default case), false if not.
	 * @return	mixed	A JForm object on success, false on failure
	 * @since	1.6
	 */
	public function getForm($data = array(), $loadData = true)
	{
		// Get the form.
		$form = $this->loadForm('bookzo.book', 'book', array('control' => 'book', 'load_data' => $loadData));
		
		if (empty($form)) {
			return false;
		}	
		
		return $form;
	}
	
	public function paymentActive()
	{
		//if ( $this->app->config->get('general.usepayment') && $this->app->config->get('bookzo.onlinepaymentactive', 0) ) {
		if ( $this->app->config->get('bookzo.onlinepaymentactive', 0) ) {
			return true;
		}
		
		return false;
	}
	
	public function getPaymentAmount()
	{
		if ( $this->paymentActive() && ( $booking = $this->getBooking() ) !== false ) 
		{
			$data 	 = $this->state->get('data');
			$type 	 = $this->app->config->get('bookzo.onlinepaymentamount');
			$prepaid = $booking->get('prepaymentamount');
			$total	 = $booking->getTotalPrice();
			
			if ( $type == 'Partially' ) {
				return $prepaid;
			}
			elseif ( $type == 'Total' ) {
				return $total;
			}
			
			return ($data->get('pay.amount', 'partial') == 'partial' ? $prepaid : $total);
		}
		
		return 0;
	}
	
	public function getSteps()
	{
		// show detail page?
		$showdetail = true;
		if ( $this->app->config->get('book.hidedetails', 0) && $this->state->get('exactbooking', 0) ) {
			$showdetail = false;
		}
		
		// get order by settings
		$steps  = array();
		$order 	= (int) $this->app->config->get('book.page_order', 1);

		switch ($order) 
		{
			default:
			case 1:
				$steps 	  	= $showdetail 
							? array( 1 => 'details', 2 => array('guest', 'guests'), 3 => array('items', 'remarks'))
							: array( 1 => array('guest', 'guests'), 2 => array('items', 'remarks'));
				break;
			case 2:
				$steps 	  	= $showdetail 
							? array( 1 => 'details', 2 => array('guest', 'guests'), 3 => 'items', 4 => 'remarks')
							: array( 1 => array('guest', 'guests'), 2 => 'items', 3 => 'remarks');
				break;
			case 3:
				$steps 	  	= $showdetail 
							? array( 1 => 'details', 2 => 'guest', 3 => 'guests', 4 => array('items', 'remarks'))
							: array( 1 => 'guest', 2 => 'guests', 3 => array('items', 'remarks'));
				break;
			case 4:
				$steps 	  	= $showdetail 
							? array( 1 => 'details', 2 => 'guest', 3 => 'guests', 4 => 'items', 5 => 'remarks')
							: array( 1 => 'guest', 2 => 'guests', 3 => 'items', 4 => 'remarks');
				break;
			case 5:
				$steps 	  	= $showdetail 
							? array( 1 => 'details', 2 => 'items', 3 => array('guest', 'guests'), 4 => 'remarks')
							: array( 1 => 'items', 2 => array('guest', 'guests'), 3 => 'remarks');
				break;
			case 6:
				$steps 	  	= $showdetail 
							? array( 1 => 'details', 2 => 'items', 3 => 'guest', 4 => 'guests', 5 => 'remarks')
							: array( 1 => 'items', 2 => 'guest', 3 => 'guests', 4 => 'remarks');
				break;
			case 7:
				$steps 	  	= $showdetail 
							? array( 1 => 'details', 2 => 'items', 3 => array('guest', 'guests', 'remarks'))
							: array( 1 => 'items', 2 => array('guest', 'guests', 'remarks'));
				break;
		}
		
		// do we have a payment section
		if ( $this->paymentActive() ) {
			$steps[] = 'pay';
		}
		
		if ( $this->app->config->get('book.opc', 0) )
		{
			$tmp = array( 1 => array() );
			
			foreach ( $steps as $step ) {
				if ( is_array($step) ) {
					foreach ( $step as $substep ) {
						$tmp[1][] = $substep;
					}
				}
				else {
					$tmp[1][] = $step;
				}
			}
			
			$steps = $tmp;
		}
		
		return $steps;
	}
	
	public function getStepTitles()
	{
		$steps 	= $this->getSteps();
		$titles = array();
		
		foreach ( $steps as $k => $step ) {
			$titles[$k] = BText::_('BOOK_STEP_TITLE_' . (is_array($step) ? implode('_', $step) : $step));
		}
		
		return $titles;
	}
	
	public function getTotalSteps()
	{
		$steps = $this->getSteps();
		
		return count($steps);
	}
	
	public function getCurrentPage()
	{
		$state = $this->getState();

		return $state->get('page', 1);
	}
		
	protected function showGroup($name)
	{
		## NOTE - UGGLLLYYY
		$step 		= $this->getCurrentPage();
		$steps 		= $this->getSteps();
		
		$stepname 	= isset($steps[$step]) ? $steps[$step] : 'details';
		
		if ( $name == $stepname || (is_array($stepname) && in_array($name, $stepname)) ) {
			return true;
		}
		
		return false;
	}
	
	public function getObject()
	{
		if ( !isset($this->cache['object']) ) 
		{
			$object		 = false;
			$oid 	 	 = $this->getState('object');
			
			# NOTE - not correct need checks on arrival and departure date
			if ( $oid ) 
			{
				$object  = $this->app->api->getObjects($oid);
			}
			
			$this->cache['object'] = $object;
			
		}
		
		return $this->cache['object'];
	}
	
	public function getBooking()
	{
		if ( !isset($this->cache['booking']) ) 
		{
			$booking = false;
			$object	 = $this->getObject();
			
			if ( $object ) 
			{
				$arrival 	 = $this->getState('arrival');
				$departure 	 = $this->getState('departure');
				$persons	 = $this->getState('persons', 2);
				$seniors	 = $this->getState('seniors', 0);
				$childs		 = $this->getState('childs', 0);
				$babys		 = $this->getState('babys', 0);
				$pets		 = $this->getState('pets', 0);
				$coupon 	 = $this->getState('coupon');
				$items		 = (array) $this->getState('items', array());

				$booking	 = $this->app->api->getProspect($object->get('id'), $arrival, $departure, $persons, $seniors, $childs, $babys, $pets, $items, $coupon);
				
				if ( !$booking || !$booking->isValid() ) {
					$booking = false;
				}
				
				// set data for google dm
				if ( !$booking || $booking->getTotalPrice() == 0 ) {
					$this->app->adapter->sessionSet('bookzo.orderdetails', array('success' => false));
				} else {
					$this->app->adapter->sessionSet('bookzo.orderdetails', 
						array('success' => true, 'total' => $booking->getTotalPrice(), 'object' => $object->get('id'), 
							  'arrival' => $arrival, 'departure' => $departure )
					);
					
				}

				/*
				if ( $booking )
				{
					$booking->setGuest($data->get('guest'));
					$booking->setGuests($data->get('guests'));
					$booking->setComments($data->get('remarks.remarks'));
					$booking->setKnownFrom($data->get('remarks.knowfrom'));
				}
				*/
			}
			
			$this->cache['booking'] = $booking;
		}
		
		return $this->cache['booking'];
	}
	
	/**
	 * Method to allow derived classes to preprocess the form.
	 *
	 * @param   JForm   $form   A JForm object.
	 * @param   mixed   $data   The data expected for the form.
	 * @param   string  $group  The name of the plugin group to import (defaults to "content").
	 *
	 * @return  void
	 *
	 * @see     BFormField
	 * @since   12.2
	 * @throws  Exception if there is an error in the form event.
	 */
	protected function preprocessForm(BForm $form, $data)
	{
		$object  	= $this->getObject();
		$booking 	= $this->getBooking();
		$tmpdata	= $this->state->get('data');
		
		if ( $booking && $object ) 
		{
			// start of by making person fields
			$min = $object->get('minguestcount');
			$max = $object->get('numberofbeds');

			// get settings		
			$seniorage 		= $this->app->config->get('bookzo.minagesenior', 0);
			$babyage  		= $this->app->config->get('bookzo.maxagebaby', 0);
			$childage 		= $this->app->config->get('bookzo.maxagechild', 0);

			// do we have seniors			
			if ( !$seniorage ) {
				$form->removeField('seniors', 'details');
			}
			else {
				$form->setFieldAttribute('seniors', 'label', BText::sprintf('FIELD_BOOK_SENIORS_LABEL', $seniorage), 'details');
				$this->addIntegerOptions($form, 'seniors', 'details', 0, $max);
			}
			
			// do we have babys
			if ( !$babyage ) {
				$form->removeField('babys', 'details');
			}
			else {
				$form->setFieldAttribute('babys', 'label', BText::sprintf('FIELD_BOOK_BABYS_LABEL', $babyage), 'details');
				$this->addIntegerOptions($form, 'babys', 'details', 0, $max - 1);
			}
			
			// do we have childs
			if ( !$childage ) {
				$form->removeField('childs', 'details');
			}
			else {
				$label = $babyage 
					   ? BText::sprintf('FIELD_BOOK_CHILDS_BABYS_LABEL', $babyage + 1, $childage) 
					   : BText::sprintf('FIELD_BOOK_CHILDS_LABEL', $childage);
					   
				$form->setFieldAttribute('childs', 'label', $label, 'details');
				$this->addIntegerOptions($form, 'childs', 'details', 0, $max - 1);
				
				// also update persons label
				//$form->setFieldAttribute('persons', 'desc', 	BText::_('FIELD_BOOK_ADULTS_DESC'), 'details');
				//$form->setFieldAttribute('persons', 'msg', 		BText::_('FIELD_BOOK_ADULTS_MSG'), 'details');
			}
			
			// get correct persons field desc
			if ( $seniorage || $childage || $babyage ) {
				$minpersonage = $childage ? $childage : ($babyage ? $babyage : 0);
				$maxpersonage = $seniorage ? $seniorage : 0;
				
				$form->setFieldAttribute('persons', 'desc', 	BText::_('FIELD_BOOK_ADULTS_DESC'), 'details');
				$form->setFieldAttribute('persons', 'msg', 		BText::_('FIELD_BOOK_ADULTS_MSG'), 'details');
				
				if ( $minpersonage && !$maxpersonage ) {
					$form->setFieldAttribute('persons', 'label', 	BText::sprintf('FIELD_BOOK_ADULTS_MIN_LABEL', $minpersonage), 'details');
				}
				elseif ( $maxpersonage && !$minpersonage ) {
					$form->setFieldAttribute('persons', 'label', 	BText::sprintf('FIELD_BOOK_ADULTS_MAX_LABEL', $maxpersonage), 'details');
				}
				else {
					$form->setFieldAttribute('persons', 'label', 	BText::sprintf('FIELD_BOOK_ADULTS_MIN_MAX_LABEL', $minpersonage + 1, $maxpersonage), 'details');
				}
			}
			
			// add persons
			$minpersons = $seniorage ? 0 : $min;
			$this->addIntegerOptions($form, 'persons', 'details', $minpersons, $max);
			
			// add dates to the form
			$arrival = $form->getField('arrival', 'details');
			if ( $arrival ) {
				$arrival->addOption( $this->state->get('arrival'), $this->app->date->create($this->state->get('arrival'))->format('DATE_FORMAT_DEFAULT') );
			}
			
			$departure = $form->getField('departure', 'details');
			if ( $departure ) {
				$departures = $booking->get('possibledepartures', array());
				if ( count($departures) ) {
					sort($departures);
					foreach ( $departures as $d ) {
						$departure->addOption( $this->app->date->create($d)->format('Y-m-d'), $this->app->date->create($d)->format('DATE_FORMAT_DEFAULT') );
					}
				}
				else {
					$departure->addOption( $this->state->get('departure'), $this->app->date->create($this->state->get('departure'))->format('DATE_FORMAT_DEFAULT') );
				}
			}
			
			// add cars to the form?
			if ( !$this->app->config->get('book.show_licenseplate', 0) ) {
				$form->removeField('car', 'guest');
				$form->removeField('licenseplate', 'guest');
			}
			else if ( $tmpdata->get('guest.car', 0) != 1 ) {
				$form->removeField('licenseplate', 'guest');
			}
			
			// add pets to the form
			$petsallowed = $object->get('pets');
			$pets		 = $form->getField('pets', 'details');
			if ( $pets && $petsallowed && $this->app->config->get('book.usepets', 1) ) {
				for ( $i = 0; $i <= $petsallowed; $i++ ) 
				{
					$pets->addOption($i);
				}
			}
			else {
				$form->removeField('pets', 'details');
			}
			
			// do we use coupon 
			$couponshow = $this->app->config->get('book.coupon', 0);
			if ( !$couponshow ) {
				$form->removeField('coupon', 'details');
			}
			
			// is mobile required
			$mobileshow = $this->app->config->get('book.show_mobile');
			if ( !$mobileshow ) {
				$form->removeField('mobile', 'guest');
			}
			else {
				$form->setFieldAttribute('mobile', 'required', $mobileshow == 2, 'guest');
			}
			
			// do we have a default country then add it
			$langid = $this->app->language->getId();
			$form->setFieldAttribute('country', 'default', $this->app->config->get('book.default_country.'.$langid), 'guest');
			
			// do we add guests
			if ( $this->app->config->get('book.guest_required') ) 
			{
				// lets add guests to the form
				$newxml	  = $this->app->xml->create('new');
				$guestxml = $this->app->xml->getFile( $this->app->path->path('models:forms/guest.xml') );
				
				// add a fieldset
				$fieldset = $newxml->addChild('fieldset');
				$fieldset->addAttribute('name',  'guests');
				$fieldset->addAttribute('label', 'SUBTITLE_BOOKFORM_GUESTS');	
			
				// get nr of guests
				$adults   		= $this->state->get('persons', 2);
				$seniors		= $this->state->get('seniors', 0);
				$childs			= $this->state->get('childs', 0);
				$babys 			= $this->state->get('babys', 0);
				$guests			= $adults + $seniors + $childs + $babys;
				$guestfields 	= $guestxml->getChild('field');
				$labels		 	= array();
				
				// get labels
				foreach ( $guestfields as $field ) {
					$labels[$field->getAttribute('name')] = $field->getAttribute('label');
				}
				
				// for each guest we append the xml
				// a little strange but it is the only way we can dynamicly do this
				for ( $i = 0; $i < $guests; $i++ ) 
				{
					$guestxml->setAttribute('name', 'guest'.$i);			
					
					foreach ( $guestfields as $field ) {
						if ( $field->getAttribute('name') == 'copyname' ) {
							$field->setAttribute('text', '<span data-bz-copycontact>'. BText::_('COPY_CONTACT_INFO') . '</span>');
						}
						else {
							$field->setAttribute('label', BText::sprintf($labels[$field->getAttribute('name')], $i + 1));
						}
					}
					
					$fieldset->appendXml($guestxml);
				}
	
				// add it to the form
				$form->setFields($newxml, 'guests', true);
				
				for ( $i = 1; $i < $guests; $i++ ) {
					$form->removeField('copyname', 'guests.guest'.$i);
				}
			}
			else {
				$form->removeGroup('guests');
			}
			
			
			
			// lets add items to the form
			if ( $booking ) {
				$bookableitems = $booking->getBookableItems();
				
				if ( count( $bookableitems ) ) 
				{
					$itemxml = $this->app->xml->create('new');
					$itemfieldset = $itemxml->addChild('fieldset');
					$itemfieldset->addAttribute('name',  'items');
					$itemfieldset->addAttribute('label', 'SUBTITLE_BOOKFORM_ITEMS');
					
					foreach ( $bookableitems as $item ) {
						$itemfield = $itemfieldset->addChild('field');
						$itemfield->addAttribute('type', 'bookableitem');
						$itemfield->addAttribute('name', $item->id);
						$itemfield->addAttribute('label', $item->name);
						$itemfield->addAttribute('price', $item->pricestring);
						$itemfield->addAttribute('costtype', $item->extracosttype);
						$itemfield->addAttribute('default', 0);
						$itemfield->addAttribute('inlinelabel', true);
						$itemfield->addAttribute('hiddenLabel', true);
						$itemfield->addAttribute('validate', 'number');
						$itemfield->addAttribute('datastring', 'data-bz-updatebooking');
					}
					
					$form->setFields($itemxml, 'items', true);
				}
			}
			
			// how about mobile
			if ( $this->app->config->get('book.mobile_required', 0) ) {
				$form->setFieldAttribute('mobile', 'required', true, 'guest');
			}
			
			// how about the terms
			$showterms = $this->app->config->get('book.show_terms', 2);
			if ( !$showterms ) {
				$form->removeField('terms', 'remarks');
			}
			if ( $showterms == 1 )
			{
				$form->setFieldAttribute('terms', 'required', false, 'remarks');
			}
			
			// how about the terms
			$shownewsletter = $this->app->config->get('book.show_newsletter', 0);
			if ( !$shownewsletter ) {
				$form->removeField('newsletter', 'remarks');
			}
			if ( $shownewsletter == 2 ) {
				$form->setFieldAttribute('newsletter', 'default', 1, 'remarks');
			}
			
			// how about the discount
			$showdiscount = $this->app->config->get('book.show_discounts', 0);
			if ( !$showdiscount ) {
				$form->removeField('givemediscount', 'remarks');
			}
			
			// remove banks if payment is not ideal
			if ( $this->paymentActive() )
			{
				$methods 	 = $this->app->targetpay->getPaymentMethods();
				$defmethod   = count($methods) == 1 ? reset($methods) : false;
				
				if ( $defmethod ) {
					$form->removeField('method', 'pay');
					$form->setFieldAttribute('defaultmethod', 'text', BText::_('FIELD_BOOK_PAYMENTMETHOD_OPTION_'. strtoupper($defmethod)), 'pay');
				}
				else {
					$form->removeField('defaultmethod', 'pay');
				}
				
				if ( $tmpdata->get('pay.method') != 'IDeal' && $defmethod != 'IDeal'  ) {
					$form->removeField('issuer', 'pay');
				}
				if ( $this->app->config->get('bookzo.onlinepaymentamount') != 'Choice' ) {
					$form->removeField('amount', 'pay');
				}
				
				$form->setFieldAttribute('amounttopay', 'text', $this->app->string->amount($this->getPaymentAmount()), 'pay');

			}
			
			// fire booking formloaded event
			$this->app->event->dispatcher->fire(	
				$this->app->event->create('booking:formprocessed')
							->addSubjects( array('form' => $form, 'data' => $data, 'booking' => $booking, 'object' => $object) ) 
			);
			
			// what part of the form can be removed
			$groups = $form->getGroups(array(), false);
			foreach ( $groups as $name => $group ) {
				if ( !$this->showGroup($name) ) {
					$form->removeGroup($name);
				}
			}
			
			// do we need to validate
			if ( $this->app->config->get('bookerrors', 1) == 1 && $this->app->adapter->sessionGet('bookzo.book.errors', false) ) {
				$this->app->adapter->sessionSet('bookzo.book.errors', false);
				$this->validate($form, $data);
			}
		}
	}
	
	/**
	 * Method to validate the form data.
	 *
	 * @param   JForm   $form   The form to validate against.
	 * @param   array   $data   The data to validate.
	 * @param   string  $group  The name of the field group to validate.
	 *
	 * @return  mixed  Array of filtered data if valid, false otherwise.
	 *
	 * @see     JFormRule
	 * @see     JFilterInput
	 * @since   12.2
	 */
	public function validate($form, $data, $group = null)
	{
		// get and set some base values
		$input 				= new BRegistry($data);
		
		// let parent validat
		$data = parent::validate($form, $data, $group);
		
		if ( $data === false ) { 
			return $data;
		}
		
		// for now only check persons
		$persons 	= $this->state->get('persons');
		$seniors 	= $this->state->get('seniors');
		$childs	 	= $this->state->get('childs');
		$babys	 	= $this->state->get('babys');
		$babys		= $this->app->config->get('template.book_count_baby', 1) ? $babys : 0;
		$travellers = $persons + $seniors + $childs + $babys;
		
		$object 	 = $this->getObject();
		
		if ( $travellers > $object->get('numberofbeds') ) {
			$this->setError(BText::sprintf('ERROR_BOOKING_MAX_PERSONS', $object->get('numberofbeds')));
			return false;
		}
		
		if ( $persons + $seniors < 1 ) {
			$this->setError(BText::_('ERROR_BOOKING_NO_ADULT'));
			return false;
		}
		
		if ( $travellers < $object->get('minguestcount')) {
			$this->setError(BText::sprintf('ERROR_BOOKING_MIN_PERSONS', $object->get('minguestcount')));
			return false;
		}
		
		
		return $data;
	}	
	
	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return  array    The default data is an empty array.
	 *
	 * @since   12.2
	 */
	protected function loadFormData()
	{
		$data = $this->state->get('data');

		return $data->toArray();
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * @return  void
	 *
	 * @note    Calling getState in this method will result in recursion.
	 * @since   12.2
	 */
	protected function populateState()
	{
		parent::populateState();
		
		// get data from session
		$query		= $this->app->registry->create($this->app->adapter->sessionGet('bookzo.book.query', array()));
		$data		= $this->app->registry->create($this->app->adapter->sessionGet('bookzo.book.data', array()));
		$search 	= $this->app->registry->create($this->app->adapter->sessionGet('bookzo.search.options', array()));

		$this->state->set('data', 			$data);
		$this->state->set('arrival', 		$data->get('details.arrival'));
		$this->state->set('departure', 		$data->get('details.departure'));
		$this->state->set('persons', 		$data->get('details.persons', 2));
		$this->state->set('seniors', 		$data->get('details.seniors', 0));
		$this->state->set('childs', 		$data->get('details.childs', 0));
		$this->state->set('babys', 			$data->get('details.babys', 0));
		$this->state->set('pets', 			$data->get('details.pets', 0));
		$this->state->set('coupon',			$data->get('details.coupon'));
		$this->state->set('items',			$data->get('items', array()));
		$this->state->set('object', 		$query->get('object'));
		$this->state->set('exactbooking', 	$query->get('exact'));

		// get current pages
		$page 		= $this->app->getUserStateFromRequest('book.page', 'bookpage', 1, 'int');
		$checked 	= $this->app->adapter->sessionGet('bookzo.book.pagechecked');
		
		// page cannot exceed checkedpage + 1
		if ( $page > $checked + 1 ) {
			$page = $checked + 1;
		}
		// checked page also cannot be larger then page
		if ( $checked >= $page ) {
			$checked = $page - 1;
			$this->app->adapter->sessionSet('bookzo.book.pagechecked', $checked);
		}
		
		$this->state->set('pagechecked', 	$checked);
		$this->state->set('page', 			$page);
	}
	
	protected function addIntegerOptions($form, $field, $fields = null, $min = 0, $max = 2)
	{
		$formfield 	= $form->getField($field, $fields);
		$min		= $min > $max ? $max : $min;
		
		if ( $formfield ) {
			
			for ( $i = $min; $i <= $max; $i++ ) 
			{
				$formfield->addOption($i);
			}
				
		}
		
		return $this;
	}
	
}