<?php
/**
 * @package   bookzo
 * @author    Invenda  http://www.invenda.nl
 * @copyright Copyright (C) Invenda
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Base View class
 *
 * @package Framework.Classes
 */
class BzModelConfig extends BModelForm {
	
	/**
	 * Method to get the record form.
	 *
	 * @param	array	$data		Data for the form.
	 * @param	boolean	$loadData	True if the form is to load its own data (default case), false if not.
	 * @return	mixed	A JForm object on success, false on failure
	 * @since	1.6
	 */
	public function getForm($data = array(), $loadData = true)
	{
		// Get the form.
		$form = $this->loadForm('bookzo.config', 'config', array('control' => 'bookzo', 'load_data' => $loadData));
		
		if (empty($form)) {
			return false;
		}	
		
		return $form;
	}
	
	/**
	 * Method to allow derived classes to preprocess the form.
	 *
	 * @param   JForm   $form   A JForm object.
	 * @param   mixed   $data   The data expected for the form.
	 * @param   string  $group  The name of the plugin group to import (defaults to "content").
	 *
	 * @return  void
	 *
	 * @see     BFormField
	 * @since   12.2
	 * @throws  Exception if there is an error in the form event.
	 */
	protected function preprocessForm(BForm $form, $data)
	{
		// get all widgets config files
		$widgets	 = $this->app->widget->getList();
				
		foreach ( $widgets as $widget ) {
			if ( $widgetform = $this->app->widget->{$widget}->getConfigForm() ) {
				$this->app->widget->{$widget}->loadConfigLanguageFile();
				$xml 	 = $widgetform->getXml();
				$form->setFields($xml, 'widgets');
			}
		}
		
		// get all plugin config files
		$plugins	 = $this->app->plugin->getList();
				
		foreach ( $plugins as $plugin ) {
			if ( $pluginform = $this->app->plugin->{$plugin}->getConfigForm() ) {
				$this->app->plugin->{$plugin}->loadConfigLanguageFile();
				$xml 	 = $pluginform->getXml();
				$form->setFields($xml, 'plugins');
			}
		}
		
		// fire booking formloaded event
		$this->app->event->dispatcher->fire(	
			$this->app->event->create('config:formprocessed')
						->addSubjects( array('form' => $form, 'data' => $data) ) 
		);
	}
	
	/**
	 * Method to determine the form paths.
	 *
	 * @return  void
	 * @since   12.2
	 */
	protected function addFormPaths()
	{
		$app = Bookzo::getInstance();
		
		// Load form and field paths
		BForm::addFormPath(BOOKZO_ROOT);
		BForm::addFieldPath(BOOKZO_ROOT . '/libraries/bookzo/fields');
		
		// Also load override paths
		$modelpaths = $app->path->getPaths('models', true);
		
		foreach ( $modelpaths as $modelpath ) {
			BForm::addFormPath($modelpath . '/admin/forms');
			BForm::addFieldPath($modelpath . '/admin/fields');
			BForm::addRulePath($modelpath . '/admin/rules');		
		}
	}
	
	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return  array    The default data is an empty array.
	 *
	 * @since   12.2
	 */
	protected function loadFormData()
	{
		// we try to load the config file
		$file = BOOKZO_ROOT . '/config/bookzo.config';
		$data = array();
		
		if ($this->app->filesystem->file->exists($file)) 
		{
			$config = new BRegistry();
			$config->loadFile($file);

			$data = $config->toArray();
		}
		
		return $data;
	}
	
}