<?php
/**
 * @package   bookzo
 * @author    Invenda  http://www.invenda.nl
 * @copyright Copyright (C) Invenda
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Base View class
 *
 * @package Framework.Classes
 */
class BzModelDiscounts extends BModelList 
{	
	/**
	 * Get the departure date by startdate and duration type
	 *
	 * @param	$start		string	the arrival date	 
	 * @param	$definition	int		the pricedefininition id
	 * @return	$departure	string	the departure date
	 * @access	public
	 * @since	1.0
	 */
	public function getDeparture($arrival, $definition)
	{
		$departure	 = false;
		
		// get the correct definition
		if ( $definition = $this->app->api->getPriceDefinitions( (int) $definition ) )
		{
			$departure	= $this->app->date->create( $arrival )->add( $definition->numberofnights )->format( 'Y-m-d' );
		}
		
		return $departure;
	}
	
	public function getItems()
	{	
		// try loading from cache
		if ( isset($this->cache['items']) ) {
			return $this->cache['items'];
		}
		
		// get search data
		$this->cache['items'] 	= array();
		$items					= array();
		$actions 				= $this->app->api->getActions(true);
		
		if ( !count($actions) ) {
			return $this->cache['items'];
		}
		
		$actionids 	= array_keys($actions);
		$discounts 	= $this->app->api->getPrices(array('actions' => $actionids), true);
		
		// do we have periods
		if ( !count($discounts) ) {
			return $this->cache['items'];
		}
		
		// remove discounts without pricedrop
		foreach ( $discounts as $object => $prices ) {
			foreach ( $prices as $k => $price ) {
				if ( !isset($price->pricebeforediscount) || $price->pricebeforediscount <= $price->price ) {
					unset($discounts[$object][$k]);
				}
			}
			if ( !count($discounts[$object]) ) {
				unset($discounts[$object]);
			}
		}
		
		// lets get the objects
		$itemids 	= array_keys($discounts);
		$items 		= $this->app->api->getObjects($itemids);
		
		// add prices to each found object
		foreach ( $items as $item ) 
		{
			foreach ( $discounts[$item->get('id')] as $price ) {
				$item->addPrice($price);
			}
		}
		
							
		## NOTE - should we group here
		if ( $this->app->config->get('bookzo.bookpergroup', 0) ) {
			
			$tmp 		 = array();
			$foundgroups = array();
			foreach ( $items as $k => $item ) {
				if ( !in_array($item->get('groupid'), $foundgroups) ) {
					$foundgroups[] = $item->get('groupid');
					$tmp[$item->get('groupid')] = $item;
				}
				else {
					$prices = $item->get('prices');
					foreach ( $prices as $price ) {
						$tmp[$item->get('groupid')]->addPrice( $price );
					}
				}
			}
			
			$items = $tmp;
		}
		
		// now we need to set a discountorder for this object
		foreach ( $items as $item ) {
			$item->set('discountorder', $this->app->array->firstkey( $item->get('prices', array()) ));
		}
		
		// last but not least filter the items
		$items = $this->app->bookzo->filters->addObject($items)->getFiltered();

		// add the filtered elements to the session
		$this->app->adapter->sessionSet('bookzo.discount.list', array_keys($items));
		
		// sort the items as requested
		$this->order($items);

		// update cache
		$this->cache['items'] = $items;
		
		return $this->cache['items'];
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * @return  void
	 *
	 * @note    Calling getState in this method will result in recursion.
	 * @since   12.2
	 */
	protected function populateState( $order = 'id', $dir = 'asc' )
	{
		// call parent populate for default settings
		parent::populateState( 'discountorder', 'ASC' );
		
	//	$values = $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.discount.query') );
	}
}