<?php
/**
 * @package   bookzo
 * @author    Invenda  http://www.invenda.nl
 * @copyright Copyright (C) Invenda
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Base View class
 *
 * @package Framework.Classes
 */
class BzModelFavourites extends BModelList {
	
	public function getItems()
	{
		// try loading from cache
		if ( isset($this->cache['items']) ) {
			return $this->cache['items'];
		}
		
		// initiate
		$items	= array();
		
		// get items by ids
		$ids 	= $this->getIds(); 
		if ( count($ids) ) {
			$items 	= $this->app->api->getObjects($ids);
		}
		
		// last but not least filter the items
		$items = $this->app->bookzo->filters->addObject($items)->getFiltered();
		
		// add the filtered elements to the session
		$this->app->adapter->sessionSet('bookzo.favourites.list', array_keys($items));
		
		// group results if requested
		if ( $this->app->config->get('bookzo.bookpergroup', 0) ) {
			
			$tmp 		 = array();
			$foundgroups = array();
			foreach ( $items as $k => $item ) {
				if ( !in_array($item->get('groupid'), $foundgroups) ) {
					$foundgroups[] = $item->get('groupid');
					$tmp[$k] = $item;
				}
			}
			
			$items = $tmp;
		}
		
		// update cache
		$this->cache['items'] = $items;
		
		return $this->cache['items'];
	}
	
	public function getIds()
	{
		return $this->app->bookzo->favourites->getItems();
	}
	
	public function getTotal()
	{
		return $this->app->bookzo->favourites->getCount();
	}
	
	/**
     * Add an item to favourites
	 * We add it to the jar immediatly
     *
     * @param   mixed	$id		either an array or single id
     * @return  bool			true on succes
	 * @access 	public
     * @since   3.1
     */
	public function process($id)
	{
		if ( $this->app->bookzo->favourites->isFavourite($id) ) {
			return $this->remove($id);
		}
		
		return $this->add($id);
	}
	
	/**
     * Add an item to favourites
	 * We add it to the jar immediatly
     *
     * @param   mixed	$id		either an array or single id
     * @return  bool			true on succes
	 * @access 	public
     * @since   3.1
     */
	public function add($id)
	{
		return $this->app->bookzo->favourites->add($id);
	}
	
	/**
     * Removes an item to favourites
	 * We add it to the jar immediatly
     *
     * @param   mixed	$id		either an array or single id
     * @return  bool			true on succes
	 * @access 	public
     * @since   3.1
     */
	public function remove($id)
	{
		return $this->app->bookzo->favourites->remove($id);
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * @return  void
	 *
	 * @note    Calling getState in this method will result in recursion.
	 * @since   12.2
	 */
	protected function populateState( $order = 'id', $dir = 'asc' )
	{	
		// call parent populate for default settings
		parent::populateState( $this->app->config->get('template.results_order'), $this->app->config->get('template.results_order_dir') );
		
		$this->state->set('ids', $this->app->bookzo->favourites->getItems());
	}
	
}