<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Form
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Form Field class for the Joomla Platform.
 * Single check box field.
 * This is a boolean field with null for false and the specified option for true
 *
 * @package     Bookzo.Platform
 * @subpackage  Form
 * @link        http://www.w3.org/TR/html-markup/input.checkbox.html#input.checkbox
 * @see         BFormFieldCheckboxes
 * @since       11.1
 */
class BFormFieldCountry extends BFormFieldSelect
{
	protected function getOptions()
	{
		$options = array();

		try {
			
			// render the widget
			$app 		= Bookzo::getInstance();
			$countries 	= $app->api->getCountries();
			$options	= array();
			
			foreach ( $countries as $country )
			{
				$name 	= $country->translate('name', $app->config->get('book.show_countries', 1));
				if ( strlen(trim($name)) ) {
					$options[$name] = BHtml::_('select.option', $country->get('id'), $name);
				}
			}
			
			ksort($options);
		}
		catch (RuntimeException $e) {
			$options = array();
		}

		// Merge any additional options in the XML definition.
		$options = array_merge(parent::getOptions(), $options);

		return $options;
	}
}
