<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Form
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Form Field class for the Joomla Platform.
 * Single check box field.
 * This is a boolean field with null for false and the specified option for true
 *
 * @package     Bookzo.Platform
 * @subpackage  Form
 * @link        http://www.w3.org/TR/html-markup/input.checkbox.html#input.checkbox
 * @see         BFormFieldCheckboxes
 * @since       11.1
 */
class BFormFieldHousenrSuffix extends BFormFieldText
{
	/**
	 * Method to get the field input markup.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   11.1
	 */
	protected function getInput()
	{		
		// Translate placeholder text
		$hint = $this->translateHint ? BText::_($this->hint) : $this->hint;

		// Initialize some field attributes.
		$size       = !empty($this->size) 		? ' size="' . $this->size . '"' 			: '';
		$maxLength  = !empty($this->maxLength) 	? ' maxlength="' . $this->maxLength . '"' 	: '';
		$class      = !empty($this->class) 		? ' class="' . $this->class . '"' 			: '';
		$pattern    = !empty($this->pattern) 	? ' pattern="' . $this->pattern . '"' 		: '';
		$required   = $this->required 			? ' required aria-required="true"' 			: '';
		$hint       = $hint 					? ' placeholder="' . $hint . '"' 			: '';		
		$readonly	= $this->readonly 			? ' readonly' : '';
		$disabled   = $this->disabled 			? ' disabled' : '';
		
		// split value
		$values		= (array) $this->value;
		$housenr	= isset($values['housenr']) ? $values['housenr'] : '';
		$suffix		= isset($values['suffix']) ? $values['suffix'] : '';

		// Initialize JavaScript field attributes.
		$onchange 	= !empty($this->onchange) ? ' onchange="' . $this->onchange . '"' : '';

		// render the fields
		$html 		= array();
		$html[] 	= '<div class="bz-grid bz-grid-small">';
		$html[] 	= '<div class="bz-width-1-1 bz-width-small-1-2">';
		$html[]   	= '<input type="text" name="' . $this->name . '[housenr]" id="' . $this->id . '_housenr" value="'
			. htmlspecialchars($housenr, ENT_COMPAT, 'UTF-8') . '"' . $class . $size . $disabled . $readonly 
			. $hint . $onchange . $maxLength . $required . $pattern . ' />';
		$html[]		= '</div>';
		$html[] 	= '<div class="bz-width-1-1 bz-width-small-1-2">';
		$html[]   	= '<input type="text" name="' . $this->name . '[suffix]" id="' . $this->id . '_suffix" value="'
			. htmlspecialchars($suffix, ENT_COMPAT, 'UTF-8') . '"' . $class . $size . $disabled . $readonly 
			. $hint . $onchange . $maxLength . $required . $pattern . ' />';
		$html[]		= '</div>';
		$html[] 	= '</div>';

		return implode($html);
	}
}
