<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Form
 *
 * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Form Field class for the Joomla Platform.
 * Provides radio button inputs
 *
 * @package     Bookzo.Platform
 * @subpackage  Form
 * @link        http://www.w3.org/TR/html-markup/command.radio.html#command.radio
 * @since       11.1
 */
class BFormFieldTerms extends BFormFieldCheckbox
{
	/**
	 * The form field type.
	 *
	 * @var    string
	 * @since  11.1
	 */
	protected $type = 'Terms';

	/**
	 * Method to get the field input markup.
	 * The checked element sets the field to selected.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   11.1
	 */
	protected function getInput()
	{
		// Initialize some field attributes.
		$class     = !empty($this->class) 	? ' class="' . $this->class . '"' : '';
		$disabled  = $this->disabled 		? ' disabled' : '';
		$value     = !empty($this->default) ? $this->default : '1';
		$required  = $this->required 		? ' required aria-required="true"' : '';
		$autofocus = $this->autofocus 		? ' autofocus' : '';
		$checked   = $this->checked || !empty($this->value) ? ' checked' : '';

		// Initialize JavaScript field attributes.
		$onclick  = !empty($this->onclick) 	? ' onclick="' . $this->onclick . '"' : '';
		$onchange = !empty($this->onchange) ? ' onchange="' . $this->onchange . '"' : '';
		
		$text	  = $this->getText();
		if ( !$text ) {
			$label = BText::_('FIELD_BOOK_CONDITIONS_LABEL');
		}
		else {
			$label = BText::sprintf('FIELD_BOOK_CONDITIONS_LABEL_SHOW', 'data-bz-toggle="{target:\'.th-terms\'}"');
			$label .= '<div class="th-terms bz-hidden bz-panel bz-panel-box">';
			$label .= '<h4>' . BText::_('FIELD_BOOK_CONDITIONS_TITLE') . '</h4>';
			$label .= $text;
			$label .= '</div>';
		}

		$return  = '<div class="bz-clearfix">';
		$return .= '<div class="bz-float-left">';
		$return .= '<input type="checkbox" name="' . $this->name . '" id="' . $this->id . '" value="'
			. htmlspecialchars($value, ENT_COMPAT, 'UTF-8') . '"' . $class . $checked . $disabled . $onclick . $onchange
			. $required . $autofocus . ' />';
		$return .= '</div>';
		$return .= '<div class="bz-overflow-hidden">' . $label . '</div>';
		$return .= '</div>';
		
		return $return;
	}
	
	protected function getText()
	{
		## NOTE - Why is app not a default in fields
		$app	= Bookzo::getInstance();
		$langid = $app->language->getId();
		$text	= $app->config->get('book.terms.'.$langid);
		
		if ( strlen(trim($text)) ) {
			return nl2br($text);
		}
		
		return false;
	}
}
