<?php
/**
 * @package   bookzo
 * @author    Invenda  http://www.invenda.nl
 * @copyright Copyright (C) Invenda
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

/**
 * Base View class
 *
 * @package Framework.Classes
 */
class BzModelResults extends BModelList 
{	
	/**
	 * Get the departure date by startdate and duration type
	 *
	 * @param	$start		string	the arrival date	 
	 * @param	$definition	int		the pricedefininition id
	 * @return	$departure	string	the departure date
	 * @access	public
	 * @since	1.0
	 */
	public function getDeparture($arrival, $definition)
	{
		$departure	 = false;
		
		// get the correct definition
		if ( $definition = $this->app->api->getPriceDefinitions( (int) $definition ) )
		{
			$departure	= $this->app->date->create( $arrival )->add( $definition->numberofnights )->format( 'Y-m-d' );
		}
		
		return $departure;
	}
	
	public function getItems()
	{	
		// try loading from cache
		if ( isset($this->cache['items']) ) {
			return $this->cache['items'];
		}
		
		// get search data
		$items				= array();
		$arrival 			= $this->getState('arrival');
		$departure 			= $this->getState('departure');
		$persons			= $this->getState('persons');
		$pets				= $this->getState('pets');
		$group				= $this->getState('group');
				
		// do we have the query in session cache
		## NOTE - Shouldn't we also check for same query filters etc
		$found	 	= $this->app->adapter->sessionGet('bookzo.search.results');	

		// no cache then make a new fetch
		if ( !is_array($found) || !count($found) || 1 == 1) 
		{
			$found	 	= $this->app->api->getFreeObjects($arrival, $departure, $group, $persons, $pets);				
			$this->app->adapter->sessionSet('bookzo.search.results', $found);
		}

		// get ids found
		$foundids	= array_keys($found);

		// if found find matching objects
		if ( count($foundids) ) 
		{	
			$objects	= $this->app->api->getObjects($foundids);

			// add prices to the objects
			foreach ( $objects as $id => $object ) {
				$object->addPrice($found[$id]->price);	
				
				$object->addPrice($found[$id]->price);			
				$object->set('searchresult', true);
			}

			$items = $objects;
		}
		
		## NOTE - should we group here
		// group results if requested
		if ( $this->app->config->get('bookzo.bookpergroup', 0) ) {
			
			$tmp 		 = array();
			$foundgroups = array();
			foreach ( $items as $k => $item ) {
				if ( !in_array($item->get('groupid'), $foundgroups) ) {
					$foundgroups[] = $item->get('groupid');
					$tmp[$k] = $item;
				}
			}
			
			$items = $tmp;
		}
		
		// last but not least filter the items
		$items = $this->app->bookzo->filters->addObject($items)->getFiltered();

		// add the filtered elements to the session
		$this->app->adapter->sessionSet('bookzo.results.list', array_keys($items));
		
		// sort the items as requested
		$this->order($items);

		// update cache
		$this->cache['items'] = $items;
		
		return $this->cache['items'];
	}
	
	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * @return  void
	 *
	 * @note    Calling getState in this method will result in recursion.
	 * @since   12.2
	 */
	protected function populateState( $order = 'id', $dir = 'asc' )
	{
		// call parent populate for default settings
		parent::populateState( $this->app->config->get('template.results_order'), $this->app->config->get('template.results_order_dir') );
		
		$values = $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.search.query') );

		$this->state->set('arrival', 	$values->get('arrival'));
		$this->state->set('departure', 	$values->get('departure'));
		$this->state->set('persons', 	$values->get('persons', 1));
		$this->state->set('pets', 		(int) $values->get('pets', 0));
		$this->state->set('group', 		(int) $values->get('group', 0));

		## NOTE only temporary
		$this->state->set('lastminutes',(int) $values->get('lastminutes', 0));
	}
}