<?php
/**
 * @package     Bookzo.Platform
 * @subpackage  Form
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('_BOOKZO') or die;

/**
 * Form Rule class for the Joomla Platform
 *
 * @since  11.1
 */
class BFormRuleLicenseplate extends BFormRule
{
	/**
	 * Method to test the url for a valid parts.
	 *
	 * @param   SimpleXMLElement  $element  The SimpleXMLElement object representing the <field /> tag for the form field object.
	 * @param   mixed             $value    The form field value to validate.
	 * @param   string            $group    The field name group control value. This acts as as an array container for the field.
	 *                                      For example if the field has name="foo" and the group value is set to "bar" then the
	 *                                      full field name would end up being "bar[foo]".
	 * @param   Registry          $input    An optional Registry object with the entire data set to validate against the entire form.
	 * @param   JForm             $form     The form object for which the field is being tested.
	 *
	 * @return  boolean  True if the value is valid, false otherwise.
	 *
	 * @since   11.1
	 */
	public function test(SimpleXMLElement $element, $value, $group = null, BRegistry $input = null, BForm $form = null)
	{
		// If the field is empty and not required, the field is valid.
		$required = ((string) $element['required'] == 'true' || (string) $element['required'] == 'required');
		
		// split values
		$value   = trim($value);
				
		// lets update filtered value
		parent::updateValue($value, $form, $element, $group);
		
		// is it required
		if (!$required && !strlen($value))
		{
			return true;
		}
		
		if ( $required && !strlen($value) ) {
			return new RuntimeException(BText::sprintf('FORM_VALIDATE_FIELD_REQUIRED', BText::_('FIELD_BOOK_LICENSEPLATE_LABEL')) );
		}
		
		// licenplate are digits letters and - is integer and minimum of 6
		if(	preg_match("/^[a-zA-Z\d\-]+$/", $value) && strlen($value) >= 6){
			return true;
		}
		
		return false;
	}
}
