<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzWidgetCalendar extends BWidget {

	protected $calendar;
	
	protected $state;
	
	/**
	 * Render the module
	 *
	 * @param 	none
	 * @return 	mixed 	the html
	 * @since 	1.0.0
	 */
	public function render()
	{
		$params = $this->params;
		$id 	= (int) $params->get('id');
		
		// can we find this object
		if ( !$id || !$object = $this->app->api->getObjects($id) ) {
			return false;
		}
		
		// update state 
		$state 			= $this->getState(array('id' => $id));
		
		// get search params
		$objectmax 		= (int) $object->get('numberofbeds');
		$objectmin 		= (int) $object->get('minguestcount');
		$personssearch 	= (int) $state->get('persons', $object->get('persons', 2));
		$pets		 	= $state->get('pets', 0);
		$persons		= $personssearch < $objectmin ? $objectmin : ($personssearch > $objectmax ? $objectmax : $personssearch);	
		
		// do we need to update
		if ( $persons > $personssearch ) {
			$state = $this->getState(array('persons' => $persons));
		}

		// do we let user decide nr of persons
		$personslist 	= '';
		if ( $params->get('choosepersons') && ( $params->get('pricecalculation') || $params->get('showprices') ) ) {
			$personoptions = array();
			for ( $i = $objectmin; $i <= $objectmax; $i++ ) {
				$personoptions[] = $this->app->html->select->option($i, $i);
			}
			$attr		  = 'data-bz-updatecalendar class="bz-input"';
			$personslist  = $this->app->html->select->genericlist('persons', $personoptions, $persons, $attr);
		}
		else {
			$params->set('choosepersons', 0);
		}
		
		// setup the calendar
		$pricecalculation 	= $this->getPriceCalculation();
		$calendar 			= $this->setUpCalendar($object);
		
		// get stuff we need from calendar
		$months 			= $calendar->render();
		$typelist			= $calendar->getPriceList();
		$activetype 	  	= $calendar->getActiveType();
		
		$activemonth		= $state->get('arrival') 
							? $this->app->date->create( $state->get('arrival') )->format('Y-m-01')
							: $this->app->date->today()->format('Y-m-01');
		$calendars		  	= $this->renderer->render('calendar', compact('months', 'params', 'activemonth'));	
		
		// render general template
		return  $this->renderer->render('default', compact('calendar', 'calendars', 'pricecalculation', 'params', 'personslist', 'typelist', 'activetype'));	
	}
	
	/*
	public function ajaxGetPrice()
	{		
		$return 		= array();
		$state	 	 	= $this->getState();
				
		if ( $object = $this->app->api->getObjects($state->get('coid')) )
		{
			// finally get the arrivals
			if ( $html = $this->getPriceCalculation() ) {
				$return['html'] = $html;
			}
			else {
				throw new BControllerException('Price could not be found');
			}
		}
		else {
			throw new BControllerException('Price could not be found');
		}

		// return
		return $return;
	}
	*/
	
	public function ajaxUpdateCalendar()
	{		
		$return 		= array();
		$params			= $this->params;
		$state	 	 	= $this->getState();
				
		if ( $object = $this->app->api->getObjects($state->get('id')) )
		{
			if ( $this->app->input->get('type') == 'full' ) 
			{
				// setup the calendar
				$calendar = $this->setUpCalendar($object);
		
				// get stuff we need from calendar
				$months 			= $calendar->render();
				$monthhtml			= array();
				foreach ( $months as $month ) {
					$monthhtml['calendar-month-'.$month->month] = $month->html;
				}
				$return['calendar']	= $monthhtml;	
			}
			
			// finally get the arrivals
			if ( $price = $this->getPriceCalculation() ) {
				$return['price'] = $price;
			}
			else {
				throw new BControllerException('Price could not be found');
			}
		}
		else {
			throw new BControllerException('Price could not be found');
		}

		// return
		return $return;
	}


	public function setUpCalendar($object)
	{
		if ( is_null($this->calendar) ) 
		{
			$params	  = $this->params;
			$state 	  = $this->getState();

			// initiate calendar and merge settings
			$calendar = new BookzoCalendar();
			$calendar->setNrOfMonths($params->get('max'));
			$calendar->settings->merge($params);
			
			// also set other settings
			$calendar->settings->set('class', 		 	'booked');
			$calendar->settings->set('old', 			'other-month');
			$calendar->settings->set('pricestyle', 		$params->get('calendar_pricestyle'));
			$calendar->settings->set('hidecurrency', 	$params->get('calendar_hidecurrency'));
						
			// set active calendar arrival and departure
			$calendar->setActivePeriod( $state->get('arrival'), $state->get('departure') );
			
			// get periods	
			$blocks 		= $object->getPeriods($state->get('persons',$object->get('persons', 2)), $state->get('pets',0));
			$arrivals		= $object->getPossibleArrivals($state->get('persons',$object->get('persons', 2)), $state->get('pets',0));
			
			## NOTE - for now only for object
			$booked		= array();
			if ( !$this->app->config->get('bookzo.bookpergroup', 0) ) {
				$booked = $object->getBooked();
			}
	
			// check if period has overlap with booked period and is valid
			foreach ( $blocks as $i => $block ) { 
			
				// is it valid
				if ( !$block->objectid || !in_array($block->arrival, $arrivals) ) 
				{
					unset($blocks[$i]);
					continue;
				}

				## NOTE - let John look at this -> because this ain't right				
				// redate if nights aren't correct
				if ($block->minnights && $block->minnights > $block->nights ) {
					$block->departure = $this->app->date->create($block->arrival)->add($block->minnights)->format('Y-m-d');
					$block->total 	  = 0; 
				}

				// does it have a overlap
				foreach ( $booked as $b ) {
					if ( $block->arrival < $b->departure && $block->departure > $b->arrival ) {
						unset($blocks[$i]);
						continue 2;
					}
				}
			}		
	
			foreach ( $blocks as $block ) {
				// set calendar start end enddate
				if ( is_null($this->start) || $this->start > $block->arrival ) {
					$this->start = $block->arrival;
				}
				if ( is_null($this->end) || $this->end < $block->departure ) {
					$this->end = $block->departure;
				}
						
				$calendar->addPrice($block, 'free', 'free-start', 'free-end', 'bookable');		
			}
							
			// return the widget
			$this->calendar 	= $calendar;
		}
		
		return $this->calendar;
	}
	
	protected function getPriceCalculation()
	{
		// get search queries
		$params		 = $this->params;
		$state	 	 = $this->getState();
		
		// override some params
		$params->set('pricestyle', 		$params->get('pricecalculationpricestyle'));
		$params->set('hidecurrency', 	$params->get('pricecalculationhidecurrency'));
		
		// get default search values
		$oid		 = $state->get('coid');
		
		// get object 
		if ( !$object = $this->app->api->getObjects($oid) ) {
			return false;
		}
		
		$arrival 	 = $state->get('arrival');
		$departure 	 = $state->get('departure');
		$persons 	 = $state->get('persons', $object->get('persons', 2));
		$pets	 	 = $state->get('pets', 0);
		
		// get possible arrivals
		$start		 = $this->app->date->today()->format('Y-m-d');
		$end		 = $this->app->date->nextyear()->format('Y-12-31');
		$oid		 = $this->app->config->get('bookzo.bookpergroup', 0) ? 0 : $oid;
		$gid		 = $this->app->config->get('bookzo.bookpergroup', 0) ? $object->get('groupid') : 0;
		$arrivals 	 = $this->app->api->getArrivals( $start, $end, 0, $gid, $persons, 0, $oid );

		// get correct arrival		
		if ( !$arrival || !in_array($arrival, $arrivals) ) {
			$arrival = $this->app->array->first($arrivals);
		}
		
		// no arrival then return 
		if ( !$arrival ) {
			return false;
		}
		
		// get possible departures
		$departures  = $this->app->api->getDepartures( $arrival, $gid, $persons, 0, $oid );
		if ( !$departure || !in_array($departure, $departures) ) {
			$departure = $this->app->array->first($departures);
		}
		
		// no departure then return 
		if ( !$departure ) {
			return false;
		}
		
		// now get the pricecalculation
		$prospect = $this->app->api->getProspect($oid, $arrival, $departure, $persons, 0, 0, 0, $pets, array(), null, $gid);
		
		// build price
		if ( !$prospect->get('reservationnumber') ) {
			return false;
		}
		
		// create direct booking link
		$booklink = $this->app->route->route('layout=book&task=book.request&object='. $oid .'&arrival='.$arrival. '&departure='.$departure .  '&persons='.$persons );
		
		// make a list for departures
		$departurelist	= '';
		
		if ( $params->get('departurechange', 0) ) {
			$departureoptions 	= array();
			$departures 	  	= $prospect->get('possibledepartures', array());
			$dateformat 		= $this->app->config->get('template.book_date_notation', 'DATE_FORMAT_DEFAULT');
			
			// do we have multiple departures
			if ( count($departures) > 1 ) {
				sort($departures);
				foreach ( $departures as $d ) {
					$departureoptions[] = $this->app->html->select->option(
												$this->app->date->create($d)->format('Y-m-d'), $this->app->date->create($d)->format($dateformat)
											);
				}
				
				// create list
				$attr		   = 'data-bz-directbookingdeparture class="bz-input bz-size-small"';
				$departurelist = $this->app->html->select->genericlist('departure', $departureoptions, $departure, $attr);
				
			}		
		}
		
		// update arrival and departure
		$this->getState(array('arrival' => $arrival, 'departure' => $departure));
				
		// output pricecalculation
		return $this->renderer->render('directbooking', compact('prospect','object','arrival','departure','persons','params','departurelist','booklink'));
	}
	
	/**
	 * Method to store and update values changed in calendar
	 * 
	 * @param 	string $name The name of the data class to retrieve 
	 * @return 	AppTable The table object
	 * @since 	1.0.0
	 */
	public function getState($vars = array())
	{
		// do we create a new state
		if ( is_null($this->state) || isset($vars['id']) ) 
		{
			// get search queries
			$state	 	 = $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.calendar.values') );
			$searchstate = $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.search.query') );
			$input		 = $this->app->input;
			
			// do we look at a new accommodation then reset
			if ( isset($vars['id']) && $state->get('id') != $vars['id'] ) {
				$state = $searchstate;
				$state->set('id', 	$vars['id']);
				$state->set('coid', $vars['id']);
			}
			
			if ( $arrival 	= $input->get('arrival') ) {
				$state->set('arrival', 	$arrival);
			}
			if ( $departure = $input->get('departure') ) {
				$state->set('departure', 	$departure);
			}
			if ( $persons = $input->get('persons') ) {
				$state->set('persons', 	$persons);
			}
			if ( $coid = $input->get('coid') ) {
				$state->set('coid', $coid);
			}
			if ( is_int( $input->get('pets') ) ) {
				$state->set('pets', 	$input->get('pets'));
			}
			
			$this->state = $state;
		}
		
		// update if needed
		foreach ( $vars as $k => $v ) {
			$this->state->set($k, $v);
		}
		
		// restore
		$this->app->adapter->sessionSet( 'bookzo.calendar.values', $this->state->toArray() );
		
		// return
		return $this->state;
	}
}