<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
## NOTE - Dit is enkel een eerste opzet
class BzWidgetMap extends BWidget {

	protected $markers = array();
	
	protected $settings = array();
	
	/**
	 * Render the module
	 *
	 * @param 	none
	 * @return 	mixed 	the html
	 * @since 	1.0.0
	 */
	public function render()
	{
		// anything to render
		if ( !count($this->markers) ) {
			return false;
		}
		
		$this->setSetting('apiKey', $this->params->get('apikey'));
		
		// add the javascript
		$this->app->adapter->addScript('assets:js/map.js');
		$this->setSetting('zoom', 15);
		
		// set stuff for the template
		$class		= '';
		$identifier			= $this->identifier;
		
		if ( count($this->markers) == 1 ) {
			$first = reset($this->markers);
			$this->setCenter($first['lat'], $first['lng']);
		}
		
		
		
		// get width and height
		$width		= (int) 0;
		$height		= (int) 400;
		$width		= (int) $width 	? $width.'px' 	: '100%';
		$height		= (int) $height ? $height.'px' 	: '800px';
		
		// add markers to settings
		$this->setSetting('adresses', array_values($this->markers));
		
		$options	= $this->getSettings(true);
						
		// render the widget
		return  $this->renderer->render('default', compact('identifier', 'class', 'options', 'width', 'height') );
	}
	
	public function addMarker($lat, $lng, $html = '')
	{
		$key 	= $lat.$lng;
		
		if ( !isset($this->markers[$key]) ) 
		{
			$marker = array(
						'lat'	=> 	$lat,
						'lng'	=> 	$lng,
						'popup'	=> 	$html	
					);
					
			$this->markers[$key] = $marker;
		} 
		else 
		{
			$this->markers[$key]['popup'] .= $html;
		}
		
		return $this;
	}
	
	public function addAddress( $street = '', $zipcode = '', $city = '', $country = '' )
	{
		$parts = array();
		
		if ( strlen($zipcode) ) {
			$parts[] = str_replace(array(' ', '-'), '', $zipcode);
		}
		
		if ( strlen($street) ) {
			$parts[] = $street;
		}
		
		if ( strlen($city) ) {
			$parts[] = $city;
		}
		
		if ( count($parts) ) {
			$address = implode(',', $parts);
			$address = str_replace(" ", "+", $address);
			
			
			try {
				// get content from googlemaps
				if ( false !== ($json = @file_get_contents("http://maps.google.com/maps/api/geocode/json?address=$address&sensor=false")) ) 
				{
					$json = json_decode($json);
	
					// throw error if not found				
					if ( !is_object($json) || (isset($json->{'status'}) && $json->{'status'} == 'ZERO_RESULTS') || isset($json->{'error_message'}) ) {
						throw new BWidgetException('No map results');
					}
	
					// found so add the marker
					$lat 	= $json->{'results'}[0]->{'geometry'}->{'location'}->{'lat'};
					$lng 	= $json->{'results'}[0]->{'geometry'}->{'location'}->{'lng'};
					
					if ( $lat && $lng ) {
						$this->addMarker($lat, $lng);
					}
				}
				else {
					$error = error_get_last();
					throw new BWidgetException('Googlemaps returned an error: ' . $error);
				}
			}
			catch ( Exception $e ) {
				return;
			}
		}
		
		return;
	}
	
	/**
     * Get the json encoded settings
     *
	 * @access	public
	 * @param	$json		boolean	if true return in json format
	 * @return	mixed				the settings in a specific format
	 * @since	1.0	 
	 */
	public function getSettings($json = true)
	{
		if ( $json ) {
			return str_replace("'", "\u0027", json_encode($this->settings));
		}

		return $this->settings;
	}
	
	/**
     * Set an option for the slideshow
     *
	 * @access	public
	 * @param	$option	string	the option name
	 * @param	$value	string	the option value
	 * @return	this			for chainging
	 * @since	1.0	 
	 */
	public function setSetting($key, $value)
	{
		// only add if exists
		if ( is_string($value) && (ctype_digit(strval($value))) ) {
			$value = (int) $value;
		}
		$this->settings[$key] = $value;
		
		// return
		return $this;
	}
	
	public function setCenter($lat, $lng, $zoom = 0 )
	{
		$this->setSetting('lat',$lat);
		$this->setSetting('lng',$lng);
		
		if ( (int) $zoom ) {
			$this->setSetting('zoom', (int) $zoom);
		}
		
//		$this->addMarker($lat, $lng);
		
		return $this;
	}
}