<?php
/**
* @package   	Bz
* @author    	Invenda http://www.invenda.nl
* @copyright 	Copyright (C) Invenda.nl
* @license   	http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_BOOKZO') or die;

/**
 * Bz data helper class.
 *
 * Helper for managing and retrieving paths
 * We can register paths.
 * When loading files we search paths top to bottom
 *
 * @subpackage 	framework.helpers
 * @since 		1.0.0
 */
class BzWidgetPriceList extends BWidget 
{
	public function render()
	{
		$params		= $this->params;
		$id 		= (int) $params->get('id');
		$combine 	= (int) $params->get('combine', 0);
		
		// get current search
		$activetab			= false;
		$searchstate 		= $this->app->registry->create( $this->app->adapter->sessionGet('bookzo.search.query') );
		$searchedarrival 	= $searchstate->get('arrival');
		
		// let prices link
		$params->set('linkprice', 1);

		// can we find this object
		if ( !$id || ($object = $this->app->api->getObjects($id)) === false ) {
			return '';
		}

		// get the prices for this object and active search
		$prices  		= $object->getPeriods($searchstate->get('persons',$object->get('persons', 2)), $searchstate->get('pets',0));
		$arrivals		= $object->getPossibleArrivals($searchstate->get('persons',$object->get('persons', 2)), $searchstate->get('pets',0));
		
		if ( !count($prices) ) {
			return '';
		}
		
		// return for now
		$definitionids	= $this->app->array->extract($prices, 'priceid', true);
		$definitions	= $this->app->api->getPriceDefinitions($definitionids, true);
		$definitionids  = array_keys($definitions);
				
		
		## NOTE - filter periods for now only for object
		$booked		= array();
		if ( !$this->app->config->get('bookzo.bookpergroup', 0) ) {
			$booked = $object->getBooked();
		}
		
		// // check if period has overlap with booked period and is valid
		foreach ( $prices as $i => $price ) {
			
			// is it valid
			if ( !$price->objectid || !in_array($price->arrival, $arrivals) ) 
			{
				unset($prices[$i]);
				continue;
			}

			## NOTE - let John look at this -> because this ain't right				
			// redate if nights aren't correct
			if ($price->minnights && $price->minnights > $price->nights ) {
				$price->departure = $this->app->date->create($price->arrival)->add($price->minnights)->format('Y-m-d');
			}

			foreach ( $booked as $b ) {
				if ( $price->arrival < $b->departure && $price->departure > $b->arrival ) {
					unset($prices[$i]);
					continue 2;
				}
			}
		}
		
		// first divide them in months
		$monthlist = array();
		
		foreach ( $prices as $price ) 
		{
			$monthkey 	= $this->app->date->create($price->arrival)->format('Y-m-01');
			$monthlist[$monthkey][$price->arrival][$price->priceid] = $price;
		}
		
		// now lets build some kind of table
		$months = array();

		foreach ( $monthlist as $month => $arrivals ) 
		{
			$foundtypes		= array();
			$tmp 			= new stdClass();
			$tmp->month 	= $month;			
			$tmp->headings 	= array();
			$tmp->rows 		= array();
			
			
			// first build headers of table
			foreach ( $arrivals as $departures ) 
			{
				foreach ( $departures as $priceid => $departure ) 
				{
					if ( !in_array($priceid, $foundtypes) )
					{
						$foundtypes[] = $priceid;
					}
				}
			}
			
			foreach ( $definitionids as $id ) {
				if ( in_array($id, $foundtypes) ) 
				{
					$id 				= $definitions[$id]->get('id');
					
					$heading	   		= new stdClass();
					$heading->name 		= $definitions[$id]->get('name');
					
					if ( !isset($tmp->headings[$heading->name]) ) {
						$tmp->headings[$heading->name] = $heading;
						$tmp->headings[$heading->name]->ids = array();
					}
				
					$tmp->headings[$heading->name]->ids[] = $id;						
				}
			} 
			
			// now lets build the rows
			foreach ( $arrivals as $arrival => $departures ) 
			{
				foreach ( $tmp->headings as $heading ) 
				{
					$found = false;
					foreach ( $heading->ids as $typeid )
					{
						if ( array_key_exists($typeid, $departures) ) {
							$found = $departures[$typeid];
							break;
						}
					}
					
					$tmp->rows[$arrival][$heading->name] = $found;
				}
			}
			
			// is this the active month
			if ( $searchedarrival && $month == $this->app->date->create($searchedarrival)->format('Y-m-01') ) {
				$active = count($months);
			}

			// add to stack
			$months[$month] = $tmp;
			
			
		}
		
		return $this->renderer->render('default', compact('months','active','params'));
	}
}
